Class: Wx::AUI::AuiNotebookPage

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/aui/aui_notebook.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

Holds information about a page in AuiNotebook.

An object of this class is notably passed to Wx::AUI::AuiTabArt#draw_tab and is used by it to render the pages tab accordingly.

Category: Window Docking (wxAUI)

Requires:

  • USE_AUI

Instance Method Summary collapse

Instance Method Details

#activeBoolean

True if the page is the currently selected page.

Returns:

  • (Boolean)


595
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 595

def active; end

#active=(val) ⇒ void

This method returns an undefined value.

True if the page is the currently selected page.

Parameters:

  • val (Boolean)


601
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 601

def active=(val); end

#bitmapWx::BitmapBundle

Bitmap shown in the tab if valid.

Returns:



583
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 583

def bitmap; end

#bitmap=(val) ⇒ void

This method returns an undefined value.

Bitmap shown in the tab if valid.

Parameters:



589
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 589

def bitmap=(val); end

#captionString

Text displayed on the tab.

Returns:

  • (String)


559
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 559

def caption; end

#caption=(val) ⇒ void

This method returns an undefined value.

Text displayed on the tab.

Parameters:

  • val (String)


565
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 565

def caption=(val); end

#tooltipString

Tooltip displayed when hovering over tab title.

Returns:

  • (String)


571
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 571

def tooltip; end

#tooltip=(val) ⇒ void

This method returns an undefined value.

Tooltip displayed when hovering over tab title.

Parameters:

  • val (String)


577
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 577

def tooltip=(val); end

#windowWx::Window

Window shown on this page.

Returns:



547
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 547

def window; end

#window=(val) ⇒ void

This method returns an undefined value.

Window shown on this page.

Parameters:



553
# File 'lib/wx/doc/gen/aui/aui_notebook.rb', line 553

def window=(val); end