Class: Wx::CSConv
Overview
This class converts between any character set supported by the system and Unicode.
Method Summary
Methods inherited from MBConv
Constructor Details
This class inherits a constructor from Wx::MBConv
This class converts between any character set supported by the system and Unicode.
This class inherits a constructor from Wx::MBConv