Class: Wx::GRID::GridBlockCoords
- Inherits:
-
Object
- Object
- Wx::GRID::GridBlockCoords
- Defined in:
- lib/wx/doc/gen/grid/grid_ctrl.rb
Overview
This class is untracked and should not be derived from nor instances extended!
Represents coordinates of a block of cells in the grid.
An object of this class contains coordinates of the left top and the bottom right corners of a block.
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
Equality operator.
-
#canonicalize ⇒ Wx::GRID::GridBlockCoords
Return the canonicalized block where top left coordinates is less than bottom right coordinates.
- #contains(*args) ⇒ Object
-
#difference(other, splitOrientation) ⇒ Wx::GRID::GridBlockDiffResult
Calculates the result blocks by subtracting the other block from this block.
-
#get_bottom_right ⇒ Array(Integer, Integer)
(also: #bottom_right)
Return the coordinates of the bottom right corner.
-
#get_bottom_row ⇒ Integer
(also: #bottom_row)
Return the row of the bottom right corner.
-
#get_left_col ⇒ Integer
(also: #left_col)
Return the column of the left top corner.
-
#get_right_col ⇒ Integer
(also: #right_col)
Return the column of the bottom right corner.
-
#get_top_left ⇒ Array(Integer, Integer)
(also: #top_left)
Return the coordinates of the top left corner.
-
#get_top_row ⇒ Integer
(also: #top_row)
Return the row of the left top corner.
-
#initialize(*args) ⇒ GridBlockCoords
constructor
A new instance of GridBlockCoords.
-
#intersects(other) ⇒ Boolean
Whether the blocks intersect.
-
#set_bottom_row(row) ⇒ void
(also: #bottom_row=)
Set the row of the bottom right corner.
-
#set_left_col(col) ⇒ void
(also: #left_col=)
Set the column of the left top corner.
-
#set_right_col(col) ⇒ void
(also: #right_col=)
Set the column of the bottom right corner.
-
#set_top_row(row) ⇒ void
(also: #top_row=)
Set the row of the left top corner.
-
#sym_difference(other) ⇒ Wx::GRID::GridBlockDiffResult
Calculates the symmetric difference of the blocks.
Constructor Details
#initialize ⇒ Wx::GRID::GridBlockCoords #initialize(topRow, leftCol, bottomRow, rightCol) ⇒ Wx::GRID::GridBlockCoords
Returns a new instance of GridBlockCoords.
2789 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2789 def initialize(*args) end |
Instance Method Details
#==(other) ⇒ Boolean
Equality operator.
2888 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2888 def ==(other) end |
#canonicalize ⇒ Wx::GRID::GridBlockCoords
Return the canonicalized block where top left coordinates is less than bottom right coordinates.
2847 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2847 def canonicalize; end |
#contains(cell) ⇒ Boolean #contains(other) ⇒ Boolean
2868 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2868 def contains(*args) end |
#difference(other, splitOrientation) ⇒ Wx::GRID::GridBlockDiffResult
Calculates the result blocks by subtracting the other block from this block.
Up to 4 blocks. If block doesn't exist in the result, it has value of Wx::GridNoBlockCoords.
2876 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2876 def difference(other, splitOrientation) end |
#get_bottom_right ⇒ Array(Integer, Integer) Also known as: bottom_right
Return the coordinates of the bottom right corner.
2842 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2842 def get_bottom_right; end |
#get_bottom_row ⇒ Integer Also known as: bottom_row
Return the row of the bottom right corner.
2815 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2815 def get_bottom_row; end |
#get_left_col ⇒ Integer Also known as: left_col
Return the column of the left top corner.
2804 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2804 def get_left_col; end |
#get_right_col ⇒ Integer Also known as: right_col
Return the column of the bottom right corner.
2826 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2826 def get_right_col; end |
#get_top_left ⇒ Array(Integer, Integer) Also known as: top_left
Return the coordinates of the top left corner.
2837 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2837 def get_top_left; end |
#get_top_row ⇒ Integer Also known as: top_row
Return the row of the left top corner.
2793 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2793 def get_top_row; end |
#intersects(other) ⇒ Boolean
Whether the blocks intersect.
true, if the block intersects with the other, false, otherwise.
2854 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2854 def intersects(other) end |
#set_bottom_row(row) ⇒ void Also known as: bottom_row=
This method returns an undefined value.
Set the row of the bottom right corner.
2821 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2821 def set_bottom_row(row) end |
#set_left_col(col) ⇒ void Also known as: left_col=
This method returns an undefined value.
Set the column of the left top corner.
2810 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2810 def set_left_col(col) end |
#set_right_col(col) ⇒ void Also known as: right_col=
This method returns an undefined value.
Set the column of the bottom right corner.
2832 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2832 def set_right_col(col) end |
#set_top_row(row) ⇒ void Also known as: top_row=
This method returns an undefined value.
Set the row of the left top corner.
2799 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2799 def set_top_row(row) end |
#sym_difference(other) ⇒ Wx::GRID::GridBlockDiffResult
Calculates the symmetric difference of the blocks.
Up to 4 blocks. If block doesn't exist in the result, it has value of Wx::GridNoBlockCoords.
2883 |
# File 'lib/wx/doc/gen/grid/grid_ctrl.rb', line 2883 def sym_difference(other) end |