Module: Wx::HTML

Defined in:
lib/wx/doc/gen/html/html_cell.rb,
lib/wx/doc/gen/html/html_window.rb,
lib/wx/doc/gen/html/html_list_box.rb,
lib/wx/doc/gen/html/html_printout.rb,
lib/wx/doc/gen/html/html_help_data.rb,
lib/wx/doc/gen/html/html_cell_event.rb,
lib/wx/doc/gen/html/html_link_event.rb,
lib/wx/doc/html/simple_html_listbox.rb,
lib/wx/doc/gen/html/html_data_object.rb,
lib/wx/doc/gen/html/html_help_window.rb,
lib/wx/doc/html/html_help_controller.rb,
lib/wx/doc/gen/html/html_easy_printing.rb,
lib/wx/doc/gen/html/html_help_controller.rb

Defined Under Namespace

Classes: HTMLDataObject, HelpSearchMode, HtmlBookRecord, HtmlCell, HtmlCellEvent, HtmlContainerCell, HtmlEasyPrinting, HtmlFilter, HtmlHelpController, HtmlHelpData, HtmlHelpDataItem, HtmlHelpWindow, HtmlLinkEvent, HtmlLinkInfo, HtmlListBox, HtmlOpeningStatus, HtmlPrintout, HtmlScriptMode, HtmlSelection, HtmlSelectionState, HtmlURLType, HtmlWindow, SimpleHtmlListBox

Constant Summary collapse

HTML_ALIGN_LEFT =
0
HTML_ALIGN_RIGHT =
2
HTML_ALIGN_JUSTIFY =
16
HTML_ALIGN_TOP =
4
HTML_ALIGN_BOTTOM =
8
HTML_ALIGN_CENTER =
1
HTML_CLR_FOREGROUND =
1
HTML_CLR_BACKGROUND =
2
HTML_CLR_TRANSPARENT_BACKGROUND =
4
HTML_UNITS_PIXELS =
1
HTML_UNITS_PERCENT =
2
HTML_INDENT_LEFT =
16
HTML_INDENT_RIGHT =
32
HTML_INDENT_TOP =
64
HTML_INDENT_BOTTOM =
128
HTML_INDENT_HORIZONTAL =
48
HTML_INDENT_VERTICAL =
192
HTML_INDENT_ALL =
240
HTML_COND_ISANCHOR =
1
HTML_COND_ISIMAGEMAP =
2
HTML_COND_USER =
10000
HTML_FIND_EXACT =
1
HTML_FIND_NEAREST_BEFORE =
2
HTML_FIND_NEAREST_AFTER =
4
HW_SCROLLBAR_NEVER =
2
HW_SCROLLBAR_AUTO =
4
HW_NO_SELECTION =
8
HW_DEFAULT_STYLE =
4
EVT_HTML_CELL_CLICKED =
10343
EVT_HTML_CELL_HOVER =
10344
10345
HLB_DEFAULT_STYLE =
134217728
HLB_MULTIPLE =
64
ID_HTML_PANEL =
6010
ID_HTML_BACK =
6011
ID_HTML_FORWARD =
6012
ID_HTML_UPNODE =
6013
ID_HTML_UP =
6014
ID_HTML_DOWN =
6015
ID_HTML_PRINT =
6016
ID_HTML_OPENFILE =
6017
ID_HTML_OPTIONS =
6018
ID_HTML_BOOKMARKSLIST =
6019
ID_HTML_BOOKMARKSADD =
6020
ID_HTML_BOOKMARKSREMOVE =
6021
ID_HTML_TREECTRL =
6022
ID_HTML_INDEXPAGE =
6023
ID_HTML_INDEXLIST =
6024
ID_HTML_INDEXTEXT =
6025
ID_HTML_INDEXBUTTON =
6026
ID_HTML_INDEXBUTTONALL =
6027
ID_HTML_NOTEBOOK =
6028
ID_HTML_SEARCHPAGE =
6029
ID_HTML_SEARCHTEXT =
6030
ID_HTML_SEARCHLIST =
6031
ID_HTML_SEARCHBUTTON =
6032
ID_HTML_SEARCHCHOICE =
6033
ID_HTML_COUNTINFO =
6034
PAGE_ODD =
0
PAGE_EVEN =
1
PAGE_ALL =
2
HF_TOOLBAR =
1
HF_CONTENTS =
2
HF_INDEX =
4
HF_SEARCH =
8
HF_BOOKMARKS =
16
HF_OPEN_FILES =
32
HF_PRINT =
64
HF_FLAT_TOOLBAR =
128
HF_MERGE_BOOKS =
256
HF_ICONS_BOOK =
512
HF_ICONS_BOOK_CHAPTER =
1024
HF_ICONS_FOLDER =
0
HF_DEFAULT_STYLE =
95
ID_HTML_HELPFRAME =
6001
HF_EMBEDDED =
32768
HF_DIALOG =
65536
HF_FRAME =
131072
HF_MODAL =
262144
HELP_NETSCAPE =
1

Class Method Summary collapse

Class Method Details

.html_modal_help(parent, help_file, topic = '', style = Wx::HTML::HF_DEFAULT_STYLE) ⇒ void

This method returns an undefined value.

This module method uses Wx::HTML::HtmlHelpController to display help in a modal dialog and returns after the dialog has been closed.

This is useful on platforms such as WXOSX where if you display help from a modal dialog, the help window must itself be a modal dialog.

Parameters:

  • parent (Wx::Window)

    parent of the dialog.

  • help_file (String)

    the HTML help file to show.

  • topic (String) (defaults to: '')

    an optional topic. If this is empty, the help contents will be shown.

  • style (Integer) (defaults to: Wx::HTML::HF_DEFAULT_STYLE)

    is a combination of the flags described in the HtmlHelpController documentation.



31
# File 'lib/wx/doc/html/html_help_controller.rb', line 31

def self.html_modal_help(parent, help_file, topic = '', style = Wx::HTML::HF_DEFAULT_STYLE); end

.HtmlModalHelp(parent, help_file, topic, style = Wx::HTML::HF_DEFAULT_STYLE) ⇒ void

This method returns an undefined value.

Convenience alias for html_modal_help similarly named as the wxWidgets wxHtmlModalHelp class.

Parameters:

  • parent (Wx::Window)

    parent of the dialog.

  • help_file (String)

    the HTML help file to show.

  • topic (String)

    an optional topic. If this is empty, the help contents will be shown.

  • style (Integer) (defaults to: Wx::HTML::HF_DEFAULT_STYLE)

    is a combination of the flags described in the HtmlHelpController documentation.



40
# File 'lib/wx/doc/html/html_help_controller.rb', line 40

def self.HtmlModalHelp(parent, help_file, topic, style = Wx::HTML::HF_DEFAULT_STYLE); end