Class: Wx::HTML::HtmlLinkInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/html/html_cell.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

This class stores all necessary information about hypertext links (as represented by tag in HTML documents).

In current implementation it stores URL and target frame name.

Note:

Frames are not currently supported by Wx::HTML!

Category: Wx::HTML

Requires:

  • USE_HTML

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initializeWx::HTML::HtmlLinkInfo #initialize(href, target = ('')) ⇒ Wx::HTML::HtmlLinkInfo

Returns a new instance of HtmlLinkInfo.

Overloads:

  • #initializeWx::HTML::HtmlLinkInfo

    Default ctor.

  • #initialize(href, target = ('')) ⇒ Wx::HTML::HtmlLinkInfo

    Construct hypertext link from HREF (aka URL) and TARGET (name of target frame).

    Parameters:

    • href (String)
    • target (String) (defaults to: (''))


299
# File 'lib/wx/doc/gen/html/html_cell.rb', line 299

def initialize(*args) end

Instance Method Details

#get_eventWx::MouseEvent Also known as: event

Return pointer to event that generated OnLinkClicked() event.

Valid only within Wx::HTML::HtmlWindow#on_link_clicked, nil otherwise.

Returns:



305
# File 'lib/wx/doc/gen/html/html_cell.rb', line 305

def get_event; end

#get_hrefString Also known as: href

Return HREF value of the tag.

Returns:

  • (String)


310
# File 'lib/wx/doc/gen/html/html_cell.rb', line 310

def get_href; end

#get_html_cellWx::HTML::HtmlCell Also known as: html_cell

Return pointer to the cell that was clicked.

Valid only within Wx::HTML::HtmlWindow#on_link_clicked, nil otherwise.

Returns:



317
# File 'lib/wx/doc/gen/html/html_cell.rb', line 317

def get_html_cell; end

#get_targetString Also known as: target

Returns:

  • (String)


322
# File 'lib/wx/doc/gen/html/html_cell.rb', line 322

def get_target; end