Class: Wx::ItemAttr

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/list_ctrl.rb

Overview

Represents the attributes (colour, font, ...) of an item of a control with multiple items such as e.g.

ListCtrl.

Category: Data Structures

See Also:

  • Overview

Requires:

  • USE_LISTCTRL

Instance Method Summary collapse

Constructor Details

#initializeWx::ItemAttr #initialize(colText, colBack, font) ⇒ Wx::ItemAttr

Returns a new instance of ItemAttr.

Overloads:



1587
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1587

def initialize(*args) end

Instance Method Details

#==(other) ⇒ Boolean

Compare two item attributes for equality.

Parameters:

Returns:

  • (Boolean)


1592
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1592

def ==(other) end

#get_background_colourWx::Colour, ... Also known as: background_colour

Returns the currently set background colour.

Returns:



1596
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1596

def get_background_colour; end

#get_fontWx::Font, Wx::FontInfo Also known as: font

Returns the currently set font.

Returns:



1601
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1601

def get_font; end

#get_text_colourWx::Colour, ... Also known as: text_colour

Returns the currently set text colour.

Returns:



1606
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1606

def get_text_colour; end

#has_background_colourBoolean Also known as: has_background_colour?

Returns true if the currently set background colour is valid.

Returns:

  • (Boolean)


1611
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1611

def has_background_colour; end

#has_coloursBoolean Also known as: has_colours?

Returns true if either text or background colour is set.

Returns:

  • (Boolean)

See Also:



1620
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1620

def has_colours; end

#has_fontBoolean Also known as: has_font?

Returns true if the currently set font is valid.

Returns:

  • (Boolean)


1625
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1625

def has_font; end

#has_text_colourBoolean Also known as: has_text_colour?

Returns true if the currently set text colour is valid.

Returns:

  • (Boolean)


1630
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1630

def has_text_colour; end

#is_defaultBoolean Also known as: default?

Returns true if this object has no custom attributes set.

Returns:

  • (Boolean)


1635
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1635

def is_default; end

#set_background_colour(colour) ⇒ void Also known as: background_colour=

This method returns an undefined value.

Sets a new background colour.

Parameters:



1641
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1641

def set_background_colour(colour) end

#set_font(font) ⇒ void Also known as: font=

This method returns an undefined value.

Sets a new font.

Parameters:



1647
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1647

def set_font(font) end

#set_text_colour(colour) ⇒ void Also known as: text_colour=

This method returns an undefined value.

Sets a new text colour.

Parameters:



1653
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1653

def set_text_colour(colour) end