Class: Wx::LanguageInfo
- Inherits:
-
Object
- Object
- Wx::LanguageInfo
- Defined in:
- lib/wx/doc/gen/locale.rb
Overview
This class is untracked and should not be derived from nor instances extended!
Encapsulates a Language identifier together with OS-specific information related to that language.
Instance Method Summary collapse
-
#canonical_name ⇒ String
Canonical name of the language, e.g.
-
#canonical_name=(val) ⇒ void
Canonical name of the language, e.g.
-
#canonical_ref ⇒ String
Canonical reference including region.
-
#canonical_ref=(val) ⇒ void
Canonical reference including region.
-
#description ⇒ String
Human-readable name of the language in English.
-
#description=(val) ⇒ void
Human-readable name of the language in English.
-
#description_native ⇒ String
Human-readable name of the language in this language itself.
-
#description_native=(val) ⇒ void
Human-readable name of the language in this language itself.
-
#get_canonical_with_region ⇒ String
(also: #canonical_with_region)
Return the canonical locale name including the region, if known.
-
#get_locale_name ⇒ String
(also: #locale_name)
Return the locale name corresponding to this language usable with
setlocale()on the current system. -
#language ⇒ Integer
Language id.
-
#language=(val) ⇒ void
Language id.
-
#layout_direction ⇒ Wx::LayoutDirection
The layout direction used for this language.
-
#layout_direction=(val) ⇒ void
The layout direction used for this language.
-
#locale_tag ⇒ String
Tag for locale in BCP 47-like notation.
-
#locale_tag=(val) ⇒ void
Tag for locale in BCP 47-like notation.
Instance Method Details
#canonical_name ⇒ String
Canonical name of the language, e.g. fr_FR.
4220 |
# File 'lib/wx/doc/gen/locale.rb', line 4220 def canonical_name; end |
#canonical_name=(val) ⇒ void
This method returns an undefined value.
Canonical name of the language, e.g. fr_FR.
4226 |
# File 'lib/wx/doc/gen/locale.rb', line 4226 def canonical_name=(val); end |
#canonical_ref ⇒ String
Canonical reference including region. Set, if the name specifies the language only, e.g. fr_FR for fr. Empty, if region is unknown or already part of the name.
4232 |
# File 'lib/wx/doc/gen/locale.rb', line 4232 def canonical_ref; end |
#canonical_ref=(val) ⇒ void
This method returns an undefined value.
Canonical reference including region. Set, if the name specifies the language only, e.g. fr_FR for fr. Empty, if region is unknown or already part of the name.
4238 |
# File 'lib/wx/doc/gen/locale.rb', line 4238 def canonical_ref=(val); end |
#description ⇒ String
Human-readable name of the language in English.
4244 |
# File 'lib/wx/doc/gen/locale.rb', line 4244 def description; end |
#description=(val) ⇒ void
This method returns an undefined value.
Human-readable name of the language in English.
4250 |
# File 'lib/wx/doc/gen/locale.rb', line 4250 def description=(val); end |
#description_native ⇒ String
Human-readable name of the language in this language itself.
4256 |
# File 'lib/wx/doc/gen/locale.rb', line 4256 def description_native; end |
#description_native=(val) ⇒ void
This method returns an undefined value.
Human-readable name of the language in this language itself.
4262 |
# File 'lib/wx/doc/gen/locale.rb', line 4262 def description_native=(val); end |
#get_canonical_with_region ⇒ String Also known as: canonical_with_region
Return the canonical locale name including the region, if known.
The value is identical to CanonicalRef, if not empty, otherwise it is identical to CanonicalName.
4287 |
# File 'lib/wx/doc/gen/locale.rb', line 4287 def get_canonical_with_region; end |
#get_locale_name ⇒ String Also known as: locale_name
Return the locale name corresponding to this language usable with setlocale() on the current system.
If setting locale for this language is not supported, the returned string is empty.
4280 |
# File 'lib/wx/doc/gen/locale.rb', line 4280 def get_locale_name; end |
#language ⇒ Integer
Wx::Language id. It should be greater than Wx::Language::LANGUAGE_USER_DEFINED when defining your own language info structure.
4196 |
# File 'lib/wx/doc/gen/locale.rb', line 4196 def language; end |
#language=(val) ⇒ void
This method returns an undefined value.
Wx::Language id. It should be greater than Wx::Language::LANGUAGE_USER_DEFINED when defining your own language info structure.
4202 |
# File 'lib/wx/doc/gen/locale.rb', line 4202 def language=(val); end |
#layout_direction ⇒ Wx::LayoutDirection
The layout direction used for this language.
4268 |
# File 'lib/wx/doc/gen/locale.rb', line 4268 def layout_direction; end |
#layout_direction=(val) ⇒ void
This method returns an undefined value.
The layout direction used for this language.
4274 |
# File 'lib/wx/doc/gen/locale.rb', line 4274 def layout_direction=(val); end |
#locale_tag ⇒ String
Tag for locale in BCP 47-like notation.
4208 |
# File 'lib/wx/doc/gen/locale.rb', line 4208 def locale_tag; end |
#locale_tag=(val) ⇒ void
This method returns an undefined value.
Tag for locale in BCP 47-like notation.
4214 |
# File 'lib/wx/doc/gen/locale.rb', line 4214 def locale_tag=(val); end |