Class: Wx::ListItem

Inherits:
Object show all
Defined in:
lib/wx/doc/gen/list_ctrl.rb

Overview

This class stores information about a ListCtrl item or column.

ListItem is a class which contains information about:

The ListItem object can also contain item-specific colour and font information: for this you need to call one of #set_text_colour, #set_background_colour or #set_font functions on it passing it the colour/font to use. If the colour/font is not specified, the default list control colour/font is used.

Category: Data Structures

See Also:

Requires:

  • USE_LISTCTRL

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initializeWx::ListItem

Constructor.



1399
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1399

def initialize; end

Instance Method Details

#clearvoid

This method returns an undefined value.

Resets the item state to the default.



1403
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1403

def clear; end

#get_alignWx::ListColumnFormat Also known as: align



1409
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1409

def get_align; end

#get_background_colourWx::Colour Also known as: background_colour

Returns the background colour for this item.

Returns:



1414
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1414

def get_background_colour; end

#get_columnInteger Also known as: column

Returns the zero-based column; meaningful only in report mode.

Returns:

  • (Integer)


1419
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1419

def get_column; end

#get_fontWx::Font Also known as: font

Returns the font used to display the item.

Returns:



1424
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1424

def get_font; end

#get_idInteger Also known as: id

Returns the zero-based item position.

Returns:

  • (Integer)


1429
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1429

def get_id; end

#get_imageInteger Also known as: image

Returns the zero-based index of the image associated with the item into the image list.

Returns:

  • (Integer)


1434
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1434

def get_image; end

#get_maskInteger Also known as: mask

Returns a bit mask indicating which fields of the structure are valid.

Can be any combination of the following values:

Returns:

  • (Integer)


1448
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1448

def get_mask; end

#get_stateInteger Also known as: state

Returns a bit field representing the state of the item.

Can be any combination of:

Returns:

  • (Integer)


1461
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1461

def get_state; end

#get_textWx::String Also known as: text

Returns the label/header text.

Returns:

  • (Wx::String)


1466
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1466

def get_text; end

#get_text_colourWx::Colour Also known as: text_colour

Returns the text colour.

Returns:



1471
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1471

def get_text_colour; end

#get_widthInteger Also known as: width

Meaningful only for column headers in report mode.

Returns the column width.

Returns:

  • (Integer)


1478
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1478

def get_width; end

#set_align(align) ⇒ void Also known as: align=

This method returns an undefined value.

Sets the alignment for the item.

See also #get_align

Parameters:



1486
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1486

def set_align(align) end

#set_background_colour(colBack) ⇒ void Also known as: background_colour=

This method returns an undefined value.

Sets the background colour for the item.

Parameters:



1492
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1492

def set_background_colour(colBack) end

#set_column(col) ⇒ void Also known as: column=

This method returns an undefined value.

Sets the zero-based column.

Meaningful only in report mode.

Parameters:

  • col (Integer)


1500
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1500

def set_column(col) end

#set_data(data) ⇒ void Also known as: data=

This method returns an undefined value.

Sets client data for the item.

Please note that client data is associated with the item and not with subitems.

Parameters:



1394
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1394

def set_data(data) end

#set_font(font) ⇒ void Also known as: font=

This method returns an undefined value.

Sets the font for the item.

Parameters:



1506
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1506

def set_font(font) end

#set_id(id) ⇒ void Also known as: id=

This method returns an undefined value.

Sets the zero-based item position.

Parameters:

  • id (Integer)


1512
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1512

def set_id(id) end

#set_image(image) ⇒ void Also known as: image=

This method returns an undefined value.

Sets the zero-based index of the image associated with the item into the image list.

Parameters:

  • image (Integer)


1518
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1518

def set_image(image) end

#set_mask(mask) ⇒ void Also known as: mask=

This method returns an undefined value.

Sets the mask of valid fields.

See #get_mask.

Parameters:

  • mask (Integer)


1526
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1526

def set_mask(mask) end

#set_state(state) ⇒ void Also known as: state=

This method returns an undefined value.

Sets the item state flags (note that the valid state flags are influenced by the value of the state mask, see #set_state_mask).

See #get_state for valid flag values.

Parameters:

  • state (Integer)


1534
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1534

def set_state(state) end

#set_state_mask(stateMask) ⇒ void Also known as: state_mask=

This method returns an undefined value.

Sets the bitmask that is used to determine which of the state flags are to be set.

See also #set_state.

Parameters:

  • stateMask (Integer)


1542
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1542

def set_state_mask(stateMask) end

#set_text(text) ⇒ void Also known as: text=

This method returns an undefined value.

Sets the text label for the item.

Parameters:

  • text (String)


1548
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1548

def set_text(text) end

#set_text_colour(colText) ⇒ void Also known as: text_colour=

This method returns an undefined value.

Sets the text colour for the item.

Parameters:



1554
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1554

def set_text_colour(colText) end

#set_width(width) ⇒ void Also known as: width=

This method returns an undefined value.

Meaningful only for column headers in report mode.

Sets the column width.

Parameters:

  • width (Integer)


1562
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1562

def set_width(width) end