Class: Wx::MBConv

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/mbconv.rb

Overview

Note:

Note that in wxRuby these classes only provide types without any operations as these are not required as Ruby provides its own perfectly good encoding conversion methods. These types are therefor only required to provide as argument to certain methods of the wrapped wxWidgets classes (see for example WEB::WebViewHandlerResponse).

This class is the base class of a hierarchy of classes capable of converting text strings between multibyte (SBCS or DBCS) encodings and Unicode.

This is an abstract base class which defines the operations implemented by all different conversion classes.

Instance Method Summary collapse

Constructor Details

#initializeMBConv (protected)

Returns a new instance of MBConv.



19
# File 'lib/wx/doc/mbconv.rb', line 19

protected def initialize; end