Class: Wx::MBConvUTF16

Inherits:
MBConv
  • Object
show all
Defined in:
lib/wx/doc/mbconv.rb

Overview

This class is used to convert between multibyte encodings and UTF-16 Unicode encoding (also known as UCS-2).

Unlike UTF-8 encoding, UTF-16 uses words and not bytes and hence depends on the byte ordering: big or little endian. Hence this class is provided in a little endian version and a big endian version. MBConvUTF16 always provides the implementation native to the current platform (e.g. LE under Windows and BE under Mac).

Instance Method Summary collapse

Constructor Details

#initializeMBConvUTF16

Returns a new instance of MBConvUTF16.



83
# File 'lib/wx/doc/mbconv.rb', line 83

def initialize; end