Class: Wx::MBConvUTF32

Inherits:
MBConv
  • Object
show all
Defined in:
lib/wx/doc/mbconv.rb

Overview

This class is used to convert between multibyte encodings and UTF-32 Unicode encoding (also known as UCS-4).

Unlike UTF-8 encoding, UTF-32 uses (double) words and not bytes and hence depends on the byte ordering: big or little endian. Hence this class is provided in in a little endian version and a big endian version. MBConvUTF32 always provides the implementation native to the current platform (e.g. LE under Windows and BE under Mac).

Instance Method Summary collapse

Constructor Details

#initializeMBConvUTF32

Returns a new instance of MBConvUTF32.



92
# File 'lib/wx/doc/mbconv.rb', line 92

def initialize; end