Class: Wx::PG::PGPaintData

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/pg/pg_property.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

Contains information related to property's OnCustomPaint.

Requires:

  • USE_PROPGRID

Instance Method Summary collapse

Instance Method Details

#choice_itemInteger

Normally -1, otherwise index to drop-down list item that has to be drawn.

Returns:

  • (Integer)


2041
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2041

def choice_item; end

#choice_item=(val) ⇒ void

This method returns an undefined value.

Normally -1, otherwise index to drop-down list item that has to be drawn.

Parameters:

  • val (Integer)


2047
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2047

def choice_item=(val); end

#drawn_heightInteger

In a measure item call, set this to the height of item at m_choiceItem index.

Returns:

  • (Integer)


2065
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2065

def drawn_height; end

#drawn_height=(val) ⇒ void

This method returns an undefined value.

In a measure item call, set this to the height of item at m_choiceItem index.

Parameters:

  • val (Integer)


2071
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2071

def drawn_height=(val); end

#drawn_widthInteger

Set to drawn width in OnCustomPaint (optional).

Returns:

  • (Integer)


2053
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2053

def drawn_width; end

#drawn_width=(val) ⇒ void

This method returns an undefined value.

Set to drawn width in OnCustomPaint (optional).

Parameters:

  • val (Integer)


2059
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2059

def drawn_width=(val); end

#parentWx::PG::PropertyGrid



2029
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2029

def parent; end

#parent=(val) ⇒ void

This method returns an undefined value.

Wx::PG::PropertyGrid

Parameters:



2035
# File 'lib/wx/doc/gen/pg/pg_property.rb', line 2035

def parent=(val); end