Class: Wx::RBN::RibbonAUIArtProvider

Inherits:
RibbonMSWArtProvider show all
Defined in:
lib/wx/doc/gen/rbn/ribbon_art_provider.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

An art provider styled after the AUI docking framework.

Like RibbonMSWArtProvider it uses gradient fills, but differs in its layout of panel labels (placed at the top rather than the bottom) and general styling.

Category: Ribbon User Interface

See Also:

Requires:

  • USE_RIBBON

Instance Method Summary collapse

Methods inherited from RibbonArtProvider

#clone, #draw_button_bar_background, #draw_button_bar_button, #draw_gallery_background, #draw_gallery_item_background, #draw_help_button, #draw_minimised_panel, #draw_page_background, #draw_panel_background, #draw_scroll_button, #draw_tab, #draw_tab_ctrl_background, #draw_tab_separator, #draw_toggle_button, #draw_tool, #draw_tool_bar_background, #draw_tool_group_background, #get_bar_tab_width, #get_bar_toggle_button_area, #get_button_bar_button_size, #get_button_bar_button_text_width, #get_color, #get_colour, #get_colour_scheme, #get_flags, #get_font, #get_gallery_client_size, #get_gallery_size, #get_metric, #get_minimised_panel_minimum_size, #get_page_background_redraw_area, #get_panel_client_size, #get_panel_ext_button_area, #get_panel_size, #get_ribbon_help_button_area, #get_scroll_button_minimum_size, #get_tab_ctrl_height, #get_tool_size, #set_color, #set_colour, #set_colour_scheme, #set_flags, #set_font, #set_metric

Constructor Details

#initializeWx::RBN::RibbonAUIArtProvider



1135
# File 'lib/wx/doc/gen/rbn/ribbon_art_provider.rb', line 1135

def initialize; end