Class: Wx::RTC::RichTextContextMenuPropertiesInfo

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_ctrl.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

RichTextContextMenuPropertiesInfo keeps track of objects that appear in the context menu, whose properties are available to be edited.

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Constructor Details

#initializeWx::RTC::RichTextContextMenuPropertiesInfo

Constructor.



1932
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1932

def initialize; end

Instance Method Details

#add_item(label, obj) ⇒ Boolean

Adds an item.

Parameters:

Returns:

  • (Boolean)


1942
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1942

def add_item(label, obj) end

#add_items(ctrl, container, obj) ⇒ Integer

Adds appropriate menu items for the current container and clicked on object (and container's parent, if appropriate).

Parameters:

Returns:

  • (Integer)


1955
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1955

def add_items(ctrl, container, obj) end

#add_menu_items(menu, startCmd = wxID_RICHTEXT_PROPERTIES1) ⇒ Integer

Returns the number of menu items that were added.

Parameters:

  • menu (Wx::Menu)
  • startCmd (Integer) (defaults to: wxID_RICHTEXT_PROPERTIES1)

Returns:

  • (Integer)


1948
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1948

def add_menu_items(menu, startCmd=wxID_RICHTEXT_PROPERTIES1) end

#clearvoid

This method returns an undefined value.

Clears the items.



1959
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1959

def clear; end

#get_countInteger Also known as: count

Returns the number of items.

Returns:

  • (Integer)


1985
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1985

def get_count; end

#get_label(n) ⇒ String Also known as: label

Returns the nth label.

Parameters:

  • n (Integer)

Returns:

  • (String)


1964
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1964

def get_label(n) end

#get_labelsWx::ArrayString Also known as: labels

Returns the array of labels.

Returns:

  • (Wx::ArrayString)


1980
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1980

def get_labels; end

#get_object(n) ⇒ Wx::RTC::RichTextObject Also known as: object

Returns the nth object.

Parameters:

  • n (Integer)

Returns:



1970
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1970

def get_object(n) end

#get_objectsArray<Wx::RTC::RichTextObject> Also known as: objects

Returns the array of objects.

Returns:



1975
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1975

def get_objects; end

#initvoid

This method returns an undefined value.

Initialisation.



1936
# File 'lib/wx/doc/gen/rtc/rich_text_ctrl.rb', line 1936

def init; end