Class: Wx::RTC::RichTextDrawingContext

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A class for passing information to drawing and measuring functions.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initialize(buffer) ⇒ Wx::RTC::RichTextDrawingContext

Pass the buffer to the context so the context can retrieve information such as virtual attributes.

Parameters:



1339
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1339

def initialize(buffer) end

Instance Method Details

#apply_virtual_attributes(attr, obj) ⇒ Boolean

Applies any virtual attributes relevant to this object.

Parameters:

Returns:

  • (Boolean)


1364
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1364

def apply_virtual_attributes(attr, obj) end

#enable_delayed_image_loading(b) ⇒ void

This method returns an undefined value.

Enable or disable delayed image loading.

Parameters:

  • b (Boolean)


1433
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1433

def enable_delayed_image_loading(b) end

#enable_images(b) ⇒ void

This method returns an undefined value.

Enable or disable images.

Parameters:

  • b (Boolean)


1412
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1412

def enable_images(b) end

#enable_virtual_attributes(b) ⇒ void

This method returns an undefined value.

Enables virtual attribute processing.

Parameters:

  • b (Boolean)


1402
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1402

def enable_virtual_attributes(b) end

#get_delayed_image_loadingBoolean Also known as: delayed_image_loading

Returns true if delayed image loading is enabled.

Returns:

  • (Boolean)


1437
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1437

def get_delayed_image_loading; end

#get_images_enabledBoolean Also known as: images_enabled

Returns true if images are enabled.

Returns:

  • (Boolean)


1416
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1416

def get_images_enabled; end

#get_laying_outBoolean Also known as: laying_out

Returns true if laying out.

Returns:

  • (Boolean)


1427
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1427

def get_laying_out; end

#get_virtual_attributes(obj) ⇒ Wx::RTC::RichTextAttr Also known as: virtual_attributes

Returns the virtual attributes for this object.

Virtual attributes can be provided for visual cues without affecting the actual styling.

Parameters:

Returns:



1357
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1357

def get_virtual_attributes(obj) end

#get_virtual_attributes_enabledBoolean Also known as: virtual_attributes_enabled

Returns true if virtual attribute processing is enabled.

Returns:

  • (Boolean)


1406
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1406

def get_virtual_attributes_enabled; end

#get_virtual_subobject_attributes(obj, positions, attributes) ⇒ Integer Also known as: virtual_subobject_attributes

Gets the mixed virtual attributes for individual positions within the object.

For example, individual characters within a text object may require special highlighting. The function is passed the count returned by GetVirtualSubobjectAttributesCount.

Parameters:

Returns:

  • (Integer)


1381
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1381

def get_virtual_subobject_attributes(obj, positions, attributes) end

#get_virtual_subobject_attributes_count(obj) ⇒ Integer Also known as: virtual_subobject_attributes_count

Gets the count for mixed virtual attributes for individual positions within the object.

For example, individual characters within a text object may require special highlighting.

Parameters:

Returns:

  • (Integer)


1371
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1371

def get_virtual_subobject_attributes_count(obj) end

#get_virtual_text(obj, text) ⇒ Boolean Also known as: virtual_text

Gets the virtual text for this object.

Parameters:

Returns:

  • (Boolean)


1396
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1396

def get_virtual_text(obj, text) end

#has_virtual_attributes(obj) ⇒ Boolean Also known as: has_virtual_attributes?

Does this object have virtual attributes?

Virtual attributes can be provided for visual cues without affecting the actual styling.

Parameters:

Returns:

  • (Boolean)


1349
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1349

def has_virtual_attributes(obj) end

#has_virtual_text(obj) ⇒ Boolean Also known as: has_virtual_text?

Do we have virtual text for this object?

Virtual text allows an application to replace characters in an object for editing and display purposes, for example for highlighting special characters.

Parameters:

Returns:

  • (Boolean)


1389
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1389

def has_virtual_text(obj) end

#initvoid

This method returns an undefined value.



1342
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1342

def init; end

#set_laying_out(b) ⇒ void Also known as: laying_out=

This method returns an undefined value.

Set laying out flag.

Parameters:

  • b (Boolean)


1422
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1422

def set_laying_out(b) end