Class: Wx::RTC::RichTextDrawingHandler

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_buffer.rb

Overview

The base class for custom drawing handlers.

Currently, drawing handlers can provide virtual attributes.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initialize(name = ('')) ⇒ Wx::RTC::RichTextDrawingHandler

Creates a drawing handler object.

Parameters:

  • name (String) (defaults to: (''))


1124
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1124

def initialize(name=('')) end

Instance Method Details

#get_nameString Also known as: name

Returns the name of the handler.

Returns:

  • (String)


1180
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1180

def get_name; end

#get_virtual_attributes(attr, obj) ⇒ Boolean Also known as: virtual_attributes

Provides virtual attributes that we can provide.

Parameters:

Returns:

  • (Boolean)


1136
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1136

def get_virtual_attributes(attr, obj) end

#get_virtual_subobject_attributes(obj, positions, attributes) ⇒ Integer Also known as: virtual_subobject_attributes

Gets the mixed virtual attributes for individual positions within the object.

For example, individual characters within a text object may require special highlighting. Returns the number of virtual attributes found.

Parameters:

Returns:

  • (Integer)


1154
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1154

def get_virtual_subobject_attributes(obj, positions, attributes) end

#get_virtual_subobject_attributes_count(obj) ⇒ Integer Also known as: virtual_subobject_attributes_count

Gets the count for mixed virtual attributes for individual positions within the object.

For example, individual characters within a text object may require special highlighting.

Parameters:

Returns:

  • (Integer)


1144
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1144

def get_virtual_subobject_attributes_count(obj) end

#get_virtual_text(obj, text) ⇒ Boolean Also known as: virtual_text

Gets the virtual text for this object.

Parameters:

Returns:

  • (Boolean)


1169
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1169

def get_virtual_text(obj, text) end

#has_virtual_attributes(obj) ⇒ Boolean Also known as: has_virtual_attributes?

Returns true if this object has virtual attributes that we can provide.

Parameters:

Returns:

  • (Boolean)


1129
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1129

def has_virtual_attributes(obj) end

#has_virtual_text(obj) ⇒ Boolean Also known as: has_virtual_text?

Do we have virtual text for this object?

Virtual text allows an application to replace characters in an object for editing and display purposes, for example for highlighting special characters.

Parameters:

Returns:

  • (Boolean)


1162
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1162

def has_virtual_text(obj) end

#set_name(name) ⇒ void Also known as: name=

This method returns an undefined value.

Sets the name of the handler.

Parameters:

  • name (String)


1175
# File 'lib/wx/doc/gen/rtc/rich_text_buffer.rb', line 1175

def set_name(name) end