Class: Wx::RTC::RichTextProperties

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A simple property class using Variants.

This is used to give each rich text object the ability to store custom properties that can be used by the application.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initializeWx::RTC::RichTextProperties #initialize(props) ⇒ Wx::RTC::RichTextProperties

Returns a new instance of RichTextProperties.

Overloads:



2787
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2787

def initialize(*args) end

Instance Method Details

#==(props) ⇒ Boolean

Equality operator.

Parameters:

Returns:

  • (Boolean)


2792
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2792

def ==(props) end

#clearvoid

This method returns an undefined value.

Clears the properties.



2801
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2801

def clear; end

#copy(props) ⇒ void

This method returns an undefined value.

Copies from props.

Parameters:



2797
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2797

def copy(props) end

#find(name) ⇒ Integer

Finds the given property.

Parameters:

  • name (String)

Returns:

  • (Integer)


2833
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2833

def find(name) end

#find_or_create_property(name) ⇒ Wx::Variant

Finds or creates a property with the given name, returning a pointer to the variant.

Parameters:

  • name (String)

Returns:



2849
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2849

def find_or_create_property(name) end

#get_countInteger Also known as: count

Returns a count of the properties.

Returns:

  • (Integer)


2821
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2821

def get_count; end

#get_propertiesArray<Wx::Variant> Also known as: properties

Returns the array of variants implementing the properties.

Returns:



2805
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2805

def get_properties; end

#get_property(name) ⇒ Wx::Variant Also known as: property

Gets the property variant by name.

Parameters:

  • name (String)

Returns:



2843
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2843

def get_property(name) end

#get_property_bool(name) ⇒ Boolean Also known as: property_bool

Gets the value of the named property as a boolean.

Parameters:

  • name (String)

Returns:

  • (Boolean)


2866
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2866

def get_property_bool(name) end

#get_property_double(name) ⇒ Float Also known as: property_double

Gets the value of the named property as a double.

Parameters:

  • name (String)

Returns:

  • (Float)


2872
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2872

def get_property_double(name) end

#get_property_long(name) ⇒ Integer Also known as: property_long

Gets the value of the named property as a long integer.

Parameters:

  • name (String)

Returns:

  • (Integer)


2860
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2860

def get_property_long(name) end

#get_property_namesArray<String> Also known as: property_names

Returns all the property names.

Returns:

  • (Array<String>)


2816
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2816

def get_property_names; end

#get_property_string(name) ⇒ String Also known as: property_string

Gets the value of the named property as a string.

Parameters:

  • name (String)

Returns:

  • (String)


2854
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2854

def get_property_string(name) end

#has_property(name) ⇒ Boolean Also known as: has_property?

Returns true if the given property is found.

Parameters:

  • name (String)

Returns:

  • (Boolean)


2827
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2827

def has_property(name) end

#merge_properties(properties) ⇒ void

This method returns an undefined value.

Merges the given properties with these properties.

Parameters:



2915
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2915

def merge_properties(properties) end

#remove(name) ⇒ Boolean

Removes the given property.

Parameters:

  • name (String)

Returns:

  • (Boolean)


2838
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2838

def remove(name) end

#remove_properties(properties) ⇒ void

This method returns an undefined value.

Removes the given properties from these properties.

Parameters:



2910
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2910

def remove_properties(properties) end

#set_properties(props) ⇒ void Also known as: properties=

This method returns an undefined value.

Sets the array of variants.

Parameters:



2811
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2811

def set_properties(props) end

#set_property(variant) ⇒ void #set_property(name, variant) ⇒ void #set_property(name, value) ⇒ void #set_property(name, value) ⇒ void #set_property(name, value) ⇒ void #set_property(name, value) ⇒ void Also known as: property=

Overloads:

  • #set_property(variant) ⇒ void

    This method returns an undefined value.

    Sets the property by passing a variant which contains a name and value.

    Parameters:

    • variant (nil, String, Integer, Float, Time, Wx::Font, Wx::Colour, Wx::Variant, Array<WxVariant>, Array<String>, ObjectWx::PG::ColourPropertyValue)
  • #set_property(name, variant) ⇒ void

    This method returns an undefined value.

    Sets a property by name and variant.

    Parameters:

    • name (String)
    • variant (nil, String, Integer, Float, Time, Wx::Font, Wx::Colour, Wx::Variant, Array<WxVariant>, Array<String>, ObjectWx::PG::ColourPropertyValue)
  • #set_property(name, value) ⇒ void

    This method returns an undefined value.

    Sets a property by name and string value.

    Parameters:

    • name (String)
    • value (String)
  • #set_property(name, value) ⇒ void

    This method returns an undefined value.

    Sets property by name and long integer value.

    Parameters:

    • name (String)
    • value (Integer)
  • #set_property(name, value) ⇒ void

    This method returns an undefined value.

    Sets property by name and double value.

    Parameters:

    • name (String)
    • value (Float)
  • #set_property(name, value) ⇒ void

    This method returns an undefined value.

    Sets property by name and boolean value.

    Parameters:

    • name (String)
    • value (Boolean)


2904
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2904

def set_property(*args) end