Class: Wx::RTC::RichTextXMLHandler
- Inherits:
-
RichTextFileHandler
- Object
- Object
- RichTextFileHandler
- Wx::RTC::RichTextXMLHandler
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_xml_handler.rb
Overview
A handler for loading and saving content in an XML format specific to RichTextBuffer.
You can either add the handler to the buffer and load and save through the buffer or control API, or you can create an instance of the handler on the stack and call its functions directly.
Handler flags
The following flags can be used with this handler, via the handler's #set_flags function or the buffer or control's SetHandlerFlags() function:
- RICHTEXT_HANDLER_INCLUDE_STYLESHEET Include the style sheet in loading and saving operations.
Category: Rich Text
Class Method Summary collapse
-
.clear_node_to_class_map ⇒ void
Cleans up the mapping between node name and C++ class.
-
.register_node_name(nodeName, className) ⇒ void
Call with XML node name, C++ class name so that Wx::RTC can read in the node.
Instance Method Summary collapse
-
#can_load ⇒ Boolean
(also: #can_load?)
Returns true.
-
#can_save ⇒ Boolean
(also: #can_save?)
Returns true.
-
#initialize(name = ("XML"), ext = ("XML"), type = Wx::RTC::RichTextFileType::RICHTEXT_TYPE_XML) ⇒ Wx::RTC::RichTextXMLHandler
constructor
Constructor.
Methods inherited from RichTextFileHandler
#can_handle, #get_encoding, #get_extension, #get_flags, #get_name, #get_type, #is_visible, #load_file, #save_file, #set_encoding, #set_extension, #set_flags, #set_name, #set_type, #set_visible
Methods inherited from Object
#clone, #dup, #is_same_as, #un_share
Constructor Details
#initialize(name = ("XML"), ext = ("XML"), type = Wx::RTC::RichTextFileType::RICHTEXT_TYPE_XML) ⇒ Wx::RTC::RichTextXMLHandler
Constructor.
30 |
# File 'lib/wx/doc/gen/rtc/rich_text_xml_handler.rb', line 30 def initialize(name=("XML"), ext=("XML"), type=Wx::RTC::RichTextFileType::RICHTEXT_TYPE_XML) end |
Class Method Details
.clear_node_to_class_map ⇒ void
This method returns an undefined value.
Cleans up the mapping between node name and C++ class.
52 |
# File 'lib/wx/doc/gen/rtc/rich_text_xml_handler.rb', line 52 def self.clear_node_to_class_map; end |
.register_node_name(nodeName, className) ⇒ void
This method returns an undefined value.
Call with XML node name, C++ class name so that Wx::RTC can read in the node.
If you add a custom object, call this.
48 |
# File 'lib/wx/doc/gen/rtc/rich_text_xml_handler.rb', line 48 def self.register_node_name(nodeName, className) end |
Instance Method Details
#can_load ⇒ Boolean Also known as: can_load?
Returns true.
34 |
# File 'lib/wx/doc/gen/rtc/rich_text_xml_handler.rb', line 34 def can_load; end |
#can_save ⇒ Boolean Also known as: can_save?
Returns true.
39 |
# File 'lib/wx/doc/gen/rtc/rich_text_xml_handler.rb', line 39 def can_save; end |