Class: Wx::RTC::TextAttrBorder

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A class representing a rich text object border.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Constructor Details

#initializeWx::RTC::TextAttrBorder

Default constructor.



2280
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2280

def initialize; end

Instance Method Details

#==(border) ⇒ Boolean

Equality operator.

Parameters:

Returns:

  • (Boolean)


2285
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2285

def ==(border) end

#add_flag(flag) ⇒ void

This method returns an undefined value.

Adds a border flag.

Parameters:

  • flag (Integer)


2408
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2408

def add_flag(flag) end

#apply(border, compareWith = nil) ⇒ Boolean

Applies the border to this object, but not if the same as compareWith.

Parameters:

Returns:

  • (Boolean)


2303
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2303

def apply(border, compareWith=nil) end

#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void

This method returns an undefined value.

Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.

Parameters:



2315
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2315

def collect_common_attributes(attr, clashingAttr, absentAttr) end

#eq_partial(border, weakTest = true) ⇒ Boolean

Partial equality test.

If weakTest is true, attributes of this object do not have to be present if those attributes of border are present. If weakTest is false, the function will fail if an attribute is present in border but not in this object.

Parameters:

Returns:

  • (Boolean)


2297
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2297

def eq_partial(border, weakTest=true) end

#get_colourWx::Colour Also known as: colour

Gets the colour.

Returns:



2346
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2346

def get_colour; end

#get_colour_longInteger Also known as: colour_long

Gets the colour as a long.

Returns:

  • (Integer)


2341
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2341

def get_colour_long; end

#get_flagsInteger Also known as: flags

Returns the border flags.

Returns:

  • (Integer)


2396
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2396

def get_flags; end

#get_styleInteger Also known as: style

Gets the border style.

Returns:

  • (Integer)


2325
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2325

def get_style; end

#get_widthWx::RTC::TextAttrDimension Also known as: width



2350
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2350

def get_width; end

#has_colourBoolean Also known as: has_colour?

True if the border has a valid colour.

Returns:

  • (Boolean)


2372
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2372

def has_colour; end

#has_styleBoolean Also known as: has_style?

True if the border has a valid style.

Returns:

  • (Boolean)


2367
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2367

def has_style; end

#has_widthBoolean Also known as: has_width?

True if the border has a valid width.

Returns:

  • (Boolean)


2377
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2377

def has_width; end

#is_defaultBoolean Also known as: default?

True if the border has no attributes set.

Returns:

  • (Boolean)


2387
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2387

def is_default; end

#is_validBoolean Also known as: valid?

True if the border is valid.

Returns:

  • (Boolean)


2382
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2382

def is_valid; end

#make_validvoid

This method returns an undefined value.

Set the valid flag for this border.



2392
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2392

def make_valid; end

#remove_flag(flag) ⇒ void

This method returns an undefined value.

Removes a border flag.

Parameters:

  • flag (Integer)


2413
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2413

def remove_flag(flag) end

#remove_style(attr) ⇒ Boolean

Removes the specified attributes from this object.

Parameters:

Returns:

  • (Boolean)


2308
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2308

def remove_style(attr) end

#resetvoid

This method returns an undefined value.

Resets the border style, colour, width and flags.



2289
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2289

def reset; end

#set_colour(colour) ⇒ void #set_colour(colour) ⇒ void Also known as: colour=

Overloads:

  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets the border colour.

    Parameters:

    • colour (Integer)
  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets the border colour.

    Parameters:



2336
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2336

def set_colour(*args) end

#set_flags(flags) ⇒ void Also known as: flags=

This method returns an undefined value.

Sets the border flags.

Parameters:

  • flags (Integer)


2402
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2402

def set_flags(flags) end

#set_style(style) ⇒ void Also known as: style=

This method returns an undefined value.

Sets the border style.

Parameters:

  • style (Integer)


2320
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2320

def set_style(style) end

#set_width(width) ⇒ void #set_width(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ void Also known as: width=

Overloads:

  • #set_width(width) ⇒ void

    This method returns an undefined value.

    Sets the border width.

    Parameters:

  • #set_width(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ void

    This method returns an undefined value.

    Sets the border width.

    Parameters:

    • value (Integer)
    • units (Wx::TextAttrUnits) (defaults to: Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM)


2362
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2362

def set_width(*args) end