Class: Wx::RTC::TextAttrBorders

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A class representing a rich text object's borders.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Constructor Details

#initializeWx::RTC::TextAttrBorders

Default constructor.



2432
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2432

def initialize; end

Instance Method Details

#==(borders) ⇒ Boolean

Equality operator.

Parameters:

Returns:

  • (Boolean)


2437
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2437

def ==(borders) end

#apply(borders, compareWith = nil) ⇒ Boolean

Applies border to this object, but not if the same as compareWith.

Parameters:

Returns:

  • (Boolean)


2484
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2484

def apply(borders, compareWith=nil) end

#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void

This method returns an undefined value.

Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.

Parameters:



2496
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2496

def collect_common_attributes(attr, clashingAttr, absentAttr) end

#eq_partial(borders, weakTest = true) ⇒ Boolean

Partial equality test.

If weakTest is true, attributes of this object do not have to be present if those attributes of borders are present. If weakTest is false, the function will fail if an attribute is present in borders but not in this object.

Parameters:

Returns:

  • (Boolean)


2478
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2478

def eq_partial(borders, weakTest=true) end

#get_bottomWx::RTC::TextAttrBorder Also known as: bottom

Returns the bottom border.



2520
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2520

def get_bottom; end

#get_leftWx::RTC::TextAttrBorder Also known as: left

Returns the left border.



2505
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2505

def get_left; end

#get_rightWx::RTC::TextAttrBorder Also known as: right

Returns the right border.



2510
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2510

def get_right; end

#get_topWx::RTC::TextAttrBorder Also known as: top

Returns the top border.



2515
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2515

def get_top; end

#is_validBoolean Also known as: valid?

Returns true if at least one border is valid.

Returns:

  • (Boolean)


2500
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2500

def is_valid; end

#remove_style(attr) ⇒ Boolean

Removes the specified attributes from this object.

Parameters:

Returns:

  • (Boolean)


2489
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2489

def remove_style(attr) end

#resetvoid

This method returns an undefined value.

Resets all borders.



2470
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2470

def reset; end

#set_colour(colour) ⇒ void #set_colour(colour) ⇒ void Also known as: colour=

Overloads:

  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets colour of all borders.

    Parameters:

    • colour (Integer)
  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets the colour for all borders.

    Parameters:



2453
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2453

def set_colour(*args) end

#set_style(style) ⇒ void Also known as: style=

This method returns an undefined value.

Sets the style of all borders.

Parameters:

  • style (Integer)


2442
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2442

def set_style(style) end

#set_width(width) ⇒ void #set_width(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ void Also known as: width=

Overloads:

  • #set_width(width) ⇒ void

    This method returns an undefined value.

    Sets the width of all borders.

    Parameters:

  • #set_width(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ void

    This method returns an undefined value.

    Sets the width of all borders.

    Parameters:

    • value (Integer)
    • units (Wx::TextAttrUnits) (defaults to: Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM)


2465
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2465

def set_width(*args) end