Class: Wx::RTC::TextAttrDimension
- Inherits:
-
Object
- Object
- Wx::RTC::TextAttrDimension
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_object.rb
Overview
This class is untracked and should not be derived from nor instances extended!
A class representing a rich text dimension, including units and position.
Category: Rich Text
Instance Method Summary collapse
-
#==(dim) ⇒ Boolean
Equality operator.
-
#apply(dim, compareWith = nil) ⇒ Boolean
Apply the dimension, but not those identical to compareWith if present.
-
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
-
#eq_partial(dim, weakTest = true) ⇒ Boolean
Partial equality test.
-
#get_flags ⇒ Wx::TextAttrDimensionFlags
(also: #flags)
Gets the dimension flags.
-
#get_position ⇒ Wx::TextBoxAttrPosition
(also: #position)
Gets the position flags.
-
#get_units ⇒ Wx::TextAttrUnits
(also: #units)
Gets the units of the dimension.
-
#get_value ⇒ Integer
(also: #value)
Returns the integer value of the dimension.
-
#get_value_mm ⇒ Float
(also: #value_mm)
Returns the floating-pointing value of the dimension in mm.
-
#initialize(*args) ⇒ TextAttrDimension
constructor
A new instance of TextAttrDimension.
-
#is_valid ⇒ Boolean
(also: #valid?)
Returns true if the dimension is valid.
-
#reset ⇒ void
Resets the dimension value and flags.
-
#set_flags(flags) ⇒ void
(also: #flags=)
Sets the dimension flags.
-
#set_position(pos) ⇒ void
(also: #position=)
Sets the position flags.
-
#set_units(units) ⇒ void
(also: #units=)
Sets the units of the dimension.
-
#set_valid(b) ⇒ void
(also: #valid=)
Sets the valid flag.
- #set_value(*args) ⇒ Object (also: #value=)
-
#set_value_mm(value) ⇒ void
(also: #value_mm=)
Sets the value of the dimension in mm.
Constructor Details
#initialize ⇒ Wx::RTC::TextAttrDimension #initialize(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ Wx::RTC::TextAttrDimension
Returns a new instance of TextAttrDimension.
1905 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1905 def initialize(*args) end |
Instance Method Details
#==(dim) ⇒ Boolean
Equality operator.
1935 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1935 def ==(dim) end |
#apply(dim, compareWith = nil) ⇒ Boolean
Apply the dimension, but not those identical to compareWith if present.
1923 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1923 def apply(dim, compareWith=nil) end |
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
This method returns an undefined value.
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
1930 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1930 def collect_common_attributes(attr, clashingAttr, absentAttr) end |
#eq_partial(dim, weakTest = true) ⇒ Boolean
Partial equality test.
If weakTest is true, attributes of this object do not have to be present if those attributes of dim are present. If weakTest is false, the function will fail if an attribute is present in dim but not in this object.
1917 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1917 def eq_partial(dim, weakTest=true) end |
#get_flags ⇒ Wx::TextAttrDimensionFlags Also known as: flags
Gets the dimension flags.
2009 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2009 def get_flags; end |
#get_position ⇒ Wx::TextBoxAttrPosition Also known as: position
Gets the position flags.
1987 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1987 def get_position; end |
#get_units ⇒ Wx::TextAttrUnits Also known as: units
Gets the units of the dimension.
1976 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1976 def get_units; end |
#get_value ⇒ Integer Also known as: value
Returns the integer value of the dimension.
1939 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1939 def get_value; end |
#get_value_mm ⇒ Float Also known as: value_mm
Returns the floating-pointing value of the dimension in mm.
1944 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1944 def get_value_mm; end |
#is_valid ⇒ Boolean Also known as: valid?
Returns true if the dimension is valid.
1998 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1998 def is_valid; end |
#reset ⇒ void
This method returns an undefined value.
Resets the dimension value and flags.
1909 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1909 def reset; end |
#set_flags(flags) ⇒ void Also known as: flags=
This method returns an undefined value.
Sets the dimension flags.
2015 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2015 def set_flags(flags) end |
#set_position(pos) ⇒ void Also known as: position=
This method returns an undefined value.
Sets the position flags.
1993 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1993 def set_position(pos) end |
#set_units(units) ⇒ void Also known as: units=
This method returns an undefined value.
Sets the units of the dimension.
1982 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1982 def set_units(units) end |
#set_valid(b) ⇒ void Also known as: valid=
This method returns an undefined value.
Sets the valid flag.
2004 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2004 def set_valid(b) end |
#set_value(value) ⇒ void #set_value(value, flags) ⇒ void #set_value(value, units) ⇒ void #set_value(dim) ⇒ void Also known as: value=
1971 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1971 def set_value(*args) end |
#set_value_mm(value) ⇒ void Also known as: value_mm=
This method returns an undefined value.
Sets the value of the dimension in mm.
1950 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1950 def set_value_mm(value) end |