Class: Wx::RTC::TextAttrDimensions
- Inherits:
-
Object
- Object
- Wx::RTC::TextAttrDimensions
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_object.rb
Overview
This class is untracked and should not be derived from nor instances extended!
A class for left, right, top and bottom dimensions.
Category: Rich Text
Instance Method Summary collapse
-
#==(dims) ⇒ Boolean
Equality operator.
-
#apply(dims, compareWith = nil) ⇒ Boolean
Apply to 'this', but not if the same as compareWith.
-
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
-
#eq_partial(dims, weakTest = true) ⇒ Boolean
Partial equality test.
-
#get_bottom ⇒ Wx::RTC::TextAttrDimension
(also: #bottom)
Gets the bottom dimension.
-
#get_left ⇒ Wx::RTC::TextAttrDimension
(also: #left)
Gets the left dimension.
-
#get_right ⇒ Wx::RTC::TextAttrDimension
(also: #right)
Gets the right dimension.
-
#get_top ⇒ Wx::RTC::TextAttrDimension
(also: #top)
Gets the top dimension.
-
#initialize ⇒ Wx::RTC::TextAttrDimensions
constructor
Default constructor.
-
#is_valid ⇒ Boolean
(also: #valid?)
Are all dimensions valid?.
-
#remove_style(attr) ⇒ Boolean
Remove specified attributes from this object.
-
#reset ⇒ void
Resets the value and flags for all dimensions.
Constructor Details
#initialize ⇒ Wx::RTC::TextAttrDimensions
Default constructor.
2035 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2035 def initialize; end |
Instance Method Details
#==(dims) ⇒ Boolean
Equality operator.
2044 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2044 def ==(dims) end |
#apply(dims, compareWith = nil) ⇒ Boolean
Apply to 'this', but not if the same as compareWith.
2058 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2058 def apply(dims, compareWith=nil) end |
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
This method returns an undefined value.
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
2065 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2065 def collect_common_attributes(attr, clashingAttr, absentAttr) end |
#eq_partial(dims, weakTest = true) ⇒ Boolean
Partial equality test.
If weakTest is true, attributes of this object do not have to be present if those attributes of dims are present. If weakTest is false, the function will fail if an attribute is present in dims but not in this object.
2052 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2052 def eq_partial(dims, weakTest=true) end |
#get_bottom ⇒ Wx::RTC::TextAttrDimension Also known as: bottom
Gets the bottom dimension.
2089 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2089 def get_bottom; end |
#get_left ⇒ Wx::RTC::TextAttrDimension Also known as: left
Gets the left dimension.
2074 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2074 def get_left; end |
#get_right ⇒ Wx::RTC::TextAttrDimension Also known as: right
Gets the right dimension.
2079 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2079 def get_right; end |
#get_top ⇒ Wx::RTC::TextAttrDimension Also known as: top
Gets the top dimension.
2084 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2084 def get_top; end |
#is_valid ⇒ Boolean Also known as: valid?
Are all dimensions valid?
2094 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2094 def is_valid; end |
#remove_style(attr) ⇒ Boolean
Remove specified attributes from this object.
2070 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2070 def remove_style(attr) end |
#reset ⇒ void
This method returns an undefined value.
Resets the value and flags for all dimensions.
2039 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2039 def reset; end |