Class: Wx::RTC::TextAttrShadow

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A class representing a shadow.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Constructor Details

#initializeWx::RTC::TextAttrShadow

Default constructor.



2113
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2113

def initialize; end

Instance Method Details

#==(shadow) ⇒ Boolean

Equality operator.

Parameters:

Returns:

  • (Boolean)


2118
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2118

def ==(shadow) end

#add_flag(flag) ⇒ void

This method returns an undefined value.

Adds a border flag.

Parameters:

  • flag (Integer)


2245
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2245

def add_flag(flag) end

#apply(shadow, compareWith = nil) ⇒ Boolean

Applies the border to this object, but not if the same as compareWith.

Parameters:

Returns:

  • (Boolean)


2136
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2136

def apply(shadow, compareWith=nil) end

#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void

This method returns an undefined value.

Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.

Parameters:



2148
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2148

def collect_common_attributes(attr, clashingAttr, absentAttr) end

#eq_partial(shadow, weakTest = true) ⇒ Boolean

Partial equality test.

If weakTest is true, attributes of this object do not have to be present if those attributes of border are present. If weakTest is false, the function will fail if an attribute is present in border but not in this object.

Parameters:

Returns:

  • (Boolean)


2130
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2130

def eq_partial(shadow, weakTest=true) end

#get_blur_distanceWx::RTC::TextAttrDimension Also known as: blur_distance



2207
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2207

def get_blur_distance; end

#get_colourWx::Colour Also known as: colour

Gets the colour.

Returns:



2168
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2168

def get_colour; end

#get_colour_longInteger Also known as: colour_long

Gets the colour as a long.

Returns:

  • (Integer)


2163
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2163

def get_colour_long; end

#get_flagsInteger Also known as: flags

Returns the border flags.

Returns:

  • (Integer)


2233
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2233

def get_flags; end

#get_offset_xWx::RTC::TextAttrDimension Also known as: offset_x



2177
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2177

def get_offset_x; end

#get_offset_yWx::RTC::TextAttrDimension Also known as: offset_y



2187
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2187

def get_offset_y; end

#get_opacityWx::RTC::TextAttrDimension Also known as: opacity



2217
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2217

def get_opacity; end

#get_spreadWx::RTC::TextAttrDimension Also known as: spread



2197
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2197

def get_spread; end

#has_colourBoolean Also known as: has_colour?

True if the shadow has a valid colour.

Returns:

  • (Boolean)


2173
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2173

def has_colour; end

#is_defaultBoolean Also known as: default?

True if the shadow has no attributes set.

Returns:

  • (Boolean)


2260
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2260

def is_default; end

#is_validBoolean Also known as: valid?

Returns true if the dimension is valid.

Returns:

  • (Boolean)


2222
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2222

def is_valid; end

#remove_flag(flag) ⇒ void

This method returns an undefined value.

Removes a border flag.

Parameters:

  • flag (Integer)


2250
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2250

def remove_flag(flag) end

#remove_style(attr) ⇒ Boolean

Removes the specified attributes from this object.

Parameters:

Returns:

  • (Boolean)


2141
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2141

def remove_style(attr) end

#resetvoid

This method returns an undefined value.

Resets the shadow.



2122
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2122

def reset; end

#set_blur_distance(blur) ⇒ void Also known as: blur_distance=

This method returns an undefined value.

Sets the shadow blur distance.

Parameters:



2213
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2213

def set_blur_distance(blur) end

#set_colour(colour) ⇒ void #set_colour(colour) ⇒ void Also known as: colour=

Overloads:

  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets the shadow colour.

    Parameters:

    • colour (Integer)
  • #set_colour(colour) ⇒ void

    This method returns an undefined value.

    Sets the shadow colour.

    Parameters:



2158
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2158

def set_colour(*args) end

#set_flags(flags) ⇒ void Also known as: flags=

This method returns an undefined value.

Sets the border flags.

Parameters:

  • flags (Integer)


2239
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2239

def set_flags(flags) end

#set_offset_x(offset) ⇒ void Also known as: offset_x=

This method returns an undefined value.

Sets the shadow horizontal offset.

Parameters:



2183
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2183

def set_offset_x(offset) end

#set_offset_y(offset) ⇒ void Also known as: offset_y=

This method returns an undefined value.

Sets the shadow vertical offset.

Parameters:



2193
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2193

def set_offset_y(offset) end

#set_opacity(opacity) ⇒ void Also known as: opacity=

This method returns an undefined value.

Sets the shadow opacity.

Parameters:



2255
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2255

def set_opacity(opacity) end

#set_spread(spread) ⇒ void Also known as: spread=

This method returns an undefined value.

Sets the shadow spread size.

Parameters:



2203
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2203

def set_spread(spread) end

#set_valid(b) ⇒ void Also known as: valid=

This method returns an undefined value.

Sets the valid flag.

Parameters:

  • b (Boolean)


2228
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2228

def set_valid(b) end