Class: Wx::RTC::TextBoxAttr

Inherits:
Object
  • Object
show all
Defined in:
lib/wx/doc/gen/rtc/rich_text_object.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A class representing the box attributes of a rich text object.

Category: Rich Text

See Also:

Requires:

  • USE_RICHTEXT

Instance Method Summary collapse

Constructor Details

#initializeWx::RTC::TextBoxAttr #initialize(attr) ⇒ Wx::RTC::TextBoxAttr

Returns a new instance of TextBoxAttr.

Overloads:



1544
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1544

def initialize(*args) end

Instance Method Details

#==(attr) ⇒ Boolean

Equality test.

Parameters:

Returns:

  • (Boolean)


1557
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1557

def ==(attr) end

#add_flag(flag) ⇒ void

This method returns an undefined value.

Adds this flag.

Parameters:

  • flag (Wx::TextBoxAttrFlags)


1612
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1612

def add_flag(flag) end

#apply(style, compareWith = nil) ⇒ Boolean

Merges the given attributes.

If compareWith is non-null, then it will be used to mask out those attributes that are the same in style and compareWith, for situations where we don't want to explicitly set inherited attributes.

Parameters:

Returns:

  • (Boolean)


1573
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1573

def apply(style, compareWith=nil) end

#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void

This method returns an undefined value.

Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.

Parameters:



1580
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1580

def collect_common_attributes(attr, clashingAttr, absentAttr) end

#eq_partial(attr, weakTest = true) ⇒ Boolean

Partial equality test, ignoring unset attributes.

If weakTest is true, attributes of this object do not have to be present if those attributes of attr are present. If weakTest is false, the function will fail if an attribute is present in attr but not in this object.

Parameters:

Returns:

  • (Boolean)


1565
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1565

def eq_partial(attr, weakTest=true) end

#get_borderWx::RTC::TextAttrBorders Also known as: border



1785
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1785

def get_border; end

#get_bottomWx::RTC::TextAttrDimension Also known as: bottom



1761
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1761

def get_bottom; end

#get_bottom_borderWx::RTC::TextAttrBorder Also known as: bottom_border



1801
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1801

def get_bottom_border; end

#get_bottom_marginWx::RTC::TextAttrDimension Also known as: bottom_margin



1741
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1741

def get_bottom_margin; end

#get_bottom_outlineWx::RTC::TextAttrBorder Also known as: bottom_outline



1821
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1821

def get_bottom_outline; end

#get_bottom_paddingWx::RTC::TextAttrDimension Also known as: bottom_padding



1781
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1781

def get_bottom_padding; end

#get_box_style_nameWx::String Also known as: box_style_name

Returns the box style name.

Returns:

  • (Wx::String)


1864
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1864

def get_box_style_name; end

#get_clear_modeWx::TextBoxAttrClearStyle Also known as: clear_mode

Returns the clear mode - whether to wrap text after object.

Currently unimplemented.

Returns:

  • (Wx::TextBoxAttrClearStyle)


1644
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1644

def get_clear_mode; end

#get_collapse_bordersWx::TextBoxAttrCollapseMode Also known as: collapse_borders

Returns the collapse mode - whether to collapse borders.

Returns:

  • (Wx::TextBoxAttrCollapseMode)


1662
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1662

def get_collapse_borders; end

#get_corner_radiusWx::RTC::TextAttrDimension Also known as: corner_radius

Returns the corner radius value.



1699
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1699

def get_corner_radius; end

#get_flagsInteger Also known as: flags

Returns the flags.

Returns:

  • (Integer)


1595
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1595

def get_flags; end

#get_float_modeWx::TextBoxAttrFloatStyle Also known as: float_mode

Returns the float mode.

Returns:

  • (Wx::TextBoxAttrFloatStyle)


1621
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1621

def get_float_mode; end

#get_heightWx::RTC::TextAttrDimension Also known as: height



1859
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1859

def get_height; end

#get_leftWx::RTC::TextAttrDimension Also known as: left



1749
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1749

def get_left; end

#get_left_borderWx::RTC::TextAttrBorder Also known as: left_border



1789
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1789

def get_left_border; end

#get_left_marginWx::RTC::TextAttrDimension Also known as: left_margin



1729
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1729

def get_left_margin; end

#get_left_outlineWx::RTC::TextAttrBorder Also known as: left_outline



1809
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1809

def get_left_outline; end

#get_left_paddingWx::RTC::TextAttrDimension Also known as: left_padding



1769
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1769

def get_left_padding; end

#get_marginsWx::RTC::TextAttrDimensions Also known as: margins



1725
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1725

def get_margins; end

#get_max_sizeWx::RTC::TextAttrSize Also known as: max_size



1833
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1833

def get_max_size; end

#get_min_sizeWx::RTC::TextAttrSize Also known as: min_size



1829
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1829

def get_min_size; end

#get_outlineWx::RTC::TextAttrBorders Also known as: outline



1805
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1805

def get_outline; end

#get_paddingWx::RTC::TextAttrDimensions Also known as: padding



1765
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1765

def get_padding; end

#get_positionWx::RTC::TextAttrDimensions Also known as: position



1745
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1745

def get_position; end

#get_rightWx::RTC::TextAttrDimension Also known as: right



1753
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1753

def get_right; end

#get_right_borderWx::RTC::TextAttrBorder Also known as: right_border



1797
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1797

def get_right_border; end

#get_right_marginWx::RTC::TextAttrDimension Also known as: right_margin



1733
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1733

def get_right_margin; end

#get_right_outlineWx::RTC::TextAttrBorder Also known as: right_outline



1817
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1817

def get_right_outline; end

#get_right_paddingWx::RTC::TextAttrDimension Also known as: right_padding



1773
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1773

def get_right_padding; end

#get_shadowWx::RTC::TextAttrShadow Also known as: shadow



1879
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1879

def get_shadow; end

#get_sizeWx::RTC::TextAttrSize Also known as: size



1825
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1825

def get_size; end

#get_topWx::RTC::TextAttrDimension Also known as: top



1757
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1757

def get_top; end

#get_top_borderWx::RTC::TextAttrBorder Also known as: top_border



1793
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1793

def get_top_border; end

#get_top_marginWx::RTC::TextAttrDimension Also known as: top_margin



1737
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1737

def get_top_margin; end

#get_top_outlineWx::RTC::TextAttrBorder Also known as: top_outline



1813
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1813

def get_top_outline; end

#get_top_paddingWx::RTC::TextAttrDimension Also known as: top_padding



1777
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1777

def get_top_padding; end

#get_vertical_alignmentWx::TextBoxAttrVerticalAlignment Also known as: vertical_alignment

Returns the vertical alignment.

Returns:

  • (Wx::TextBoxAttrVerticalAlignment)


1710
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1710

def get_vertical_alignment; end

#get_whitespace_modeWx::TextBoxAttrWhitespaceMode Also known as: whitespace_mode

Returns the whitespace mode.

Returns:

  • (Wx::TextBoxAttrWhitespaceMode)


1678
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1678

def get_whitespace_mode; end

#get_widthWx::RTC::TextAttrDimension Also known as: width



1855
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1855

def get_width; end

#has_box_style_nameBoolean Also known as: has_box_style_name?

Returns true if the box style name is present.

Returns:

  • (Boolean)


1875
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1875

def has_box_style_name; end

#has_clear_modeBoolean Also known as: has_clear_mode?

Returns true if we have a clear flag.

Returns:

  • (Boolean)


1657
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1657

def has_clear_mode; end

#has_collapse_bordersBoolean Also known as: has_collapse_borders?

Returns true if the collapse borders flag is present.

Returns:

  • (Boolean)


1673
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1673

def has_collapse_borders; end

#has_corner_radiusBoolean Also known as: has_corner_radius?

Returns true if the corner radius flag is present.

Returns:

  • (Boolean)


1694
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1694

def has_corner_radius; end

#has_flag(flag) ⇒ Boolean Also known as: has_flag?

Is this flag present?

Parameters:

  • flag (Wx::TextBoxAttrFlags)

Returns:

  • (Boolean)


1601
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1601

def has_flag(flag) end

#has_float_modeBoolean Also known as: has_float_mode?

Returns true if float mode is active.

Returns:

  • (Boolean)


1632
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1632

def has_float_mode; end

#has_vertical_alignmentBoolean Also known as: has_vertical_alignment?

Returns true if a vertical alignment flag is present.

Returns:

  • (Boolean)


1721
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1721

def has_vertical_alignment; end

#has_whitespace_modeBoolean Also known as: has_whitespace_mode?

Returns true if the whitespace flag is present.

Returns:

  • (Boolean)


1689
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1689

def has_whitespace_mode; end

#initvoid

This method returns an undefined value.

Initialises this object.



1548
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1548

def init; end

#is_defaultBoolean Also known as: default?

Returns true if no attributes are set.

Returns:

  • (Boolean)


1616
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1616

def is_default; end

#is_floatingBoolean Also known as: floating?

Returns true if this object is floating.

Returns:

  • (Boolean)


1637
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1637

def is_floating; end

#remove_flag(flag) ⇒ void

This method returns an undefined value.

Removes this flag.

Parameters:

  • flag (Wx::TextBoxAttrFlags)


1607
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1607

def remove_flag(flag) end

#remove_style(attr) ⇒ Boolean

Removes the specified attributes from this object.

Parameters:

Returns:

  • (Boolean)


1585
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1585

def remove_style(attr) end

#resetvoid

This method returns an undefined value.

Resets this object.



1552
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1552

def reset; end

#set_box_style_name(name) ⇒ void Also known as: box_style_name=

This method returns an undefined value.

Sets the box style name.

Parameters:

  • name (String)


1870
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1870

def set_box_style_name(name) end

#set_clear_mode(mode) ⇒ void Also known as: clear_mode=

This method returns an undefined value.

Set the clear mode.

Currently unimplemented.

Parameters:

  • mode (Wx::TextBoxAttrClearStyle)


1652
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1652

def set_clear_mode(mode) end

#set_collapse_borders(collapse) ⇒ void Also known as: collapse_borders=

This method returns an undefined value.

Sets the collapse mode - whether to collapse borders.

Parameters:

  • collapse (Wx::TextBoxAttrCollapseMode)


1668
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1668

def set_collapse_borders(collapse) end

#set_corner_radius(dim) ⇒ void Also known as: corner_radius=

This method returns an undefined value.

Sets the corner radius value.

Parameters:



1705
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1705

def set_corner_radius(dim) end

#set_flags(flags) ⇒ void Also known as: flags=

This method returns an undefined value.

Sets the flags.

Parameters:

  • flags (Integer)


1590
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1590

def set_flags(flags) end

#set_float_mode(mode) ⇒ void Also known as: float_mode=

This method returns an undefined value.

Sets the float mode.

Parameters:

  • mode (Wx::TextBoxAttrFloatStyle)


1627
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1627

def set_float_mode(mode) end

#set_max_size(sz) ⇒ void Also known as: max_size=

This method returns an undefined value.

Sets the object maximum size.

Parameters:



1851
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1851

def set_max_size(sz) end

#set_min_size(sz) ⇒ void Also known as: min_size=

This method returns an undefined value.

Sets the object minimum size.

Parameters:



1845
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1845

def set_min_size(sz) end

#set_size(sz) ⇒ void Also known as: size=

This method returns an undefined value.

Sets the object size.

Parameters:



1839
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1839

def set_size(sz) end

#set_vertical_alignment(verticalAlignment) ⇒ void Also known as: vertical_alignment=

This method returns an undefined value.

Sets the vertical alignment.

Parameters:

  • verticalAlignment (Wx::TextBoxAttrVerticalAlignment)


1716
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1716

def set_vertical_alignment(verticalAlignment) end

#set_whitespace_mode(whitespace) ⇒ void Also known as: whitespace_mode=

This method returns an undefined value.

Sets the whitespace mode.

Parameters:

  • whitespace (Wx::TextBoxAttrWhitespaceMode)


1684
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1684

def set_whitespace_mode(whitespace) end