Class: Wx::Slider

Inherits:
Control show all
Defined in:
lib/wx/doc/gen/slider.rb

Overview

A slider is a control with a handle which can be pulled back and forth to change the value.

On Windows, the track bar control is used. On GTK+, tick marks are only available for version 2.16 and later. Slider generates the same events as ScrollBar but in practice the most convenient way to process Slider updates is by handling the slider-specific EVT_SLIDER event which carries CommandEvent containing just the latest slider position.

Styles

This class supports the following styles:

  • SL_HORIZONTAL: Displays the slider horizontally (this is the default).

  • SL_VERTICAL: Displays the slider vertically.

  • SL_AUTOTICKS: Displays tick marks (Windows, GTK+ 2.16 and later).

  • SL_MIN_MAX_LABELS: Displays minimum, maximum labels (new since wxWidgets 2.9.1).

  • SL_VALUE_LABEL: Displays value label (new since wxWidgets 2.9.1).

  • SL_LABELS: Displays minimum, maximum and value labels (same as SL_VALUE_LABEL and SL_MIN_MAX_LABELS together).

  • SL_LEFT: Displays ticks on the left and forces the slider to be vertical (Windows and GTK+ 3 only).

  • SL_RIGHT: Displays ticks on the right and forces the slider to be vertical.

  • SL_TOP: Displays ticks on the top (Windows and GTK+ 3 only).

  • SL_BOTTOM: Displays ticks on the bottom (this is the default).

  • SL_BOTH: Displays ticks on both sides of the slider. Windows only.

  • SL_SELRANGE: Displays a highlighted selection range. Windows only.

  • SL_INVERSE: Inverses the minimum and maximum endpoints on the slider. Not compatible with SL_SELRANGE.

Notice that SL_LEFT, SL_TOP, SL_RIGHT and SL_BOTTOM specify the position of the slider ticks and that the slider labels, if any, are positioned on the opposite side. So, to have a label on the left side of a vertical slider, SL_RIGHT must be used (or none of these styles at all should be specified as left and top are default positions for the vertical and horizontal sliders respectively).

Events emitted by this class

The following event-handler methods redirect the events to member method or handler blocks for ScrollEvent events. Event handler methods for events emitted by this class: except for this, the macros behave exactly the same.

The difference between EVT_SCROLL_THUMBRELEASE and EVT_SCROLL_CHANGED

The EVT_SCROLL_THUMBRELEASE event is only emitted when actually dragging the thumb using the mouse and releasing it (This EVT_SCROLL_THUMBRELEASE event is also followed by an EVT_SCROLL_CHANGED event). The EVT_SCROLL_CHANGED event also occurs when using the keyboard to change the thumb position, and when clicking next to the thumb (In all these cases the EVT_SCROLL_THUMBRELEASE event does not happen). In short, the EVT_SCROLL_CHANGED event is triggered when scrolling/ moving has finished independently of the way it had started. Please see the page_samples_widgets ("Slider" page) to see the difference between EVT_SCROLL_THUMBRELEASE and EVT_SCROLL_CHANGED in action.

Category: Controls

Appearance:
WXMSW Appearance WXGTK Appearance WXOSX Appearance

See Also:

Requires:

  • USE_SLIDER

Instance Method Summary collapse

Methods inherited from Control

#command, ellipsize, escape_mnemonics, #get_label, #get_label_text, #get_size_from_text, #get_size_from_text_size, remove_mnemonics, #set_label, #set_label_markup, #set_label_text

Methods inherited from Window

#accepts_focus, #accepts_focus_from_keyboard, #accepts_focus_recursively, #add_child, #adjust_for_layout_direction, #always_show_scrollbars, #begin_repositioning_children, #cache_best_size, #can_accept_focus, #can_accept_focus_from_keyboard, #can_scroll, #can_set_transparent, #capture_mouse, #center, #center_on_parent, #centre, #centre_on_parent, #clear_background, #client_to_screen, #client_to_window_size, #close, #convert_dialog_to_pixels, #convert_pixels_to_dialog, #destroy, #destroy_children, #disable, #disable_focus_from_keyboard, #do_prepare_update_window_ui, #do_update_window_ui, #drag_accept_files, #each_child, #enable, #enable_touch_events, #enable_visible_focus, #end_repositioning_children, find_focus, #find_window_by_id, find_window_by_id, #find_window_by_label, find_window_by_label, #find_window_by_name, find_window_by_name, #fit, #fit_inside, #freeze, #from_dip, from_dip, #from_phys, from_phys, #get_accelerator_table, #get_auto_layout, #get_background_colour, #get_background_style, #get_best_height, #get_best_size, #get_best_virtual_size, #get_best_width, #get_border, get_capture, #get_caret, #get_char_height, #get_char_width, #get_children, get_class_default_attributes, #get_client_area_origin, #get_client_rect, #get_client_size, #get_containing_sizer, #get_content_scale_factor, #get_cursor, #get_cursor_bundle, #get_default_attributes, #get_dpi, #get_dpi_scale_factor, #get_drop_target, #get_effective_min_size, #get_event_handler, #get_extra_style, #get_font, #get_foreground_colour, #get_grand_parent, #get_help_id_at_point, #get_help_text, #get_help_text_at_point, #get_id, #get_label, #get_layout_direction, #get_max_client_size, #get_max_height, #get_max_size, #get_max_width, #get_min_client_size, #get_min_height, #get_min_size, #get_min_size_from_known_direction, #get_min_width, #get_name, #get_next_sibling, #get_parent, #get_popup_menu_selection_from_user, #get_position, #get_prev_sibling, #get_rect, #get_screen_position, #get_screen_rect, #get_scroll_pos, #get_scroll_range, #get_scroll_thumb, #get_size, #get_sizer, #get_text_extent, #get_theme_enabled, #get_tool_tip, #get_tool_tip_text, #get_update_client_rect, #get_update_region, #get_validator, #get_virtual_size, #get_window_border_size, #get_window_style, #get_window_style_flag, #get_window_variant, #handle_as_navigation_key, #handle_window_event, #has_capture, #has_extra_style, #has_flag, #has_focus, #has_multiple_pages, #has_scrollbar, #has_transparent_background, #hide, #hide_with_effect, #hit_test, #inform_first_direction, #inherit_attributes, #inherits_background_colour, #inherits_foreground_colour, #init_dialog, #invalidate_best_size, #is_being_deleted, #is_descendant, #is_double_buffered, #is_enabled, #is_exposed, #is_focusable, #is_frozen, #is_retained, #is_scrollbar_always_shown, #is_shown, #is_shown_on_screen, #is_this_enabled, #is_top_level, #is_transparent_background_supported, #layout, #line_down, #line_up, #locked, #lower_window, #move, #move_after_in_tab_order, #move_before_in_tab_order, #navigate, #navigate_in, new_control_id, #on_internal_idle, #page_down, #page_up, #paint, #paint_buffered, #pop_event_handler, #popup_menu, #post_size_event, #post_size_event_to_parent, #process_window_event, #process_window_event_locally, #push_event_handler, #raise_window, #refresh, #refresh_rect, #release_mouse, #remove_child, #remove_event_handler, #reparent, #screen_to_client, #scroll_lines, #scroll_pages, #scroll_window, #send_size_event, #send_size_event_to_parent, #set_accelerator_table, #set_auto_layout, #set_background_colour, #set_background_style, #set_can_focus, #set_caret, #set_client_size, #set_containing_sizer, #set_cursor, #set_cursor_bundle, #set_double_buffered, #set_drop_target, #set_event_handler, #set_extra_style, #set_focus, #set_focus_from_kbd, #set_font, #set_foreground_colour, #set_help_text, #set_id, #set_initial_size, #set_label, #set_layout_direction, #set_max_client_size, #set_max_size, #set_min_client_size, #set_min_size, #set_name, #set_next_handler, #set_own_background_colour, #set_own_font, #set_own_foreground_colour, #set_position, #set_previous_handler, #set_scroll_pos, #set_scrollbar, #set_size, #set_size_hints, #set_sizer, #set_sizer_and_fit, #set_theme_enabled, #set_tool_tip, #set_transparent, #set_validator, #set_virtual_size, #set_window_style, #set_window_style_flag, #set_window_variant, #should_inherit_colours, #show, #show_with_effect, #switch_sizer, #thaw, #to_dip, to_dip, #to_phys, to_phys, #toggle_window_style, #transfer_data_from_window, #transfer_data_to_window, unreserve_control_id, #unset_tool_tip, #update, #update_window_ui, #use_background_colour, #use_bg_col, #use_foreground_colour, #validate, #warp_pointer, #window_to_client_size

Methods inherited from EvtHandler

add_filter, #add_pending_event, #call_after, clear_filters, #connect, #delete_pending_events, #disconnect, #evt_activate, #evt_activate_app, #evt_aui_pane_activated, #evt_aui_pane_button, #evt_aui_pane_close, #evt_aui_pane_maximize, #evt_aui_pane_minimize, #evt_aui_pane_restore, #evt_aui_render, #evt_auinotebook_allow_dnd, #evt_auinotebook_begin_drag, #evt_auinotebook_bg_dclick, #evt_auinotebook_button, #evt_auinotebook_drag_done, #evt_auinotebook_drag_motion, #evt_auinotebook_end_drag, #evt_auinotebook_page_changed, #evt_auinotebook_page_changing, #evt_auinotebook_page_close, #evt_auinotebook_page_closed, #evt_auinotebook_tab_middle_down, #evt_auinotebook_tab_middle_up, #evt_auinotebook_tab_right_down, #evt_auinotebook_tab_right_up, #evt_auitoolbar_begin_drag, #evt_auitoolbar_middle_click, #evt_auitoolbar_overflow_click, #evt_auitoolbar_right_click, #evt_auitoolbar_tool_dropdown, #evt_button, #evt_calculate_layout, #evt_calendar, #evt_calendar_page_changed, #evt_calendar_sel_changed, #evt_calendar_week_clicked, #evt_calendar_weekday_clicked, #evt_char, #evt_char_hook, #evt_checkbox, #evt_checklistbox, #evt_child_focus, #evt_choice, #evt_choicebook_page_changed, #evt_choicebook_page_changing, #evt_close, #evt_collapsiblepane_changed, #evt_colourpicker_changed, #evt_colourpicker_current_changed, #evt_colourpicker_dialog_cancelled, #evt_combobox, #evt_combobox_closeup, #evt_combobox_dropdown, #evt_command, #evt_command_enter, #evt_command_kill_focus, #evt_command_left_click, #evt_command_left_dclick, #evt_command_range, #evt_command_right_click, #evt_command_scroll, #evt_command_scroll_bottom, #evt_command_scroll_changed, #evt_command_scroll_linedown, #evt_command_scroll_lineup, #evt_command_scroll_pagedown, #evt_command_scroll_pageup, #evt_command_scroll_thumbrelease, #evt_command_scroll_thumbtrack, #evt_command_scroll_top, #evt_command_set_focus, #evt_context_menu, #evt_date_changed, #evt_dialup_connected, #evt_dialup_disconnected, #evt_dirctrl_fileactivated, #evt_dirctrl_selectionchanged, #evt_dirpicker_changed, #evt_dpi_changed, #evt_drop_files, #evt_end_session, #evt_enter_window, #evt_erase_background, #evt_filectrl_fileactivated, #evt_filectrl_filterchanged, #evt_filectrl_folderchanged, #evt_filectrl_selectionchanged, #evt_filepicker_changed, #evt_find, #evt_find_close, #evt_find_next, #evt_find_replace, #evt_find_replace_all, #evt_fontpicker_changed, #evt_fullscreen, #evt_gesture_pan, #evt_gesture_rotate, #evt_gesture_zoom, #evt_grid_cell_changed, #evt_grid_cell_changing, #evt_grid_cell_left_click, #evt_grid_cell_left_dclick, #evt_grid_cell_right_click, #evt_grid_cell_right_dclick, #evt_grid_cmd_col_size, #evt_grid_cmd_editor_created, #evt_grid_cmd_range_selected, #evt_grid_cmd_range_selecting, #evt_grid_cmd_row_size, #evt_grid_col_auto_size, #evt_grid_col_label_size, #evt_grid_col_move, #evt_grid_col_size, #evt_grid_col_sort, #evt_grid_editor_created, #evt_grid_editor_hidden, #evt_grid_editor_shown, #evt_grid_label_left_click, #evt_grid_label_left_dclick, #evt_grid_label_right_click, #evt_grid_label_right_dclick, #evt_grid_range_selected, #evt_grid_range_selecting, #evt_grid_row_auto_size, #evt_grid_row_label_size, #evt_grid_row_move, #evt_grid_row_size, #evt_grid_select_cell, #evt_grid_tabbing, #evt_header_begin_reorder, #evt_header_begin_resize, #evt_header_click, #evt_header_dclick, #evt_header_dragging_cancelled, #evt_header_end_reorder, #evt_header_end_resize, #evt_header_middle_click, #evt_header_middle_dclick, #evt_header_resizing, #evt_header_right_click, #evt_header_right_dclick, #evt_header_separator_dclick, #evt_help, #evt_help_range, #evt_hibernate, #evt_hotkey, #evt_html_cell_clicked, #evt_html_cell_hover, #evt_html_link_clicked, #evt_hyperlink, #evt_iconize, #evt_idle, #evt_init_dialog, #evt_joy_button_down, #evt_joy_button_up, #evt_joy_move, #evt_joy_zmove, #evt_joystick_events, #evt_key_down, #evt_key_up, #evt_kill_focus, #evt_leave_window, #evt_left_dclick, #evt_left_down, #evt_left_up, #evt_list_begin_drag, #evt_list_begin_label_edit, #evt_list_begin_rdrag, #evt_list_cache_hint, #evt_list_col_begin_drag, #evt_list_col_click, #evt_list_col_dragging, #evt_list_col_end_drag, #evt_list_col_right_click, #evt_list_delete_all_items, #evt_list_delete_item, #evt_list_end_label_edit, #evt_list_insert_item, #evt_list_item_activated, #evt_list_item_checked, #evt_list_item_deselected, #evt_list_item_focused, #evt_list_item_middle_click, #evt_list_item_right_click, #evt_list_item_selected, #evt_list_item_unchecked, #evt_list_key_down, #evt_listbook_page_changed, #evt_listbook_page_changing, #evt_listbox, #evt_listbox_dclick, #evt_long_press, #evt_magnify, #evt_maximize, #evt_media_finished, #evt_media_loaded, #evt_media_pause, #evt_media_play, #evt_media_statechanged, #evt_media_stop, #evt_menu, #evt_menu_close, #evt_menu_highlight, #evt_menu_highlight_all, #evt_menu_open, #evt_menu_range, #evt_middle_dclick, #evt_middle_down, #evt_middle_up, #evt_motion, #evt_mouse_aux1_dclick, #evt_mouse_aux1_down, #evt_mouse_aux1_up, #evt_mouse_aux2_dclick, #evt_mouse_aux2_down, #evt_mouse_aux2_up, #evt_mouse_events, #evt_mousewheel, #evt_move, #evt_move_end, #evt_move_start, #evt_moving, #evt_navigation_key, #evt_notebook_page_changed, #evt_notebook_page_changing, #evt_paint, #evt_pg_changed, #evt_pg_changing, #evt_pg_col_begin_drag, #evt_pg_col_dragging, #evt_pg_col_end_drag, #evt_pg_double_click, #evt_pg_highlighted, #evt_pg_item_collapsed, #evt_pg_item_expanded, #evt_pg_label_edit_begin, #evt_pg_label_edit_ending, #evt_pg_page_changed, #evt_pg_right_click, #evt_pg_selected, #evt_press_and_tap, #evt_query_end_session, #evt_query_layout_info, #evt_radiobox, #evt_radiobutton, #evt_ribbonbar_help_click, #evt_ribbonbar_page_changed, #evt_ribbonbar_page_changing, #evt_ribbonbar_tab_left_dclick, #evt_ribbonbar_tab_middle_down, #evt_ribbonbar_tab_middle_up, #evt_ribbonbar_tab_right_down, #evt_ribbonbar_tab_right_up, #evt_ribbonbar_toggled, #evt_ribbonbuttonbar_clicked, #evt_ribbonbuttonbar_dropdown_clicked, #evt_ribbongallery_clicked, #evt_ribbongallery_hover_changed, #evt_ribbongallery_selected, #evt_ribbonpanel_extbutton_activated, #evt_ribbontoolbar_clicked, #evt_ribbontoolbar_dropdown_clicked, #evt_richtext_buffer_reset, #evt_richtext_character, #evt_richtext_consuming_character, #evt_richtext_content_deleted, #evt_richtext_content_inserted, #evt_richtext_delete, #evt_richtext_focus_object_changed, #evt_richtext_left_click, #evt_richtext_left_dclick, #evt_richtext_middle_click, #evt_richtext_properties_changed, #evt_richtext_return, #evt_richtext_right_click, #evt_richtext_selection_changed, #evt_richtext_style_changed, #evt_richtext_stylesheet_changed, #evt_richtext_stylesheet_replaced, #evt_richtext_stylesheet_replacing, #evt_right_dclick, #evt_right_down, #evt_right_up, #evt_sash_dragged, #evt_sash_dragged_range, #evt_scroll, #evt_scroll_bottom, #evt_scroll_changed, #evt_scroll_linedown, #evt_scroll_lineup, #evt_scroll_pagedown, #evt_scroll_pageup, #evt_scroll_thumbrelease, #evt_scroll_thumbtrack, #evt_scroll_top, #evt_scrollbar, #evt_scrollwin, #evt_scrollwin_bottom, #evt_scrollwin_linedown, #evt_scrollwin_lineup, #evt_scrollwin_pagedown, #evt_scrollwin_pageup, #evt_scrollwin_thumbrelease, #evt_scrollwin_thumbtrack, #evt_scrollwin_top, #evt_search, #evt_search_cancel, #evt_set_cursor, #evt_set_focus, #evt_show, #evt_size, #evt_slider, #evt_spin, #evt_spin_down, #evt_spin_up, #evt_spinctrl, #evt_spinctrldouble, #evt_splitter_dclick, #evt_splitter_sash_pos_changed, #evt_splitter_sash_pos_changing, #evt_splitter_sash_pos_resize, #evt_splitter_unsplit, #evt_stc_autocomp_cancelled, #evt_stc_autocomp_char_deleted, #evt_stc_autocomp_completed, #evt_stc_autocomp_selection, #evt_stc_autocomp_selection_change, #evt_stc_calltip_click, #evt_stc_change, #evt_stc_charadded, #evt_stc_clipboard_copy, #evt_stc_clipboard_paste, #evt_stc_do_drop, #evt_stc_doubleclick, #evt_stc_drag_over, #evt_stc_dwellend, #evt_stc_dwellstart, #evt_stc_hotspot_click, #evt_stc_hotspot_dclick, #evt_stc_hotspot_release_click, #evt_stc_indicator_click, #evt_stc_indicator_release, #evt_stc_macrorecord, #evt_stc_margin_right_click, #evt_stc_marginclick, #evt_stc_modified, #evt_stc_needshown, #evt_stc_painted, #evt_stc_romodifyattempt, #evt_stc_savepointleft, #evt_stc_savepointreached, #evt_stc_start_drag, #evt_stc_styleneeded, #evt_stc_updateui, #evt_stc_userlistselection, #evt_stc_zoom, #evt_sys_colour_changed, #evt_taskbar_click, #evt_taskbar_left_dclick, #evt_taskbar_left_down, #evt_taskbar_left_up, #evt_taskbar_move, #evt_taskbar_right_dclick, #evt_taskbar_right_down, #evt_taskbar_right_up, #evt_text, #evt_text_copy, #evt_text_cut, #evt_text_enter, #evt_text_maxlen, #evt_text_paste, #evt_text_url, #evt_time_changed, #evt_timer, #evt_togglebutton, #evt_tool, #evt_tool_dropdown, #evt_tool_enter, #evt_tool_range, #evt_tool_rclicked, #evt_tool_rclicked_range, #evt_toolbook_page_changed, #evt_toolbook_page_changing, #evt_tree_begin_drag, #evt_tree_begin_label_edit, #evt_tree_begin_rdrag, #evt_tree_delete_item, #evt_tree_end_drag, #evt_tree_end_label_edit, #evt_tree_get_info, #evt_tree_item_activated, #evt_tree_item_collapsed, #evt_tree_item_collapsing, #evt_tree_item_expanded, #evt_tree_item_expanding, #evt_tree_item_gettooltip, #evt_tree_item_menu, #evt_tree_item_middle_click, #evt_tree_item_right_click, #evt_tree_key_down, #evt_tree_sel_changed, #evt_tree_sel_changing, #evt_tree_set_info, #evt_tree_state_image_click, #evt_treebook_node_collapsed, #evt_treebook_node_expanded, #evt_treebook_page_changed, #evt_treebook_page_changing, #evt_two_finger_tap, #evt_update_ui, #evt_update_ui_range, #evt_webview_browsing_data_cleared, #evt_webview_created, #evt_webview_error, #evt_webview_fullscreen_changed, #evt_webview_loaded, #evt_webview_navigated, #evt_webview_navigating, #evt_webview_newwindow, #evt_webview_newwindow_features, #evt_webview_script_message_received, #evt_webview_script_result, #evt_webview_title_changed, #evt_webview_window_close_requested, #evt_window_create, #evt_window_destroy, #evt_wizard_before_page_changed, #evt_wizard_cancel, #evt_wizard_finished, #evt_wizard_help, #evt_wizard_page_changed, #evt_wizard_page_changing, #evt_wizard_page_shown, #get_client_object, #get_evt_handler_enabled, #get_next_handler, #get_previous_handler, #is_unlinked, #make_shared, #process_event, #process_event_locally, #process_pending_events, #queue_event, register_class, remove_filter, #safely_process_event, #set_client_object, #set_evt_handler_enabled, #set_next_handler, #try_after, #try_before, #unlink

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initializeWx::Slider #initialize(parent, id, value, minValue, maxValue, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = Wx::SL_HORIZONTAL, validator = Wx::DEFAULT_VALIDATOR, name = Wx::SLIDER_NAME_STR) ⇒ Wx::Slider #initialize(parent, id, value, minValue, maxValue, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = Wx::SL_HORIZONTAL, validator = Wx::DEFAULT_VALIDATOR, name = Wx::SLIDER_NAME_STR) {|win| ... } ⇒ Wx::Slider

Returns a new instance of Slider.

Overloads:

  • #initializeWx::Slider

    Default constructor.

  • #initialize(parent, id, value, minValue, maxValue, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = Wx::SL_HORIZONTAL, validator = Wx::DEFAULT_VALIDATOR, name = Wx::SLIDER_NAME_STR) ⇒ Wx::Slider

    Constructor, creating and showing a slider.

    Parameters:

    • parent (Wx::Window)

      Parent window. Must not be nil.

    • id (Integer)

      Window identifier. The value Wx::StandardID::ID_ANY indicates a default value.

    • value (Integer)

      Initial position for the slider.

    • minValue (Integer)

      Minimum slider position.

    • maxValue (Integer)

      Maximum slider position.

    • pos (Array(Integer, Integer), Wx::Point) (defaults to: Wx::DEFAULT_POSITION)

      Window position. If DEFAULT_POSITION is specified then a default position is chosen.

    • size (Array(Integer, Integer), Wx::Size) (defaults to: Wx::DEFAULT_SIZE)

      Window size. If DEFAULT_SIZE is specified then a default size is chosen, which is typically appropriate in the transverse slider direction, but is just fixed 100 (DPI-independent) pixels in the primary direction (i.e. vertical for Wx::SL_VERTICAL sliders or horizontal for Wx::SL_HORIZONTAL ones), so it may be preferable to specify it explicitly. Conversely, when using non-default size, it's usually best to use -1 for the transverse size component, meaning that the default should be used, as the appropriate value depends on the platform and theme.

    • style (Integer) (defaults to: Wx::SL_HORIZONTAL)

      Window style. See Wx::Slider.

    • validator (Wx::Validator) (defaults to: Wx::DEFAULT_VALIDATOR)

      Window validator.

    • name (String) (defaults to: Wx::SLIDER_NAME_STR)

      Window name.

    See Also:

  • #initialize(parent, id, value, minValue, maxValue, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = Wx::SL_HORIZONTAL, validator = Wx::DEFAULT_VALIDATOR, name = Wx::SLIDER_NAME_STR) {|win| ... } ⇒ Wx::Slider

    Constructor, creating and showing a slider.

    Parameters:

    • parent (Wx::Window)

      Parent window. Must not be nil.

    • id (Integer)

      Window identifier. The value Wx::StandardID::ID_ANY indicates a default value.

    • value (Integer)

      Initial position for the slider.

    • minValue (Integer)

      Minimum slider position.

    • maxValue (Integer)

      Maximum slider position.

    • pos (Array(Integer, Integer), Wx::Point) (defaults to: Wx::DEFAULT_POSITION)

      Window position. If DEFAULT_POSITION is specified then a default position is chosen.

    • size (Array(Integer, Integer), Wx::Size) (defaults to: Wx::DEFAULT_SIZE)

      Window size. If DEFAULT_SIZE is specified then a default size is chosen, which is typically appropriate in the transverse slider direction, but is just fixed 100 (DPI-independent) pixels in the primary direction (i.e. vertical for Wx::SL_VERTICAL sliders or horizontal for Wx::SL_HORIZONTAL ones), so it may be preferable to specify it explicitly. Conversely, when using non-default size, it's usually best to use -1 for the transverse size component, meaning that the default should be used, as the appropriate value depends on the platform and theme.

    • style (Integer) (defaults to: Wx::SL_HORIZONTAL)

      Window style. See Wx::Slider.

    • validator (Wx::Validator) (defaults to: Wx::DEFAULT_VALIDATOR)

      Window validator.

    • name (String) (defaults to: Wx::SLIDER_NAME_STR)

      Window name.

    Yield Parameters:

    See Also:



187
# File 'lib/wx/doc/gen/slider.rb', line 187

def initialize(*args) end

Instance Method Details

#clear_ticksvoid

This method returns an undefined value.

Clears the ticks.

Availability: only available for the WXMSW, WXGTK ports.

Requires:

  • WXMSW or WXGTK


194
# File 'lib/wx/doc/gen/slider.rb', line 194

def clear_ticks; end

#create(parent, id, value, minValue, maxValue, point = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = Wx::SL_HORIZONTAL, validator = Wx::DEFAULT_VALIDATOR, name = Wx::SLIDER_NAME_STR) ⇒ Boolean

Used for two-step slider construction.

See #initialize for further details.

Parameters:

  • parent (Wx::Window)
  • id (Integer)
  • value (Integer)
  • minValue (Integer)
  • maxValue (Integer)
  • point (Array(Integer, Integer), Wx::Point) (defaults to: Wx::DEFAULT_POSITION)
  • size (Array(Integer, Integer), Wx::Size) (defaults to: Wx::DEFAULT_SIZE)
  • style (Integer) (defaults to: Wx::SL_HORIZONTAL)
  • validator (Wx::Validator) (defaults to: Wx::DEFAULT_VALIDATOR)
  • name (String) (defaults to: Wx::SLIDER_NAME_STR)

Returns:

  • (Boolean)


210
# File 'lib/wx/doc/gen/slider.rb', line 210

def create(parent, id, value, minValue, maxValue, point=Wx::DEFAULT_POSITION, size=Wx::DEFAULT_SIZE, style=Wx::SL_HORIZONTAL, validator=Wx::DEFAULT_VALIDATOR, name=Wx::SLIDER_NAME_STR) end

#get_line_sizeInteger Also known as: line_size

Returns the line size.

Returns:

  • (Integer)

See Also:



217
# File 'lib/wx/doc/gen/slider.rb', line 217

def get_line_size; end

#get_maxInteger Also known as: max

Gets the maximum slider value.

Returns:

  • (Integer)

See Also:



226
# File 'lib/wx/doc/gen/slider.rb', line 226

def get_max; end

#get_minInteger Also known as: min

Gets the minimum slider value.

Returns:

  • (Integer)

See Also:



235
# File 'lib/wx/doc/gen/slider.rb', line 235

def get_min; end

#get_page_sizeInteger Also known as: page_size

Returns the page size.

Returns:

  • (Integer)

See Also:



243
# File 'lib/wx/doc/gen/slider.rb', line 243

def get_page_size; end

#get_tick_freqInteger Also known as: tick_freq

Returns the tick frequency.

Availability: only available for the WXMSW, WXGTK ports.

Returns:

  • (Integer)

See Also:

Requires:

  • WXMSW or WXGTK


252
# File 'lib/wx/doc/gen/slider.rb', line 252

def get_tick_freq; end

#get_valueInteger Also known as: value

Gets the current slider value.

Returns:

  • (Integer)

See Also:



262
# File 'lib/wx/doc/gen/slider.rb', line 262

def get_value; end

#set_line_size(lineSize) ⇒ void Also known as: line_size=

This method returns an undefined value.

Sets the line size for the slider.

Parameters:

  • lineSize (Integer)

    The number of steps the slider moves when the user moves it up or down a line.

See Also:



271
# File 'lib/wx/doc/gen/slider.rb', line 271

def set_line_size(lineSize) end

#set_max(maxValue) ⇒ void Also known as: max=

This method returns an undefined value.

Sets the maximum slider value.

Parameters:

  • maxValue (Integer)

    The new top end of the slider range.

See Also:



291
# File 'lib/wx/doc/gen/slider.rb', line 291

def set_max(maxValue) end

#set_min(minValue) ⇒ void Also known as: min=

This method returns an undefined value.

Sets the minimum slider value.

Parameters:

  • minValue (Integer)

    The new bottom end of the slider range.

See Also:



281
# File 'lib/wx/doc/gen/slider.rb', line 281

def set_min(minValue) end

#set_page_size(pageSize) ⇒ void Also known as: page_size=

This method returns an undefined value.

Sets the page size for the slider.

Parameters:

  • pageSize (Integer)

    The number of steps the slider moves when the user pages up or down.

See Also:



300
# File 'lib/wx/doc/gen/slider.rb', line 300

def set_page_size(pageSize) end

#set_range(minValue, maxValue) ⇒ void

This method returns an undefined value.

Sets the minimum and maximum slider values.

Parameters:

  • minValue (Integer)
  • maxValue (Integer)

See Also:



311
# File 'lib/wx/doc/gen/slider.rb', line 311

def set_range(minValue, maxValue) end

#set_tick(tickPos) ⇒ void Also known as: tick=

This method returns an undefined value.

Sets a tick position.

Availability: only available for the WXMSW, WXGTK ports.

Parameters:

  • tickPos (Integer)

    The tick position.

See Also:

Requires:

  • WXMSW or WXGTK


320
# File 'lib/wx/doc/gen/slider.rb', line 320

def set_tick(tickPos) end

#set_tick_freq(freq) ⇒ void Also known as: tick_freq=

This method returns an undefined value.

Sets the tick mark frequency and position.

Availability: only available for the WXMSW, WXGTK ports.

Parameters:

  • freq (Integer)

    Frequency. For example, if the frequency is set to two, a tick mark is displayed for every other increment in the slider's range.

See Also:

Requires:

  • WXMSW or WXGTK


330
# File 'lib/wx/doc/gen/slider.rb', line 330

def set_tick_freq(freq) end

#set_value(value) ⇒ void Also known as: value=

This method returns an undefined value.

Sets the slider position.

Parameters:

  • value (Integer)

    The slider position.



336
# File 'lib/wx/doc/gen/slider.rb', line 336

def set_value(value) end