Class: Wx::TextSearch
- Inherits:
-
Object
- Object
- Wx::TextSearch
- Defined in:
- lib/wx/doc/gen/text_ctrl.rb
Overview
This class is untracked and should not be derived from nor instances extended!
Search options for Wx::TextCtrl#search_text.
This is a builder class, where property functions can be called during construction. For example:
wxTextSearchResult result =
textctrl->SearchText(wxTextSearch(L"Institutional Research").
SearchDirection(wxTextSearch::Direction::Down).
MatchCase().
MatchWholeWord());
Defined Under Namespace
Classes: Direction
Instance Method Summary collapse
- #get_direction ⇒ Wx::URLDataObject::Direction
- #get_search_value ⇒ String
- #get_starting_position ⇒ Integer
-
#initialize(text) ⇒ Wx::TextSearch
constructor
The string to search for.
-
#match_case(matchCase = true) ⇒ Wx::TextSearch
Whether the search should match case (i.e., be case sensitive).
- #match_case? ⇒ Boolean
-
#match_whole_word(matchWholeWord = true) ⇒ Wx::TextSearch
Whether the search should match the whole word.
-
#search_direction(direction) ⇒ Wx::TextSearch
Whether the search should go up or down in the text control.
-
#search_value(value) ⇒ Wx::TextSearch
The string to search for.
-
#start(startPosition) ⇒ Wx::TextSearch
Where the search should start from.
- #whole_word? ⇒ Boolean
Constructor Details
#initialize(text) ⇒ Wx::TextSearch
The string to search for.
973 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 973 def initialize(text) end |
Instance Method Details
#get_direction ⇒ Wx::URLDataObject::Direction
968 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 968 def get_direction; end |
#get_search_value ⇒ String
944 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 944 def get_search_value; end |
#get_starting_position ⇒ Integer
950 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 950 def get_starting_position; end |
#match_case(matchCase = true) ⇒ Wx::TextSearch
Whether the search should match case (i.e., be case sensitive).
By default, this is false; search will be case insensitive.
985 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 985 def match_case(matchCase=true) end |
#match_case? ⇒ Boolean
956 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 956 def match_case?; end |
#match_whole_word(matchWholeWord = true) ⇒ Wx::TextSearch
Whether the search should match the whole word.
By default, this is false; searching will not match by whole word.
992 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 992 def match_whole_word(matchWholeWord=true) end |
#search_direction(direction) ⇒ Wx::TextSearch
Whether the search should go up or down in the text control.
By default, search will go downward.
999 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 999 def search_direction(direction) end |
#search_value(value) ⇒ Wx::TextSearch
The string to search for.
978 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 978 def search_value(value) end |
#start(startPosition) ⇒ Wx::TextSearch
Where the search should start from.
By default, if searching down, then the search will start at 0. If searching up, then will start at the end of control.
1006 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 1006 def start(startPosition) end |
#whole_word? ⇒ Boolean
962 |
# File 'lib/wx/doc/gen/text_ctrl.rb', line 962 def whole_word?; end |