Class: Wx::ToolTip

Inherits:
Object show all
Defined in:
lib/wx/doc/gen/tool_tip.rb

Overview

This class holds information about a tooltip associated with a window (see Window#set_tool_tip).

The four static methods, ToolTip.enable, ToolTip.set_delay ToolTip.set_auto_pop and ToolTip.set_reshow can be used to globally alter tooltips behaviour.

Category: HELP

Requires:

  • USE_TOOLTIPS

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Object

#clone, #dup, #is_same_as, #un_share

Constructor Details

#initialize(tip) ⇒ Wx::ToolTip

Constructor.

Parameters:

  • tip (String)


21
# File 'lib/wx/doc/gen/tool_tip.rb', line 21

def initialize(tip) end

Class Method Details

.enable(flag) ⇒ void

This method returns an undefined value.

Enable or disable tooltips globally.

Note:

May not be supported on all platforms (eg. Cocoa).

Parameters:

  • flag (Boolean)


48
# File 'lib/wx/doc/gen/tool_tip.rb', line 48

def self.enable(flag) end

.set_auto_pop(msecs) ⇒ void

This method returns an undefined value.

Set the delay after which the tooltip disappears or how long a tooltip remains visible.

Note:

May not be supported on all platforms (eg. Cocoa, GTK).

Parameters:

  • msecs (Integer)


59
# File 'lib/wx/doc/gen/tool_tip.rb', line 59

def self.set_auto_pop(msecs) end

.set_delay(msecs) ⇒ void

This method returns an undefined value.

Set the delay after which the tooltip appears.

Note:

May not be supported on all platforms.

Parameters:

  • msecs (Integer)


70
# File 'lib/wx/doc/gen/tool_tip.rb', line 70

def self.set_delay(msecs) end

.set_reshow(msecs) ⇒ void

This method returns an undefined value.

Set the delay between subsequent tooltips to appear.

Note:

May not be supported on all platforms (eg. Cocoa, GTK).

Parameters:

  • msecs (Integer)


81
# File 'lib/wx/doc/gen/tool_tip.rb', line 81

def self.set_reshow(msecs) end

Instance Method Details

#get_tipString Also known as: tip

Get the tooltip text.

Returns:

  • (String)


25
# File 'lib/wx/doc/gen/tool_tip.rb', line 25

def get_tip; end

#get_windowWx::Window Also known as: window

Get the associated window.

Returns:



30
# File 'lib/wx/doc/gen/tool_tip.rb', line 30

def get_window; end

#set_tip(tip) ⇒ void Also known as: tip=

This method returns an undefined value.

Set the tooltip text.

Parameters:

  • tip (String)


36
# File 'lib/wx/doc/gen/tool_tip.rb', line 36

def set_tip(tip) end