Class: Wx::WEB::WebView
- Inherits:
-
Control
- Object
- Object
- EvtHandler
- Wx::Window
- Control
- Wx::WEB::WebView
- Defined in:
- lib/wx/doc/gen/web/web_view.rb,
lib/wx/doc/webview.rb
Overview
This control may be used to render web (HTML / CSS / JavaScript) documents.
It is designed to allow the creation of multiple backends for each port. It differs from HTML::HtmlWindow in that each backend is actually a full web engine, provided by a 3rd party (e.g., WebView2 on MSW or WebKit on macOS and GTK). This allows the correct viewing of complex pages with JavaScript and CSS.
Backend Descriptions
This class supports using multiple backends, corresponding to different implementations of the same functionality. Wx::WebViewChrome is available on all three major platforms and each platform also has its own default native backend. Backends are identified by their names, documented in the backend descriptions below.
Wx::WEB::WEBVIEW_BACKEND_IE (MSW)
The IE backend uses Microsoft's WebBrowser control, which depends the locally installed version of Internet Explorer. By default this backend emulates Internet Explorer 11. This can be changed with a registry setting by #msw_set_ie_emulation_level see this article for more information. This backend has full support for custom schemes and virtual file systems. The predefined WEBVIEW_BACKEND_IE constant contains the name of this backend and can be used to explicitly select it when using WebView.new.
If you plan to display any modern web content you should consider using Wx::WEB::WEBVIEW_BACKEND_EDGE (MSW), as Internet Explorer is not supported anymore by Microsoft.
Wx::WEB::WEBVIEW_BACKEND_EDGE (MSW)
The Edge backend uses Microsoft's Edge WebView2. It is available for Windows 7 (newer versions require Windows 10+) and newer. This backend does not support custom schemes. When using handlers, see Wx::WEB::WebViewHandler#set_virtual_host for more details on how to access handler provided URLs. This backend is enabled by default for WXMSW.
If enabled and available at runtime, Edge will be selected as the default backend. If you require the IE backend use WEBVIEW_BACKEND_IE when using WebView.new.
The predefined WEBVIEW_BACKEND_EDGE constant contains the name of this backend.
Wx::WEB::WEBVIEW_BACKEND_WEBKIT (GTK)
Under GTK the WebKit backend uses WebKitGTK+. The current minimum version required is 1.3.1 which ships by default with Ubuntu Natty and Debian Wheezy and has the package name libwebkitgtk-dev. Custom schemes and virtual files systems are supported under this backend, however embedded resources such as images and stylesheets are currently loaded using the data:// scheme. The predefined Wx::WEBVIEW_BACKEND_WEBKIT constant contains the name of this backend.
Wx::WEB::WEBVIEW_BACKEND_WEBKIT2 (GTK3)
Under GTK3 the WebKit2 version of WebKitGTK+ is used. In Ubuntu the required package name is libwebkit2gtk-4.0-dev and under Fedora it is webkitgtk4-devel. All features are supported except for clearing and enabling / disabling the history. The predefined Wx::WEBVIEW_BACKEND_WEBKIT constant contains the name of this backend.
WebKitGTK 2.42+ may fail to render content due to DMA-BUF hardware acceleration issues. This can be resolved by calling ```ruby ENV['WEBKIT_DISABLE_DMABUF_RENDERER'] = '1' ``` before creating a WebView instance.
Wx::WEB::WEBVIEW_BACKEND_WEBKIT (macOS)
The macOS WebKit backend uses Apple's WKWebView class. This backend has full support for custom schemes and virtual file systems on macOS 10.13+. In order to use handlers, two-step creation has to be used and #register_handler has to be called before #create. Starting with macOS 10.11 and iOS 9 an application cannot create unsecure connections (this includes HTTP and unverified HTTPS). You have to include additional fields in your Info.plist to enable such connections. For further details see the documentation on NSAppTransportSecurity here The predefined Wx::WEBVIEW_BACKEND_WEBKIT constant contains the name of this backend.
Wx::WEB::WEBVIEW_BACKEND_CHROMIUM (MSW, macOS, GTK)
The Chromium Embedded Framework backend has to be enabled when building wxWidgets, see the wxWidgets documentation for wxWebViewChromium for additional usage and build instructions. This backend can not be automatically build by the wxRuby3 build scripts but requires a custom wxWidgets installation. See the wxRuby3 INSTALL documentation for details on how to build with a custom wxWidgets setup.
The predefined WEBVIEW_BACKEND_CHROMIUM constant contains the name of this backend.
Asynchronous Notifications
Many of the methods in WebView are asynchronous, i.e. they return immediately and perform their work in the background. This includes functions such as #load_url and #reload. To receive notification of the progress and completion of these functions you need to handle the events that are provided. Specifically EVT_WEBVIEW_LOADED notifies when the page or a sub-frame has finished loading and EVT_WEBVIEW_ERROR notifies that an error has occurred.
Virtual File Systems and Custom Schemes
WebView supports the registering of custom scheme handlers, for example file or http. To do this create a new class which inherits from WebViewHandler, where Wx::WEB::WebViewHandler#get_file returns a pointer to a FSFile which represents the given url or Wx::WEB::WebViewHandler#start_request for more complex requests. You can then register your handler with #register_handler it will be called for all pages and resources.
WebViewFSHandler is provided to access the virtual file system encapsulated by FileSystem. The MemoryFSHandler documentation gives an example of how this may be used.
WebViewArchiveHandler is provided to allow the navigation of pages inside a zip archive. It supports paths of the form: scheme:///C:/example/docs.zip;protocol=zip/main.htm
Events emitted by this class
The following event-handler methods redirect the events to member method or handler blocks for WebViewEvent events. Event handler methods for events emitted by this class:
EvtHandler#evt_webview_created(id, meth = nil, &block): Process a EVT_WEBVIEW_CREATED event, generated when the object is fully initialized. For the backends using asynchronous initialization, such as Wx::WebViewChromium, most of this class member functions can be only used once this event is received. Available only in wxWidgets 3.3.0 or later.
EvtHandler#evt_webview_navigating(id, meth = nil, &block): Process a EVT_WEBVIEW_NAVIGATING event, generated before trying to get a resource. This event may be vetoed to prevent navigating to this resource. Note that if the displayed HTML document has several frames, one such event will be generated per frame.
EvtHandler#evt_webview_navigated(id, meth = nil, &block): Process a EVT_WEBVIEW_NAVIGATED event generated after it was confirmed that a resource would be requested. This event may not be vetoed. Note that if the displayed HTML document has several frames, one such event will be generated per frame.
EvtHandler#evt_webview_loaded(id, meth = nil, &block): Process a EVT_WEBVIEW_LOADED event generated when the document is fully loaded and displayed. Note that if the displayed HTML document has several frames, one such event will be generated per frame.
EvtHandler#evt_webview_error(id, meth = nil, &block): Process a EVT_WEBVIEW_ERROR event generated when a navigation error occurs. The integer associated with this event will be a Wx::WebNavigationError item. The string associated with this event may contain a backend-specific more precise error message/code.
EvtHandler#evt_webview_newwindow(id, meth = nil, &block): Process a EVT_WEBVIEW_NEWWINDOW event, generated when a new window is created. You must handle this event if you want anything to happen, for example to load the page in a new window or tab. For usage details see WebViewWindowFeatures.
EvtHandler#evt_webview_newwindow_features(id, meth = nil, &block): Process a EVT_WEBVIEW_NEWWINDOW_FEATURES event, generated when window features are available for the new window. For usage details see WebViewWindowFeatures. Available only in wxWidgets 3.3.0 or later.
EvtHandler#evt_webview_window_close_requested(id, meth = nil, &block): Process a EVT_WEBVIEW_WINDOW_CLOSE_REQUESTED event, generated when a window is requested to be closed. Available only in wxWidgets 3.3.0 or later.
EvtHandler#evt_webview_title_changed(id, meth = nil, &block): Process a EVT_WEBVIEW_TITLE_CHANGED event, generated when the page title changes. Use GetString to get the title.
EvtHandler#evt_webview_fullscreen_changed(id, meth = nil, &block): Process a EVT_WEBVIEW_FULLSCREEN_CHANGED event, generated when the page wants to enter or leave fullscreen. Use GetInt to get the status. Not implemented for the IE backend. Available only in wxWidgets 3.1.5 or later.
EvtHandler#evt_webview_script_message_received(id, meth = nil, &block): Process a EVT_WEBVIEW_SCRIPT_MESSAGE_RECEIVED event. Available only in wxWidgets 3.1.5 or later. For usage details see #add_script_message_handler.
EvtHandler#evt_webview_script_result(id, meth = nil, &block): Process a EVT_WEBVIEW_SCRIPT_RESULT event. Available only in wxWidgets 3.1.6 or later. For usage details see #run_script_async.
wxEVT_WEBVIEW_BROWSING_DATA_CLEARED(id, func): Process a EVT_WEBVIEW_BROWSING_DATA_CLEARED event only available in wxWidgets 3.3.0 or later. For usage details see #clear_browsing_data.
Class Method Summary collapse
-
.get_backend_version_info(backend = Wx::WEB_VIEW_BACKEND_DEFAULT, context = VersionContext::RunTime) ⇒ Wx::VersionInfo
Retrieve the version information about the backend implementation.
-
.is_backend_available(backend) ⇒ Boolean
Allows to check if a specific backend is currently available.
-
.msw_set_ie_emulation_level(level = Wx::WEB::WEBVIEWIE_EMU_IE11) ⇒ Boolean
Sets emulation level.
- .new(*args) ⇒ Object
-
.new_configuration(backend = Wx::WEB_VIEW_BACKEND_DEFAULT) ⇒ Wx::WEB::WebViewConfiguration
Create a new WebViewConfiguration object.
Instance Method Summary collapse
-
#add_script_message_handler(name) ⇒ Boolean
Add a script message handler with the given name.
-
#add_user_script(javascript, injectionTime = Wx::WEB::WebViewUserScriptInjectionTime::WEBVIEW_INJECT_AT_DOCUMENT_START) ⇒ Boolean
Injects the specified script into the webpage's content.
-
#are_browser_accelerator_keys_enabled ⇒ Boolean
Returns true if browser accelerator keys are enabled.
-
#can_copy ⇒ Boolean
(also: #can_copy?)
Returns true if the current selection can be copied.
-
#can_cut ⇒ Boolean
(also: #can_cut?)
Returns true if the current selection can be cut.
-
#can_go_back ⇒ Boolean
(also: #can_go_back?)
Returns true if it is possible to navigate backward in the history of visited pages.
-
#can_go_forward ⇒ Boolean
(also: #can_go_forward?)
Returns true if it is possible to navigate forward in the history of visited pages.
-
#can_paste ⇒ Boolean
(also: #can_paste?)
Returns true if data can be pasted.
-
#can_redo ⇒ Boolean
(also: #can_redo?)
Returns true if there is an action to redo.
-
#can_set_zoom_type(type) ⇒ Boolean
(also: #can_set_zoom_type?)
Retrieve whether a zoom type is supported.
-
#can_undo ⇒ Boolean
(also: #can_undo?)
Returns true if there is an action to undo.
-
#clear_browsing_data(types = Wx::WEB::WebViewBrowsingDataTypes::WEBVIEW_BROWSING_DATA_ALL, since = ({})) ⇒ Boolean
Clears the browsing data of the web view.
-
#clear_history ⇒ void
Clear the history, this will also remove the visible page.
-
#clear_selection ⇒ void
Clears the current selection.
-
#copy ⇒ void
Copies the current selection.
-
#create(parent, id, url = Wx::WEB_VIEW_DEFAULT_URL_STR, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = 0, name = Wx::WEB_VIEW_NAME_STR) ⇒ Boolean
Creation function for two-step creation.
-
#cut ⇒ void
Cuts the current selection.
-
#delete_selection ⇒ void
Deletes the current selection.
-
#enable_access_to_dev_tools(enable = true) ⇒ void
Enable or disable access to dev tools for the user.
-
#enable_browser_accelerator_keys(enable = true) ⇒ void
Enable or disable if browser accelerator keys are enabled.
-
#enable_context_menu(enable = true) ⇒ void
Enable or disable the right click context menu.
-
#enable_history(enable = true) ⇒ void
Enable or disable the history.
-
#find(text, flags = Wx::WEB::WebViewFindFlags::WEBVIEW_FIND_DEFAULT) ⇒ Integer
Finds a phrase on the current page and if found, the control will scroll the phrase into view and select it.
-
#get_backward_history ⇒ Array<Wx::WEB::WebViewHistoryItem>
(also: #backward_history)
Returns a list of items in the back history.
-
#get_current_title ⇒ String
(also: #current_title)
Get the title of the current web page, or its URL/path if title is not available.
-
#get_current_url ⇒ String
(also: #current_url)
Get the URL of the currently displayed document.
-
#get_forward_history ⇒ Array<Wx::WEB::WebViewHistoryItem>
(also: #forward_history)
Returns a list of items in the forward history.
-
#get_page_source ⇒ String
(also: #page_source)
Get the HTML source code of the currently displayed document.
-
#get_page_text ⇒ String
(also: #page_text)
Get the text of the current page.
-
#get_selected_source ⇒ String
(also: #selected_source)
Returns the currently selected source, if any.
-
#get_selected_text ⇒ String
(also: #selected_text)
Returns the currently selected text, if any.
-
#get_user_agent ⇒ String
(also: #user_agent)
Returns the current user agent string for the web view.
-
#get_zoom ⇒ Wx::WebViewZoom
(also: #zoom)
Get the zoom level of the page.
-
#get_zoom_factor ⇒ Float
(also: #zoom_factor)
Get the zoom factor of the page.
-
#get_zoom_type ⇒ Wx::WebViewZoomType
(also: #zoom_type)
Get how the zoom factor is currently interpreted.
-
#go_back ⇒ void
Navigate back in the history of visited pages.
-
#go_forward ⇒ void
Navigate forward in the history of visited pages.
-
#has_selection ⇒ Boolean
(also: #has_selection?)
Returns true if there is a current selection.
-
#is_access_to_dev_tools_enabled ⇒ Boolean
(also: #access_to_dev_tools_enabled?)
Returns true if dev tools are available to the user.
-
#is_busy ⇒ Boolean
(also: #busy?)
Returns whether the web control is currently busy (e.g. loading a page).
-
#is_context_menu_enabled ⇒ Boolean
(also: #context_menu_enabled?)
Returns true if a context menu will be shown on right click.
-
#is_editable ⇒ Boolean
(also: #editable?)
Returns whether the web control is currently editable.
-
#load_history_item(item) ⇒ void
Loads a history item.
-
#load_url(url) ⇒ void
Load a web page from a URL.
-
#paste ⇒ void
Pastes the current data.
- #print(*args) ⇒ Object
-
#redo_ ⇒ void
Redos the last action.
-
#register_handler(handler) ⇒ void
Registers a custom scheme handler.
-
#reload(flags = Wx::WEB::WebViewReloadFlags::WEBVIEW_RELOAD_DEFAULT) ⇒ void
Reload the currently displayed URL.
-
#remove_all_user_scripts ⇒ void
Removes all user scripts from the web view.
-
#remove_script_message_handler(name) ⇒ Boolean
Remove a script message handler with the given name that was previously added via #add_script_message_handler.
-
#run_script(javascript) ⇒ String?
Runs the given JavaScript code.
-
#run_script_async(javascript) ⇒ void
Runs the given JavaScript code asynchronously and returns the result via a EVT_WEBVIEW_SCRIPT_RESULT.
-
#select_all ⇒ void
Selects the entire page.
-
#set_editable(enable = true) ⇒ void
(also: #editable=)
Set the editable property of the web control.
- #set_page(*args) ⇒ Object
-
#set_proxy(proxy) ⇒ Boolean
(also: #proxy=)
Set the proxy to use for all requests.
-
#set_user_agent(userAgent) ⇒ Boolean
(also: #user_agent=)
Specify a custom user agent string for the web view.
-
#set_zoom(zoom) ⇒ void
(also: #zoom=)
Set the zoom level of the page.
-
#set_zoom_factor(zoom) ⇒ void
(also: #zoom_factor=)
Set the zoom factor of the page.
-
#set_zoom_type(zoomType) ⇒ void
(also: #zoom_type=)
Set how to interpret the zoom factor.
-
#show_dev_tools ⇒ Boolean
Show the dev tools window.
-
#stop ⇒ void
Stop the current page loading process, if any.
-
#undo ⇒ void
Undos the last action.
Methods inherited from Control
#command, ellipsize, escape_mnemonics, #get_label, #get_label_text, #get_size_from_text, #get_size_from_text_size, #initialize, remove_mnemonics, #set_label, #set_label_markup, #set_label_text
Methods inherited from Wx::Window
#accepts_focus, #accepts_focus_from_keyboard, #accepts_focus_recursively, #add_child, #adjust_for_layout_direction, #always_show_scrollbars, #begin_repositioning_children, #cache_best_size, #can_accept_focus, #can_accept_focus_from_keyboard, #can_scroll, #can_set_transparent, #capture_mouse, #center, #center_on_parent, #centre, #centre_on_parent, #clear_background, #client_to_screen, #client_to_window_size, #close, #convert_dialog_to_pixels, #convert_pixels_to_dialog, #destroy, #destroy_children, #disable, #disable_focus_from_keyboard, #do_prepare_update_window_ui, #do_update_window_ui, #drag_accept_files, #each_child, #enable, #enable_touch_events, #enable_visible_focus, #end_repositioning_children, find_focus, #find_window_by_id, find_window_by_id, #find_window_by_label, find_window_by_label, #find_window_by_name, find_window_by_name, #fit, #fit_inside, #freeze, #from_dip, from_dip, #from_phys, from_phys, #get_accelerator_table, #get_auto_layout, #get_background_colour, #get_background_style, #get_best_height, #get_best_size, #get_best_virtual_size, #get_best_width, #get_border, get_capture, #get_caret, #get_char_height, #get_char_width, #get_children, get_class_default_attributes, #get_client_area_origin, #get_client_rect, #get_client_size, #get_containing_sizer, #get_content_scale_factor, #get_cursor, #get_cursor_bundle, #get_default_attributes, #get_dpi, #get_dpi_scale_factor, #get_drop_target, #get_effective_min_size, #get_event_handler, #get_extra_style, #get_font, #get_foreground_colour, #get_grand_parent, #get_help_id_at_point, #get_help_text, #get_help_text_at_point, #get_id, #get_label, #get_layout_direction, #get_max_client_size, #get_max_height, #get_max_size, #get_max_width, #get_min_client_size, #get_min_height, #get_min_size, #get_min_size_from_known_direction, #get_min_width, #get_name, #get_next_sibling, #get_parent, #get_popup_menu_selection_from_user, #get_position, #get_prev_sibling, #get_rect, #get_screen_position, #get_screen_rect, #get_scroll_pos, #get_scroll_range, #get_scroll_thumb, #get_size, #get_sizer, #get_text_extent, #get_theme_enabled, #get_tool_tip, #get_tool_tip_text, #get_update_client_rect, #get_update_region, #get_validator, #get_virtual_size, #get_window_border_size, #get_window_style, #get_window_style_flag, #get_window_variant, #handle_as_navigation_key, #handle_window_event, #has_capture, #has_extra_style, #has_flag, #has_focus, #has_multiple_pages, #has_scrollbar, #has_transparent_background, #hide, #hide_with_effect, #hit_test, #inform_first_direction, #inherit_attributes, #inherits_background_colour, #inherits_foreground_colour, #init_dialog, #initialize, #invalidate_best_size, #is_being_deleted, #is_descendant, #is_double_buffered, #is_enabled, #is_exposed, #is_focusable, #is_frozen, #is_retained, #is_scrollbar_always_shown, #is_shown, #is_shown_on_screen, #is_this_enabled, #is_top_level, #is_transparent_background_supported, #layout, #line_down, #line_up, #locked, #lower_window, #move, #move_after_in_tab_order, #move_before_in_tab_order, #navigate, #navigate_in, new_control_id, #on_internal_idle, #page_down, #page_up, #paint, #paint_buffered, #pop_event_handler, #popup_menu, #post_size_event, #post_size_event_to_parent, #process_window_event, #process_window_event_locally, #push_event_handler, #raise_window, #refresh, #refresh_rect, #release_mouse, #remove_child, #remove_event_handler, #reparent, #screen_to_client, #scroll_lines, #scroll_pages, #scroll_window, #send_size_event, #send_size_event_to_parent, #set_accelerator_table, #set_auto_layout, #set_background_colour, #set_background_style, #set_can_focus, #set_caret, #set_client_size, #set_containing_sizer, #set_cursor, #set_cursor_bundle, #set_double_buffered, #set_drop_target, #set_event_handler, #set_extra_style, #set_focus, #set_focus_from_kbd, #set_font, #set_foreground_colour, #set_help_text, #set_id, #set_initial_size, #set_label, #set_layout_direction, #set_max_client_size, #set_max_size, #set_min_client_size, #set_min_size, #set_name, #set_next_handler, #set_own_background_colour, #set_own_font, #set_own_foreground_colour, #set_position, #set_previous_handler, #set_scroll_pos, #set_scrollbar, #set_size, #set_size_hints, #set_sizer, #set_sizer_and_fit, #set_theme_enabled, #set_tool_tip, #set_transparent, #set_validator, #set_virtual_size, #set_window_style, #set_window_style_flag, #set_window_variant, #should_inherit_colours, #show, #show_with_effect, #switch_sizer, #thaw, #to_dip, to_dip, #to_phys, to_phys, #toggle_window_style, #transfer_data_from_window, #transfer_data_to_window, unreserve_control_id, #unset_tool_tip, #update, #update_window_ui, #use_background_colour, #use_bg_col, #use_foreground_colour, #validate, #warp_pointer, #window_to_client_size
Methods inherited from EvtHandler
add_filter, #add_pending_event, #call_after, clear_filters, #connect, #delete_pending_events, #disconnect, #evt_activate, #evt_activate_app, #evt_aui_pane_activated, #evt_aui_pane_button, #evt_aui_pane_close, #evt_aui_pane_maximize, #evt_aui_pane_minimize, #evt_aui_pane_restore, #evt_aui_render, #evt_auinotebook_allow_dnd, #evt_auinotebook_begin_drag, #evt_auinotebook_bg_dclick, #evt_auinotebook_button, #evt_auinotebook_drag_done, #evt_auinotebook_drag_motion, #evt_auinotebook_end_drag, #evt_auinotebook_page_changed, #evt_auinotebook_page_changing, #evt_auinotebook_page_close, #evt_auinotebook_page_closed, #evt_auinotebook_tab_middle_down, #evt_auinotebook_tab_middle_up, #evt_auinotebook_tab_right_down, #evt_auinotebook_tab_right_up, #evt_auitoolbar_begin_drag, #evt_auitoolbar_middle_click, #evt_auitoolbar_overflow_click, #evt_auitoolbar_right_click, #evt_auitoolbar_tool_dropdown, #evt_button, #evt_calculate_layout, #evt_calendar, #evt_calendar_page_changed, #evt_calendar_sel_changed, #evt_calendar_week_clicked, #evt_calendar_weekday_clicked, #evt_char, #evt_char_hook, #evt_checkbox, #evt_checklistbox, #evt_child_focus, #evt_choice, #evt_choicebook_page_changed, #evt_choicebook_page_changing, #evt_close, #evt_collapsiblepane_changed, #evt_colourpicker_changed, #evt_colourpicker_current_changed, #evt_colourpicker_dialog_cancelled, #evt_combobox, #evt_combobox_closeup, #evt_combobox_dropdown, #evt_command, #evt_command_enter, #evt_command_kill_focus, #evt_command_left_click, #evt_command_left_dclick, #evt_command_range, #evt_command_right_click, #evt_command_scroll, #evt_command_scroll_bottom, #evt_command_scroll_changed, #evt_command_scroll_linedown, #evt_command_scroll_lineup, #evt_command_scroll_pagedown, #evt_command_scroll_pageup, #evt_command_scroll_thumbrelease, #evt_command_scroll_thumbtrack, #evt_command_scroll_top, #evt_command_set_focus, #evt_context_menu, #evt_date_changed, #evt_dialup_connected, #evt_dialup_disconnected, #evt_dirctrl_fileactivated, #evt_dirctrl_selectionchanged, #evt_dirpicker_changed, #evt_dpi_changed, #evt_drop_files, #evt_end_session, #evt_enter_window, #evt_erase_background, #evt_filectrl_fileactivated, #evt_filectrl_filterchanged, #evt_filectrl_folderchanged, #evt_filectrl_selectionchanged, #evt_filepicker_changed, #evt_find, #evt_find_close, #evt_find_next, #evt_find_replace, #evt_find_replace_all, #evt_fontpicker_changed, #evt_fullscreen, #evt_gesture_pan, #evt_gesture_rotate, #evt_gesture_zoom, #evt_grid_cell_changed, #evt_grid_cell_changing, #evt_grid_cell_left_click, #evt_grid_cell_left_dclick, #evt_grid_cell_right_click, #evt_grid_cell_right_dclick, #evt_grid_cmd_col_size, #evt_grid_cmd_editor_created, #evt_grid_cmd_range_selected, #evt_grid_cmd_range_selecting, #evt_grid_cmd_row_size, #evt_grid_col_auto_size, #evt_grid_col_label_size, #evt_grid_col_move, #evt_grid_col_size, #evt_grid_col_sort, #evt_grid_editor_created, #evt_grid_editor_hidden, #evt_grid_editor_shown, #evt_grid_label_left_click, #evt_grid_label_left_dclick, #evt_grid_label_right_click, #evt_grid_label_right_dclick, #evt_grid_range_selected, #evt_grid_range_selecting, #evt_grid_row_auto_size, #evt_grid_row_label_size, #evt_grid_row_move, #evt_grid_row_size, #evt_grid_select_cell, #evt_grid_tabbing, #evt_header_begin_reorder, #evt_header_begin_resize, #evt_header_click, #evt_header_dclick, #evt_header_dragging_cancelled, #evt_header_end_reorder, #evt_header_end_resize, #evt_header_middle_click, #evt_header_middle_dclick, #evt_header_resizing, #evt_header_right_click, #evt_header_right_dclick, #evt_header_separator_dclick, #evt_help, #evt_help_range, #evt_hibernate, #evt_hotkey, #evt_html_cell_clicked, #evt_html_cell_hover, #evt_html_link_clicked, #evt_hyperlink, #evt_iconize, #evt_idle, #evt_init_dialog, #evt_joy_button_down, #evt_joy_button_up, #evt_joy_move, #evt_joy_zmove, #evt_joystick_events, #evt_key_down, #evt_key_up, #evt_kill_focus, #evt_leave_window, #evt_left_dclick, #evt_left_down, #evt_left_up, #evt_list_begin_drag, #evt_list_begin_label_edit, #evt_list_begin_rdrag, #evt_list_cache_hint, #evt_list_col_begin_drag, #evt_list_col_click, #evt_list_col_dragging, #evt_list_col_end_drag, #evt_list_col_right_click, #evt_list_delete_all_items, #evt_list_delete_item, #evt_list_end_label_edit, #evt_list_insert_item, #evt_list_item_activated, #evt_list_item_checked, #evt_list_item_deselected, #evt_list_item_focused, #evt_list_item_middle_click, #evt_list_item_right_click, #evt_list_item_selected, #evt_list_item_unchecked, #evt_list_key_down, #evt_listbook_page_changed, #evt_listbook_page_changing, #evt_listbox, #evt_listbox_dclick, #evt_long_press, #evt_magnify, #evt_maximize, #evt_media_finished, #evt_media_loaded, #evt_media_pause, #evt_media_play, #evt_media_statechanged, #evt_media_stop, #evt_menu, #evt_menu_close, #evt_menu_highlight, #evt_menu_highlight_all, #evt_menu_open, #evt_menu_range, #evt_middle_dclick, #evt_middle_down, #evt_middle_up, #evt_motion, #evt_mouse_aux1_dclick, #evt_mouse_aux1_down, #evt_mouse_aux1_up, #evt_mouse_aux2_dclick, #evt_mouse_aux2_down, #evt_mouse_aux2_up, #evt_mouse_events, #evt_mousewheel, #evt_move, #evt_move_end, #evt_move_start, #evt_moving, #evt_navigation_key, #evt_notebook_page_changed, #evt_notebook_page_changing, #evt_paint, #evt_pg_changed, #evt_pg_changing, #evt_pg_col_begin_drag, #evt_pg_col_dragging, #evt_pg_col_end_drag, #evt_pg_double_click, #evt_pg_highlighted, #evt_pg_item_collapsed, #evt_pg_item_expanded, #evt_pg_label_edit_begin, #evt_pg_label_edit_ending, #evt_pg_page_changed, #evt_pg_right_click, #evt_pg_selected, #evt_press_and_tap, #evt_query_end_session, #evt_query_layout_info, #evt_radiobox, #evt_radiobutton, #evt_ribbonbar_help_click, #evt_ribbonbar_page_changed, #evt_ribbonbar_page_changing, #evt_ribbonbar_tab_left_dclick, #evt_ribbonbar_tab_middle_down, #evt_ribbonbar_tab_middle_up, #evt_ribbonbar_tab_right_down, #evt_ribbonbar_tab_right_up, #evt_ribbonbar_toggled, #evt_ribbonbuttonbar_clicked, #evt_ribbonbuttonbar_dropdown_clicked, #evt_ribbongallery_clicked, #evt_ribbongallery_hover_changed, #evt_ribbongallery_selected, #evt_ribbonpanel_extbutton_activated, #evt_ribbontoolbar_clicked, #evt_ribbontoolbar_dropdown_clicked, #evt_richtext_buffer_reset, #evt_richtext_character, #evt_richtext_consuming_character, #evt_richtext_content_deleted, #evt_richtext_content_inserted, #evt_richtext_delete, #evt_richtext_focus_object_changed, #evt_richtext_left_click, #evt_richtext_left_dclick, #evt_richtext_middle_click, #evt_richtext_properties_changed, #evt_richtext_return, #evt_richtext_right_click, #evt_richtext_selection_changed, #evt_richtext_style_changed, #evt_richtext_stylesheet_changed, #evt_richtext_stylesheet_replaced, #evt_richtext_stylesheet_replacing, #evt_right_dclick, #evt_right_down, #evt_right_up, #evt_sash_dragged, #evt_sash_dragged_range, #evt_scroll, #evt_scroll_bottom, #evt_scroll_changed, #evt_scroll_linedown, #evt_scroll_lineup, #evt_scroll_pagedown, #evt_scroll_pageup, #evt_scroll_thumbrelease, #evt_scroll_thumbtrack, #evt_scroll_top, #evt_scrollbar, #evt_scrollwin, #evt_scrollwin_bottom, #evt_scrollwin_linedown, #evt_scrollwin_lineup, #evt_scrollwin_pagedown, #evt_scrollwin_pageup, #evt_scrollwin_thumbrelease, #evt_scrollwin_thumbtrack, #evt_scrollwin_top, #evt_search, #evt_search_cancel, #evt_set_cursor, #evt_set_focus, #evt_show, #evt_size, #evt_slider, #evt_spin, #evt_spin_down, #evt_spin_up, #evt_spinctrl, #evt_spinctrldouble, #evt_splitter_dclick, #evt_splitter_sash_pos_changed, #evt_splitter_sash_pos_changing, #evt_splitter_sash_pos_resize, #evt_splitter_unsplit, #evt_stc_autocomp_cancelled, #evt_stc_autocomp_char_deleted, #evt_stc_autocomp_completed, #evt_stc_autocomp_selection, #evt_stc_autocomp_selection_change, #evt_stc_calltip_click, #evt_stc_change, #evt_stc_charadded, #evt_stc_clipboard_copy, #evt_stc_clipboard_paste, #evt_stc_do_drop, #evt_stc_doubleclick, #evt_stc_drag_over, #evt_stc_dwellend, #evt_stc_dwellstart, #evt_stc_hotspot_click, #evt_stc_hotspot_dclick, #evt_stc_hotspot_release_click, #evt_stc_indicator_click, #evt_stc_indicator_release, #evt_stc_macrorecord, #evt_stc_margin_right_click, #evt_stc_marginclick, #evt_stc_modified, #evt_stc_needshown, #evt_stc_painted, #evt_stc_romodifyattempt, #evt_stc_savepointleft, #evt_stc_savepointreached, #evt_stc_start_drag, #evt_stc_styleneeded, #evt_stc_updateui, #evt_stc_userlistselection, #evt_stc_zoom, #evt_sys_colour_changed, #evt_taskbar_click, #evt_taskbar_left_dclick, #evt_taskbar_left_down, #evt_taskbar_left_up, #evt_taskbar_move, #evt_taskbar_right_dclick, #evt_taskbar_right_down, #evt_taskbar_right_up, #evt_text, #evt_text_copy, #evt_text_cut, #evt_text_enter, #evt_text_maxlen, #evt_text_paste, #evt_text_url, #evt_time_changed, #evt_timer, #evt_togglebutton, #evt_tool, #evt_tool_dropdown, #evt_tool_enter, #evt_tool_range, #evt_tool_rclicked, #evt_tool_rclicked_range, #evt_toolbook_page_changed, #evt_toolbook_page_changing, #evt_tree_begin_drag, #evt_tree_begin_label_edit, #evt_tree_begin_rdrag, #evt_tree_delete_item, #evt_tree_end_drag, #evt_tree_end_label_edit, #evt_tree_get_info, #evt_tree_item_activated, #evt_tree_item_collapsed, #evt_tree_item_collapsing, #evt_tree_item_expanded, #evt_tree_item_expanding, #evt_tree_item_gettooltip, #evt_tree_item_menu, #evt_tree_item_middle_click, #evt_tree_item_right_click, #evt_tree_key_down, #evt_tree_sel_changed, #evt_tree_sel_changing, #evt_tree_set_info, #evt_tree_state_image_click, #evt_treebook_node_collapsed, #evt_treebook_node_expanded, #evt_treebook_page_changed, #evt_treebook_page_changing, #evt_two_finger_tap, #evt_update_ui, #evt_update_ui_range, #evt_webview_browsing_data_cleared, #evt_webview_created, #evt_webview_error, #evt_webview_fullscreen_changed, #evt_webview_loaded, #evt_webview_navigated, #evt_webview_navigating, #evt_webview_newwindow, #evt_webview_newwindow_features, #evt_webview_script_message_received, #evt_webview_script_result, #evt_webview_title_changed, #evt_webview_window_close_requested, #evt_window_create, #evt_window_destroy, #evt_wizard_before_page_changed, #evt_wizard_cancel, #evt_wizard_finished, #evt_wizard_help, #evt_wizard_page_changed, #evt_wizard_page_changing, #evt_wizard_page_shown, #get_client_object, #get_evt_handler_enabled, #get_next_handler, #get_previous_handler, #initialize, #is_unlinked, #make_shared, #process_event, #process_event_locally, #process_pending_events, #queue_event, register_class, remove_filter, #safely_process_event, #set_client_object, #set_evt_handler_enabled, #set_next_handler, #try_after, #try_before, #unlink
Methods inherited from Object
#clone, #dup, #initialize, #is_same_as, #un_share
Constructor Details
This class inherits a constructor from Wx::Control
Class Method Details
.get_backend_version_info(backend = Wx::WEB_VIEW_BACKEND_DEFAULT, context = VersionContext::RunTime) ⇒ Wx::VersionInfo
Retrieve the version information about the backend implementation.
1031 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1031 def self.get_backend_version_info(backend=Wx::WEB_VIEW_BACKEND_DEFAULT, context=VersionContext::RunTime) end |
.is_backend_available(backend) ⇒ Boolean
1025 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1025 def self.is_backend_available(backend) end |
.msw_set_ie_emulation_level(level = Wx::WEB::WEBVIEWIE_EMU_IE11) ⇒ Boolean
Sets emulation level.
This function is useful to change the emulation level of the system browser control used for Wx::WebView implementation under MSW, rather than using the currently default, IE11-compatible, level (with wxRuby3).
Please notice that this function works by modifying the per-user part of MSW registry, which has several implications: first, it is sufficient to call it only once (per user) as the changes done by it are persistent and, second, if you do not want them to be persistent, you need to call it with Wx::WEB::WEBVIEWIE_EMU_DEFAULT argument explicitly.
In particular, this function should be called to allow #run_script to work for JavaScript code returning arbitrary objects, which is not supported at the default emulation level.
If set to a level higher than installed version, the highest available level will be used instead. Wx::WEB::WEBVIEWIE_EMU_IE11 is recommended for best performance and experience.
This function is MSW-specific and doesn't exist under other platforms.
35 |
# File 'lib/wx/doc/webview.rb', line 35 def self.msw_set_ie_emulation_level(level=Wx::WEB::WEBVIEWIE_EMU_IE11); end |
.self.new(backend = Wx::WEB_VIEW_BACKEND_DEFAULT) ⇒ Wx::WEB::WebView .self.new(config) ⇒ Wx::WEB::WebView .self.new(parent, id, url = Wx::WEB_VIEW_DEFAULT_URL_STR, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, backend = Wx::WEB_VIEW_BACKEND_DEFAULT, style = 0, name = Wx::WEB_VIEW_NAME_STR) ⇒ Wx::WEB::WebView
1012 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1012 def self.new(*args) end |
.new_configuration(backend = Wx::WEB_VIEW_BACKEND_DEFAULT) ⇒ Wx::WEB::WebViewConfiguration
Create a new Wx::WEB::WebViewConfiguration object.
1036 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1036 def self.new_configuration(backend=Wx::WEB_VIEW_BACKEND_DEFAULT) end |
Instance Method Details
#add_script_message_handler(name) ⇒ Boolean
Add a script message handler with the given name.
To use the script message handler from javascript use window. where corresponds the value of the name parameter. The will be available to the application via a EVT_WEBVIEW_SCRIPT_MESSAGE_RECEIVED event.
Sample code receiving a script message:
# Install message handler with the name wx_msg
@webView.("wx_msg")
# Bind handler
@webView.(Wx::ID_ANY) { |evt|
Wx.("Script message received; value = %s, handler = %s", evt.get_string, evt.)
}
Sample JavaScript sending a script message:
// Send sample message body
window.wx_msg.postMessage('This is a message body');
true if the handler could be added, false if it could not be added.
The Edge backend only supports a single message handler and the Chromium and IE backends do not support script message handlers.
482 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 482 def (name) end |
#add_user_script(javascript, injectionTime = Wx::WEB::WebViewUserScriptInjectionTime::WEBVIEW_INJECT_AT_DOCUMENT_START) ⇒ Boolean
Injects the specified script into the webpage's content.
true if the script was added successfully.
Please note that this is unsupported by the IE backend and the Edge backend does only support Wx::WEB::WebViewUserScriptInjectionTime::WEBVIEW_INJECT_AT_DOCUMENT_START.
505 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 505 def add_user_script(javascript, injectionTime=Wx::WEB::WebViewUserScriptInjectionTime::WEBVIEW_INJECT_AT_DOCUMENT_START) end |
#are_browser_accelerator_keys_enabled ⇒ Boolean
Returns true if browser accelerator keys are enabled.
603 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 603 def are_browser_accelerator_keys_enabled; end |
#can_copy ⇒ Boolean Also known as: can_copy?
Returns true if the current selection can be copied.
516 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 516 def can_copy; end |
#can_cut ⇒ Boolean Also known as: can_cut?
Returns true if the current selection can be cut.
521 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 521 def can_cut; end |
#can_go_back ⇒ Boolean Also known as: can_go_back?
Returns true if it is possible to navigate backward in the history of visited pages.
607 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 607 def can_go_back; end |
#can_go_forward ⇒ Boolean Also known as: can_go_forward?
Returns true if it is possible to navigate forward in the history of visited pages.
612 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 612 def can_go_forward; end |
#can_paste ⇒ Boolean Also known as: can_paste?
Returns true if data can be pasted.
526 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 526 def can_paste; end |
#can_redo ⇒ Boolean Also known as: can_redo?
Returns true if there is an action to redo.
700 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 700 def can_redo; end |
#can_set_zoom_type(type) ⇒ Boolean Also known as: can_set_zoom_type?
Retrieve whether a zoom type is supported.
true if this type of zoom is supported by this backend (and thus can be set through #set_zoom_type).
735 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 735 def can_set_zoom_type(type) end |
#can_undo ⇒ Boolean Also known as: can_undo?
Returns true if there is an action to undo.
705 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 705 def can_undo; end |
#clear_browsing_data(types = Wx::WEB::WebViewBrowsingDataTypes::WEBVIEW_BROWSING_DATA_ALL, since = ({})) ⇒ Boolean
Clears the browsing data of the web view.
This function clears the browsing data of the web view, such as cookies, cache, history, etc. The exact data that is cleared depends on the backend used. This operation is asynchronous and may take some time to complete. When finished EVT_WEBVIEW_BROWSING_DATA_CLEARED event is generated.
false if backend doesn't support clearing browsing data or an error occurred. Otherwise, true is returned and the browsing data will be cleared asynchronously and the application will receive a EVT_WEBVIEW_BROWSING_DATA_CLEARED event when it is done (or if doing it fails later).
This is only implemented in the Edge, WebKit2GTK+ and macOS backends.
983 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 983 def clear_browsing_data(types=Wx::WEB::WebViewBrowsingDataTypes::WEBVIEW_BROWSING_DATA_ALL, since=({})) end |
#clear_history ⇒ void
This method returns an undefined value.
Clear the history, this will also remove the visible page.
This is not implemented on the WebKit2GTK+ backend and macOS.
623 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 623 def clear_history; end |
#clear_selection ⇒ void
This method returns an undefined value.
Clears the current selection.
671 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 671 def clear_selection; end |
#copy ⇒ void
This method returns an undefined value.
Copies the current selection.
531 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 531 def copy; end |
#create(parent, id, url = Wx::WEB_VIEW_DEFAULT_URL_STR, pos = Wx::DEFAULT_POSITION, size = Wx::DEFAULT_SIZE, style = 0, name = Wx::WEB_VIEW_NAME_STR) ⇒ Boolean
Creation function for two-step creation.
Please note that the object creation may be asynchronous when using some backends (e.g., Wx::WebViewEdge or Wx::WebViewChromium) and the object is not really created until EVT_WEBVIEW_CREATED event is received, so any non-trivial calls to its member functions should be delayed until then.
802 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 802 def create(parent, id, url=Wx::WEB_VIEW_DEFAULT_URL_STR, pos=Wx::DEFAULT_POSITION, size=Wx::DEFAULT_SIZE, style=0, name=Wx::WEB_VIEW_NAME_STR) end |
#cut ⇒ void
This method returns an undefined value.
Cuts the current selection.
535 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 535 def cut; end |
#delete_selection ⇒ void
This method returns an undefined value.
Deletes the current selection.
Note that for Wx::WEBVIEW_BACKEND_WEBKIT the selection must be editable, either through SetEditable or the correct HTML attribute.
677 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 677 def delete_selection; end |
#enable_access_to_dev_tools(enable = true) ⇒ void
This method returns an undefined value.
Enable or disable access to dev tools for the user.
Dev tools are disabled by default.
This is not implemented for the IE backend.
565 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 565 def enable_access_to_dev_tools(enable=true) end |
#enable_browser_accelerator_keys(enable = true) ⇒ void
This method returns an undefined value.
Enable or disable if browser accelerator keys are enabled.
Browser accelerator keys are enabled by default. The webview might implement various accelerator keys. This includes allowing accelerator key access to features such as printing and navigation. In many cases this might not be desired and the default keys can be disabled with this setting.
This is only implemented for the Edge backend.
599 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 599 def enable_browser_accelerator_keys(enable=true) end |
#enable_context_menu(enable = true) ⇒ void
This method returns an undefined value.
Enable or disable the right click context menu.
By default the standard context menu is enabled, this method can be used to disable it or re-enable it later.
546 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 546 def (enable=true) end |
#enable_history(enable = true) ⇒ void
This method returns an undefined value.
Enable or disable the history.
This will also clear the history.
This is not implemented on the WebKit2GTK+ backend and macOS.
636 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 636 def enable_history(enable=true) end |
#find(text, flags = Wx::WEB::WebViewFindFlags::WEBVIEW_FIND_DEFAULT) ⇒ Integer
Finds a phrase on the current page and if found, the control will scroll the phrase into view and select it.
If search phrase was not found in combination with the flags then NOT_FOUND is returned. If called for the first time with search phrase then the total number of results will be returned. Then for every time its called with the same search phrase it will return the number of the current match.
This function will restart the search if the flags Wx::WEB::WebViewFindFlags::WEBVIEW_FIND_ENTIRE_WORD or Wx::WEB::WebViewFindFlags::WEBVIEW_FIND_MATCH_CASE are changed, since this will require a new search. To reset the search, for example resetting the highlights call the function with an empty search phrase.
728 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 728 def find(text, flags=Wx::WEB::WebViewFindFlags::WEBVIEW_FIND_DEFAULT) end |
#get_backward_history ⇒ Array<Wx::WEB::WebViewHistoryItem> Also known as: backward_history
Returns a list of items in the back history.
The first item in the vector is the first page that was loaded by the control.
642 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 642 def get_backward_history; end |
#get_current_title ⇒ String Also known as: current_title
Get the title of the current web page, or its URL/path if title is not available.
806 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 806 def get_current_title; end |
#get_current_url ⇒ String Also known as: current_url
Get the URL of the currently displayed document.
811 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 811 def get_current_url; end |
#get_forward_history ⇒ Array<Wx::WEB::WebViewHistoryItem> Also known as: forward_history
Returns a list of items in the forward history.
The first item in the vector is the next item in the history with respect to the currently loaded page.
649 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 649 def get_forward_history; end |
#get_page_source ⇒ String Also known as: page_source
Get the HTML source code of the currently displayed document.
The HTML source code, or an empty string if no page is currently shown.
818 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 818 def get_page_source; end |
#get_page_text ⇒ String Also known as: page_text
Get the text of the current page.
823 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 823 def get_page_text; end |
#get_selected_source ⇒ String Also known as: selected_source
Returns the currently selected source, if any.
681 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 681 def get_selected_source; end |
#get_selected_text ⇒ String Also known as: selected_text
Returns the currently selected text, if any.
686 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 686 def get_selected_text; end |
#get_user_agent ⇒ String Also known as: user_agent
Returns the current user agent string for the web view.
945 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 945 def get_user_agent; end |
#get_zoom ⇒ Wx::WebViewZoom Also known as: zoom
Get the zoom level of the page.
See #get_zoom_factor to get more precise zoom scale value other than as provided by Wx::WEB::WebViewZoom. The current level of zoom.
742 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 742 def get_zoom; end |
#get_zoom_factor ⇒ Float Also known as: zoom_factor
Get the zoom factor of the page.
The current factor of zoom.
749 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 749 def get_zoom_factor; end |
#get_zoom_type ⇒ Wx::WebViewZoomType Also known as: zoom_type
Get how the zoom factor is currently interpreted.
How the zoom factor is currently interpreted by the backend.
756 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 756 def get_zoom_type; end |
#go_back ⇒ void
This method returns an undefined value.
Navigate back in the history of visited pages.
Only valid if #can_go_back returns true.
656 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 656 def go_back; end |
#go_forward ⇒ void
This method returns an undefined value.
Navigate forward in the history of visited pages.
Only valid if #can_go_forward returns true.
662 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 662 def go_forward; end |
#has_selection ⇒ Boolean Also known as: has_selection?
Returns true if there is a current selection.
691 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 691 def has_selection; end |
#is_access_to_dev_tools_enabled ⇒ Boolean Also known as: access_to_dev_tools_enabled?
Returns true if dev tools are available to the user.
569 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 569 def is_access_to_dev_tools_enabled; end |
#is_busy ⇒ Boolean Also known as: busy?
Returns whether the web control is currently busy (e.g. loading a page).
828 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 828 def is_busy; end |
#is_context_menu_enabled ⇒ Boolean Also known as:
Returns true if a context menu will be shown on right click.
550 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 550 def ; end |
#is_editable ⇒ Boolean Also known as: editable?
Returns whether the web control is currently editable.
833 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 833 def is_editable; end |
#load_history_item(item) ⇒ void
This method returns an undefined value.
Loads a history item.
667 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 667 def load_history_item(item) end |
#load_url(url) ⇒ void
This method returns an undefined value.
Load a web page from a URL.
Web engines generally report errors asynchronously, so if you wish to know whether loading the URL was successful, register to receive navigation error events.
845 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 845 def load_url(url) end |
#paste ⇒ void
This method returns an undefined value.
Pastes the current data.
539 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 539 def paste; end |
#print ⇒ void #print(printData, flags = Wx::WEB::WebViewPrintFlags::WEBVIEW_PRINT_HIDE_HEADER_FOOTER) ⇒ void
860 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 860 def print(*args) end |
#redo_ ⇒ void
This method returns an undefined value.
Redos the last action.
710 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 710 def redo_; end |
#register_handler(handler) ⇒ void
This method returns an undefined value.
Registers a custom scheme handler.
On macOS in order to use handlers two-step creation has to be used and #register_handler has to be called before #create. With the other backends it has to be called after #create.
The Edge backend does not support custom schemes, but the handler is available as a virtual host under https://scheme.wxsite. To customize this virtual host call Wx::WEB::WebViewHandler#set_virtual_host before registering the handler.
877 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 877 def register_handler(handler) end |
#reload(flags = Wx::WEB::WebViewReloadFlags::WEBVIEW_RELOAD_DEFAULT) ⇒ void
This method returns an undefined value.
Reload the currently displayed URL.
The flags are ignored by the Edge backend.
888 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 888 def reload(flags=Wx::WEB::WebViewReloadFlags::WEBVIEW_RELOAD_DEFAULT) end |
#remove_all_user_scripts ⇒ void
This method returns an undefined value.
Removes all user scripts from the web view.
512 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 512 def remove_all_user_scripts; end |
#remove_script_message_handler(name) ⇒ Boolean
Remove a script message handler with the given name that was previously added via #add_script_message_handler.
true if the handler could be removed, false if it could not be removed.
490 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 490 def (name) end |
#run_script(javascript) ⇒ String?
Runs the given JavaScript code.
Because of various potential issues it's recommended to use #run_script_async instead of this method. This is especially true if you plan to run code from a webview event and will also prevent unintended side effects on the UI outside of the webview.
JavaScript code is executed inside the browser control and has full access to DOM and other browser-provided functionality. For example, this code
webview.run_script('document.write('Hello from wxWidgets!')')
will replace the current page contents with the provided string. This method returns the result of executing this code on success (or nil if no result or on failure), e.g. a JavaScript value such as a string, a number (integer or floating point), a boolean or JSON representation for non-primitive types such as arrays and objects. For example:
if (result = webview.run_script('document.getElementById('some_id').innerHTML'))
#... result contains the contents of the given element ...
# else: the element with this ID probably doesn't exist.
end
This function has a few platform-specific limitations:
- When using WebKit v1 in WXGTK2, retrieving the result of JavaScript execution is unsupported and this function will always return nil if output is non-null to indicate this. This functionality is fully supported when using WebKit v2 or later in WXGTK3.
- When using WebKit under macOS, code execution is limited to at most 10MiB of memory and 10 seconds of execution time.
- When using Chromium backend, retrieving the result of JavaScript execution is unsupported and this function will always return nil if output is non-null to indicate this.
- When using IE backend under MSW, scripts can only be executed when the current page is fully loaded (i.e. EVT_WEBVIEW_LOADED event was received). A script tag inside the page HTML is required in order to run JavaScript.
Also notice that with the IE backend converting JavaScript objects to JSON is not supported in the default emulation mode, it implements its own object-to-JSON conversion as a fallback for this case, however it is not as full-featured, well-tested or performing as the implementation of this functionality in the browser control itself, so it is recommended to use Wx::WEB::WebView::msw_set_ie_emulation_level to change emulation level to a more modern one in which JSON conversion is done by the control itself.
436 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 436 def run_script(javascript) end |
#run_script_async(javascript) ⇒ void
This method returns an undefined value.
Runs the given JavaScript code asynchronously and returns the result via a EVT_WEBVIEW_SCRIPT_RESULT.
The script result value can be retrieved via Wx::WEB::WebViewEvent#get_string. If the execution fails Wx::WEB::WebViewEvent#is_error will return true. In this case additional script execution error information maybe available via Wx::WEB::WebViewEvent#get_string.
The IE backend does not support async script execution.
450 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 450 def run_script_async(javascript) end |
#select_all ⇒ void
This method returns an undefined value.
Selects the entire page.
696 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 696 def select_all; end |
#set_editable(enable = true) ⇒ void Also known as: editable=
This method returns an undefined value.
Set the editable property of the web control.
Enabling allows the user to edit the page even if the contenteditable attribute is not set. The exact capabilities vary with the backend being used.
This is not implemented for macOS and the Edge backend.
901 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 901 def set_editable(enable=true) end |
#set_page(html, baseUrl) ⇒ void #set_page(html, baseUrl) ⇒ void
920 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 920 def set_page(*args) end |
#set_proxy(proxy) ⇒ Boolean Also known as: proxy=
Set the proxy to use for all requests.
The proxy string must be a valid proxy specification, e.g. http://my.local.proxy.corp:8080
Currently this function is only implemented in WebKit2, Edge and Chromium backends and only WebKit2 backend allows to set the proxy after creating the webview, so it is recommended to call it before #create:
webview = Wx::WEB::WebView.new
unless webview.set_proxy("http://127.0.0.1:8080")
Wx.log_warning("Setting proxy failed!")
end
webview.create(parent, Wx::ID_ANY)
true if proxy was set successfully or false if it failed, e.g. because this is not supported by the currently used backend.
964 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 964 def set_proxy(proxy) end |
#set_user_agent(userAgent) ⇒ Boolean Also known as: user_agent=
Specify a custom user agent string for the web view.
Returns true the user agent could be set. If your first request should already use the custom user agent please use two step creation and call #set_user_agent before #create.
This is not implemented for IE.
940 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 940 def set_user_agent(userAgent) end |
#set_zoom(zoom) ⇒ void Also known as: zoom=
This method returns an undefined value.
Set the zoom level of the page.
See #set_zoom_factor for more precise scaling other than the measured steps provided by Wx::WEB::WebViewZoom.
764 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 764 def set_zoom(zoom) end |
#set_zoom_factor(zoom) ⇒ void Also known as: zoom_factor=
This method returns an undefined value.
Set the zoom factor of the page.
zoom scale in IE will be converted into Wx::WEB::WebViewZoom levels for Wx::WEB::WebViewZoomType of Wx::WEB::WebViewZoomType::WEBVIEW_ZOOM_TYPE_TEXT.
776 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 776 def set_zoom_factor(zoom) end |
#set_zoom_type(zoomType) ⇒ void Also known as: zoom_type=
This method returns an undefined value.
Set how to interpret the zoom factor.
invoke #can_set_zoom_type first, some backends may not support all zoom types.
788 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 788 def set_zoom_type(zoomType) end |
#show_dev_tools ⇒ Boolean
Show the dev tools window.
Immediately open the dev tools window. Does nothing if this window was already open. Unlike #enable_access_to_dev_tools, which allows the user to open the dev tools window from the context menu, this function opens the same window programmatically. Please note that while #show_dev_tools can be used whether access to the dev tools from the context menu was enabled or not, in WebKit2GTK+ backend calling it also enables interactive access to the dev tools from the context menu as a side effect. true if the dev tools window is shown (even if it had been already shown before this function was called), false if it could not be shown for some reason, most likely because the backend does not provide this functionality.
This function is not implemented in the IE and WebKit (GTK/macOS) backends (but is implemented for WebKit2 GTK backend).
585 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 585 def show_dev_tools; end |
#stop ⇒ void
This method returns an undefined value.
Stop the current page loading process, if any.
May trigger an error event of type Wx::WEB::WebViewNavigationError::WEBVIEW_NAV_ERR_USER_CANCELLED. TODO: make Wx::WEB::WebViewNavigationError::WEBVIEW_NAV_ERR_USER_CANCELLED errors uniform across ports.
926 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 926 def stop; end |
#undo ⇒ void
This method returns an undefined value.
Undos the last action.
714 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 714 def undo; end |