Class: Wx::WEB::WebViewArchiveHandler

Inherits:
WebViewHandler show all
Defined in:
lib/wx/doc/gen/web/web_view_handler.rb

Overview

Note:

This class is untracked and should not be derived from nor instances extended!

A custom handler for the file scheme which also supports loading from archives.

The syntax for WebViewArchiveHandler differs from virtual file systems in the rest of wxWidgets by using a syntax such as scheme:///C:/example/docs.zip;protocol=zip/main.htm Currently the only supported protocol is zip.

Category: WebView

See Also:

Requires:

  • USE_WEBVIEW

Instance Method Summary collapse

Methods inherited from WebViewHandler

#get_name, #get_security_url, #get_virtual_host, #set_security_url, #set_virtual_host, #start_request

Constructor Details

#initialize(scheme) ⇒ Wx::WEB::WebViewArchiveHandler

Constructor.

Parameters:

  • scheme (String)


142
# File 'lib/wx/doc/gen/web/web_view_handler.rb', line 142

def initialize(scheme) end

Instance Method Details

#get_file(uri) ⇒ Wx::FSFile Also known as: file

A pointer to the file represented by uri.

Parameters:

  • uri (String)

Returns:



149
# File 'lib/wx/doc/gen/web/web_view_handler.rb', line 149

def get_file(uri) end