Class: Wx::WEB::WebViewZoomType
- Defined in:
- lib/wx/doc/gen/web/web_view.rb
Overview
The type of zooming that the web view control can perform.
Constant Summary collapse
- WEBVIEW_ZOOM_TYPE_LAYOUT =
The entire layout scales when zooming, including images.
Wx::WEB::WebViewZoomType.new(0)
- WEBVIEW_ZOOM_TYPE_TEXT =
Only the text changes in size when zooming, images and other layout elements retain their initial size.
Wx::WEB::WebViewZoomType.new(1)
Method Summary
Methods inherited from Enum
#!, #&, #<=>, [], #allbits?, #anybits?, #coerce, enumerators, #eql?, #initialize, #inspect, #integer?, #method_missing, #nobits?, non_distinct, #real?, set_non_distinct, #succ, #to_int, #to_s, #|, #~
Constructor Details
This class inherits a constructor from Wx::Enum
Dynamic Method Handling
This class handles dynamic methods through the method_missing method in the class Wx::Enum