Class: Wx::HTML::HtmlLinkInfo
- Defined in:
- lib/wx/doc/gen/html/html_cell.rb
Overview
This class is untracked and should not be derived from nor instances extended!
This class stores all necessary information about hypertext links (as represented by tag in HTML documents).
In current implementation it stores URL and target frame name.
Frames are not currently supported by Wx::HTML!
Category: Wx::HTML
Instance Method Summary collapse
-
#get_event ⇒ Wx::MouseEvent
(also: #event)
Return pointer to event that generated OnLinkClicked() event.
-
#get_href ⇒ String
(also: #href)
Return HREF value of the tag.
-
#get_html_cell ⇒ Wx::HTML::HtmlCell
(also: #html_cell)
Return pointer to the cell that was clicked.
- #get_target ⇒ String (also: #target)
-
#initialize(*args) ⇒ HtmlLinkInfo
constructor
A new instance of HtmlLinkInfo.
Methods inherited from Object
#clone, #dup, #is_same_as, #un_share
Constructor Details
#initialize ⇒ Wx::HTML::HtmlLinkInfo #initialize(href, target = ('')) ⇒ Wx::HTML::HtmlLinkInfo
Returns a new instance of HtmlLinkInfo.
299 |
# File 'lib/wx/doc/gen/html/html_cell.rb', line 299 def initialize(*args) end |
Instance Method Details
#get_event ⇒ Wx::MouseEvent Also known as: event
Return pointer to event that generated OnLinkClicked() event.
Valid only within Wx::HTML::HtmlWindow#on_link_clicked, nil otherwise.
305 |
# File 'lib/wx/doc/gen/html/html_cell.rb', line 305 def get_event; end |
#get_href ⇒ String Also known as: href
Return HREF value of the tag.
310 |
# File 'lib/wx/doc/gen/html/html_cell.rb', line 310 def get_href; end |
#get_html_cell ⇒ Wx::HTML::HtmlCell Also known as: html_cell
Return pointer to the cell that was clicked.
Valid only within Wx::HTML::HtmlWindow#on_link_clicked, nil otherwise.
317 |
# File 'lib/wx/doc/gen/html/html_cell.rb', line 317 def get_html_cell; end |
#get_target ⇒ String Also known as: target
322 |
# File 'lib/wx/doc/gen/html/html_cell.rb', line 322 def get_target; end |