Class: Wx::ItemAttr
- Inherits:
-
Object
- Object
- Wx::ItemAttr
- Defined in:
- lib/wx/doc/gen/list_ctrl.rb
Overview
Represents the attributes (colour, font, ...) of an item of a control with multiple items such as e.g.
Category: Data Structures
Instance Method Summary collapse
-
#==(other) ⇒ Boolean
Compare two item attributes for equality.
-
#get_background_colour ⇒ Wx::Colour, ...
(also: #background_colour)
Returns the currently set background colour.
-
#get_font ⇒ Wx::Font, Wx::FontInfo
(also: #font)
Returns the currently set font.
-
#get_text_colour ⇒ Wx::Colour, ...
(also: #text_colour)
Returns the currently set text colour.
-
#has_background_colour ⇒ Boolean
(also: #has_background_colour?)
Returns true if the currently set background colour is valid.
-
#has_colours ⇒ Boolean
(also: #has_colours?)
Returns true if either text or background colour is set.
-
#has_font ⇒ Boolean
(also: #has_font?)
Returns true if the currently set font is valid.
-
#has_text_colour ⇒ Boolean
(also: #has_text_colour?)
Returns true if the currently set text colour is valid.
-
#initialize(*args) ⇒ ItemAttr
constructor
A new instance of ItemAttr.
-
#is_default ⇒ Boolean
(also: #default?)
Returns true if this object has no custom attributes set.
-
#set_background_colour(colour) ⇒ void
(also: #background_colour=)
Sets a new background colour.
-
#set_font(font) ⇒ void
(also: #font=)
Sets a new font.
-
#set_text_colour(colour) ⇒ void
(also: #text_colour=)
Sets a new text colour.
Constructor Details
#initialize ⇒ Wx::ItemAttr #initialize(colText, colBack, font) ⇒ Wx::ItemAttr
Returns a new instance of ItemAttr.
1587 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1587 def initialize(*args) end |
Instance Method Details
#==(other) ⇒ Boolean
Compare two item attributes for equality.
1592 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1592 def ==(other) end |
#get_background_colour ⇒ Wx::Colour, ... Also known as: background_colour
Returns the currently set background colour.
1596 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1596 def get_background_colour; end |
#get_font ⇒ Wx::Font, Wx::FontInfo Also known as: font
Returns the currently set font.
1601 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1601 def get_font; end |
#get_text_colour ⇒ Wx::Colour, ... Also known as: text_colour
Returns the currently set text colour.
1606 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1606 def get_text_colour; end |
#has_background_colour ⇒ Boolean Also known as: has_background_colour?
Returns true if the currently set background colour is valid.
1611 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1611 def has_background_colour; end |
#has_colours ⇒ Boolean Also known as: has_colours?
Returns true if either text or background colour is set.
1620 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1620 def has_colours; end |
#has_font ⇒ Boolean Also known as: has_font?
Returns true if the currently set font is valid.
1625 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1625 def has_font; end |
#has_text_colour ⇒ Boolean Also known as: has_text_colour?
Returns true if the currently set text colour is valid.
1630 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1630 def has_text_colour; end |
#is_default ⇒ Boolean Also known as: default?
Returns true if this object has no custom attributes set.
1635 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1635 def is_default; end |
#set_background_colour(colour) ⇒ void Also known as: background_colour=
This method returns an undefined value.
Sets a new background colour.
1641 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1641 def set_background_colour(colour) end |
#set_font(font) ⇒ void Also known as: font=
This method returns an undefined value.
Sets a new font.
1647 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1647 def set_font(font) end |
#set_text_colour(colour) ⇒ void Also known as: text_colour=
This method returns an undefined value.
Sets a new text colour.
1653 |
# File 'lib/wx/doc/gen/list_ctrl.rb', line 1653 def set_text_colour(colour) end |