Class: Wx::RT::SharedEvtHandler
- Inherits:
-
Object
- Object
- Wx::RT::SharedEvtHandler
- Defined in:
- lib/wx/doc/rt/shared_event_handler.rb
Overview
This class provides a threadsafe (Ractor shareable) reference to a Wx:EvtHandler providing only 2 methods; #clone and #queue_event
Instance Method Summary collapse
-
#clone ⇒ Wx::RT::SharedEvtHandler
Returns a cloned instance referencing the same EvtHandler.
-
#queue_event(evt) ⇒ void
Essentially the same functionality as EvtHandler#queue_event except that this method only accepts ThreadEvent or derived instances.
Instance Method Details
#clone ⇒ Wx::RT::SharedEvtHandler
Returns a cloned instance referencing the same EvtHandler.
24 |
# File 'lib/wx/doc/rt/shared_event_handler.rb', line 24 def clone; end |
#queue_event(evt) ⇒ void
Note that this event will not maintain any Ruby state, i.e. the actual Ruby instance and/or any instance variables thereof will not be transferred through the event messaging system. Only state managed by the wrapped C++ event instance will persist.
This method returns an undefined value.
Essentially the same functionality as EvtHandler#queue_event except that this method only accepts ThreadEvent or derived instances.
33 |
# File 'lib/wx/doc/rt/shared_event_handler.rb', line 33 def queue_event(evt); end |