Class: Wx::RTC::RichTextAttr
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_object.rb
Overview
This class is untracked and should not be derived from nor instances extended!
A class representing enhanced attributes for rich text objects.
This adds a TextBoxAttr member to the basic TextAttr class.
Category: Rich Text
Instance Method Summary collapse
-
#==(attr) ⇒ Boolean
Equality test.
-
#apply(style, compareWith = nil) ⇒ Boolean
Merges the given attributes.
-
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
-
#copy(attr) ⇒ void
Copy function.
-
#eq_partial(attr, weakTest = true) ⇒ Boolean
Partial equality test.
- #get_text_box_attr ⇒ Wx::RTC::TextBoxAttr (also: #text_box_attr)
-
#initialize(*args) ⇒ RichTextAttr
constructor
A new instance of RichTextAttr.
-
#is_default ⇒ Boolean
(also: #default?)
Returns true if no attributes are set.
-
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
-
#set_text_box_attr(attr) ⇒ void
(also: #text_box_attr=)
Set the text box attributes.
Methods inherited from TextAttr
#get_alignment, #get_background_colour, #get_bullet_font, #get_bullet_name, #get_bullet_number, #get_bullet_style, #get_bullet_text, #get_character_style_name, #get_flags, #get_font, #get_font_attributes, #get_font_encoding, #get_font_face_name, #get_font_family, #get_font_size, #get_font_style, #get_font_underlined, #get_font_weight, #get_left_indent, #get_left_sub_indent, #get_line_spacing, #get_list_style_name, #get_outline_level, #get_paragraph_spacing_after, #get_paragraph_spacing_before, #get_paragraph_style_name, #get_right_indent, #get_tabs, #get_text_colour, #get_text_effect_flags, #get_text_effects, #get_underline_colour, #get_underline_type, #get_url, #has_alignment, #has_background_colour, #has_bullet_name, #has_bullet_number, #has_bullet_style, #has_bullet_text, #has_character_style_name, #has_flag, #has_font, #has_font_encoding, #has_font_face_name, #has_font_family, #has_font_italic, #has_font_pixel_size, #has_font_point_size, #has_font_size, #has_font_underlined, #has_font_weight, #has_left_indent, #has_line_spacing, #has_list_style_name, #has_outline_level, #has_page_break, #has_paragraph_spacing_after, #has_paragraph_spacing_before, #has_paragraph_style_name, #has_right_indent, #has_tabs, #has_text_colour, #has_text_effects, #has_url, #is_character_style, #is_paragraph_style, #merge, #set_alignment, #set_background_colour, #set_bullet_font, #set_bullet_name, #set_bullet_number, #set_bullet_style, #set_bullet_text, #set_character_style_name, #set_flags, #set_font, #set_font_encoding, #set_font_face_name, #set_font_family, #set_font_pixel_size, #set_font_point_size, #set_font_size, #set_font_style, #set_font_underlined, #set_font_weight, #set_left_indent, #set_line_spacing, #set_list_style_name, #set_outline_level, #set_page_break, #set_paragraph_spacing_after, #set_paragraph_spacing_before, #set_paragraph_style_name, #set_right_indent, #set_tabs, #set_text_colour, #set_text_effect_flags, #set_text_effects, #set_url
Constructor Details
#initialize(attr) ⇒ Wx::RTC::RichTextAttr #initialize(attr) ⇒ Wx::RTC::RichTextAttr #initialize ⇒ Wx::RTC::RichTextAttr
Returns a new instance of RichTextAttr.
1468 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1468 def initialize(*args) end |
Instance Method Details
#==(attr) ⇒ Boolean
Equality test.
1478 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1478 def ==(attr) end |
#apply(style, compareWith = nil) ⇒ Boolean
Merges the given attributes.
If compareWith is non-null, then it will be used to mask out those attributes that are the same in style and compareWith, for situations where we don't want to explicitly set inherited attributes.
1494 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1494 def apply(style, compareWith=nil) end |
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
This method returns an undefined value.
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
1501 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1501 def collect_common_attributes(attr, clashingAttr, absentAttr) end |
#copy(attr) ⇒ void
This method returns an undefined value.
Copy function.
1473 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1473 def copy(attr) end |
#eq_partial(attr, weakTest = true) ⇒ Boolean
Partial equality test.
If weakTest is true, attributes of this object do not have to be present if those attributes of attr are present. If weakTest is false, the function will fail if an attribute is present in attr but not in this object.
1486 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1486 def eq_partial(attr, weakTest=true) end |
#get_text_box_attr ⇒ Wx::RTC::TextBoxAttr Also known as: text_box_attr
1509 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1509 def get_text_box_attr; end |
#is_default ⇒ Boolean Also known as: default?
Returns true if no attributes are set.
1520 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1520 def is_default; end |
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
1506 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1506 def remove_style(attr) end |
#set_text_box_attr(attr) ⇒ void Also known as: text_box_attr=
This method returns an undefined value.
Set the text box attributes.
1515 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1515 def set_text_box_attr(attr) end |