Class: Wx::RTC::TextAttrBorder
- Inherits:
-
Object
- Object
- Wx::RTC::TextAttrBorder
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_object.rb
Overview
This class is untracked and should not be derived from nor instances extended!
A class representing a rich text object border.
Category: Rich Text
Instance Method Summary collapse
-
#==(border) ⇒ Boolean
Equality operator.
-
#add_flag(flag) ⇒ void
Adds a border flag.
-
#apply(border, compareWith = nil) ⇒ Boolean
Applies the border to this object, but not if the same as compareWith.
-
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
-
#eq_partial(border, weakTest = true) ⇒ Boolean
Partial equality test.
-
#get_colour ⇒ Wx::Colour
(also: #colour)
Gets the colour.
-
#get_colour_long ⇒ Integer
(also: #colour_long)
Gets the colour as a long.
-
#get_flags ⇒ Integer
(also: #flags)
Returns the border flags.
-
#get_style ⇒ Integer
(also: #style)
Gets the border style.
- #get_width ⇒ Wx::RTC::TextAttrDimension (also: #width)
-
#has_colour ⇒ Boolean
(also: #has_colour?)
True if the border has a valid colour.
-
#has_style ⇒ Boolean
(also: #has_style?)
True if the border has a valid style.
-
#has_width ⇒ Boolean
(also: #has_width?)
True if the border has a valid width.
-
#initialize ⇒ Wx::RTC::TextAttrBorder
constructor
Default constructor.
-
#is_default ⇒ Boolean
(also: #default?)
True if the border has no attributes set.
-
#is_valid ⇒ Boolean
(also: #valid?)
True if the border is valid.
-
#make_valid ⇒ void
Set the valid flag for this border.
-
#remove_flag(flag) ⇒ void
Removes a border flag.
-
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
-
#reset ⇒ void
Resets the border style, colour, width and flags.
- #set_colour(*args) ⇒ Object (also: #colour=)
-
#set_flags(flags) ⇒ void
(also: #flags=)
Sets the border flags.
-
#set_style(style) ⇒ void
(also: #style=)
Sets the border style.
- #set_width(*args) ⇒ Object (also: #width=)
Constructor Details
#initialize ⇒ Wx::RTC::TextAttrBorder
Default constructor.
2280 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2280 def initialize; end |
Instance Method Details
#==(border) ⇒ Boolean
Equality operator.
2285 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2285 def ==(border) end |
#add_flag(flag) ⇒ void
This method returns an undefined value.
Adds a border flag.
2408 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2408 def add_flag(flag) end |
#apply(border, compareWith = nil) ⇒ Boolean
Applies the border to this object, but not if the same as compareWith.
2303 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2303 def apply(border, compareWith=nil) end |
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
This method returns an undefined value.
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
2315 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2315 def collect_common_attributes(attr, clashingAttr, absentAttr) end |
#eq_partial(border, weakTest = true) ⇒ Boolean
Partial equality test.
If weakTest is true, attributes of this object do not have to be present if those attributes of border are present. If weakTest is false, the function will fail if an attribute is present in border but not in this object.
2297 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2297 def eq_partial(border, weakTest=true) end |
#get_colour ⇒ Wx::Colour Also known as: colour
Gets the colour.
2346 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2346 def get_colour; end |
#get_colour_long ⇒ Integer Also known as: colour_long
Gets the colour as a long.
2341 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2341 def get_colour_long; end |
#get_flags ⇒ Integer Also known as: flags
Returns the border flags.
2396 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2396 def get_flags; end |
#get_style ⇒ Integer Also known as: style
Gets the border style.
2325 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2325 def get_style; end |
#get_width ⇒ Wx::RTC::TextAttrDimension Also known as: width
2350 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2350 def get_width; end |
#has_colour ⇒ Boolean Also known as: has_colour?
True if the border has a valid colour.
2372 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2372 def has_colour; end |
#has_style ⇒ Boolean Also known as: has_style?
True if the border has a valid style.
2367 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2367 def has_style; end |
#has_width ⇒ Boolean Also known as: has_width?
True if the border has a valid width.
2377 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2377 def has_width; end |
#is_default ⇒ Boolean Also known as: default?
True if the border has no attributes set.
2387 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2387 def is_default; end |
#is_valid ⇒ Boolean Also known as: valid?
True if the border is valid.
2382 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2382 def is_valid; end |
#make_valid ⇒ void
This method returns an undefined value.
Set the valid flag for this border.
2392 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2392 def make_valid; end |
#remove_flag(flag) ⇒ void
This method returns an undefined value.
Removes a border flag.
2413 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2413 def remove_flag(flag) end |
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
2308 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2308 def remove_style(attr) end |
#reset ⇒ void
This method returns an undefined value.
Resets the border style, colour, width and flags.
2289 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2289 def reset; end |
#set_colour(colour) ⇒ void #set_colour(colour) ⇒ void Also known as: colour=
2336 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2336 def set_colour(*args) end |
#set_flags(flags) ⇒ void Also known as: flags=
This method returns an undefined value.
Sets the border flags.
2402 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2402 def set_flags(flags) end |
#set_style(style) ⇒ void Also known as: style=
This method returns an undefined value.
Sets the border style.
2320 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2320 def set_style(style) end |
#set_width(width) ⇒ void #set_width(value, units = Wx::RTC::TextAttrUnits::TEXT_ATTR_UNITS_TENTHS_MM) ⇒ void Also known as: width=
2362 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 2362 def set_width(*args) end |