Class: Wx::RTC::TextBoxAttr
- Inherits:
-
Object
- Object
- Wx::RTC::TextBoxAttr
- Defined in:
- lib/wx/doc/gen/rtc/rich_text_object.rb
Overview
This class is untracked and should not be derived from nor instances extended!
A class representing the box attributes of a rich text object.
Category: Rich Text
Instance Method Summary collapse
-
#==(attr) ⇒ Boolean
Equality test.
-
#add_flag(flag) ⇒ void
Adds this flag.
-
#apply(style, compareWith = nil) ⇒ Boolean
Merges the given attributes.
-
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
-
#eq_partial(attr, weakTest = true) ⇒ Boolean
Partial equality test, ignoring unset attributes.
- #get_border ⇒ Wx::RTC::TextAttrBorders (also: #border)
- #get_bottom ⇒ Wx::RTC::TextAttrDimension (also: #bottom)
- #get_bottom_border ⇒ Wx::RTC::TextAttrBorder (also: #bottom_border)
- #get_bottom_margin ⇒ Wx::RTC::TextAttrDimension (also: #bottom_margin)
- #get_bottom_outline ⇒ Wx::RTC::TextAttrBorder (also: #bottom_outline)
- #get_bottom_padding ⇒ Wx::RTC::TextAttrDimension (also: #bottom_padding)
-
#get_box_style_name ⇒ Wx::String
(also: #box_style_name)
Returns the box style name.
-
#get_clear_mode ⇒ Wx::TextBoxAttrClearStyle
(also: #clear_mode)
Returns the clear mode - whether to wrap text after object.
-
#get_collapse_borders ⇒ Wx::TextBoxAttrCollapseMode
(also: #collapse_borders)
Returns the collapse mode - whether to collapse borders.
-
#get_corner_radius ⇒ Wx::RTC::TextAttrDimension
(also: #corner_radius)
Returns the corner radius value.
-
#get_flags ⇒ Integer
(also: #flags)
Returns the flags.
-
#get_float_mode ⇒ Wx::TextBoxAttrFloatStyle
(also: #float_mode)
Returns the float mode.
- #get_height ⇒ Wx::RTC::TextAttrDimension (also: #height)
- #get_left ⇒ Wx::RTC::TextAttrDimension (also: #left)
- #get_left_border ⇒ Wx::RTC::TextAttrBorder (also: #left_border)
- #get_left_margin ⇒ Wx::RTC::TextAttrDimension (also: #left_margin)
- #get_left_outline ⇒ Wx::RTC::TextAttrBorder (also: #left_outline)
- #get_left_padding ⇒ Wx::RTC::TextAttrDimension (also: #left_padding)
- #get_margins ⇒ Wx::RTC::TextAttrDimensions (also: #margins)
- #get_max_size ⇒ Wx::RTC::TextAttrSize (also: #max_size)
- #get_min_size ⇒ Wx::RTC::TextAttrSize (also: #min_size)
- #get_outline ⇒ Wx::RTC::TextAttrBorders (also: #outline)
- #get_padding ⇒ Wx::RTC::TextAttrDimensions (also: #padding)
- #get_position ⇒ Wx::RTC::TextAttrDimensions (also: #position)
- #get_right ⇒ Wx::RTC::TextAttrDimension (also: #right)
- #get_right_border ⇒ Wx::RTC::TextAttrBorder (also: #right_border)
- #get_right_margin ⇒ Wx::RTC::TextAttrDimension (also: #right_margin)
- #get_right_outline ⇒ Wx::RTC::TextAttrBorder (also: #right_outline)
- #get_right_padding ⇒ Wx::RTC::TextAttrDimension (also: #right_padding)
- #get_shadow ⇒ Wx::RTC::TextAttrShadow (also: #shadow)
- #get_size ⇒ Wx::RTC::TextAttrSize (also: #size)
- #get_top ⇒ Wx::RTC::TextAttrDimension (also: #top)
- #get_top_border ⇒ Wx::RTC::TextAttrBorder (also: #top_border)
- #get_top_margin ⇒ Wx::RTC::TextAttrDimension (also: #top_margin)
- #get_top_outline ⇒ Wx::RTC::TextAttrBorder (also: #top_outline)
- #get_top_padding ⇒ Wx::RTC::TextAttrDimension (also: #top_padding)
-
#get_vertical_alignment ⇒ Wx::TextBoxAttrVerticalAlignment
(also: #vertical_alignment)
Returns the vertical alignment.
-
#get_whitespace_mode ⇒ Wx::TextBoxAttrWhitespaceMode
(also: #whitespace_mode)
Returns the whitespace mode.
- #get_width ⇒ Wx::RTC::TextAttrDimension (also: #width)
-
#has_box_style_name ⇒ Boolean
(also: #has_box_style_name?)
Returns true if the box style name is present.
-
#has_clear_mode ⇒ Boolean
(also: #has_clear_mode?)
Returns true if we have a clear flag.
-
#has_collapse_borders ⇒ Boolean
(also: #has_collapse_borders?)
Returns true if the collapse borders flag is present.
-
#has_corner_radius ⇒ Boolean
(also: #has_corner_radius?)
Returns true if the corner radius flag is present.
-
#has_flag(flag) ⇒ Boolean
(also: #has_flag?)
Is this flag present?.
-
#has_float_mode ⇒ Boolean
(also: #has_float_mode?)
Returns true if float mode is active.
-
#has_vertical_alignment ⇒ Boolean
(also: #has_vertical_alignment?)
Returns true if a vertical alignment flag is present.
-
#has_whitespace_mode ⇒ Boolean
(also: #has_whitespace_mode?)
Returns true if the whitespace flag is present.
-
#init ⇒ void
Initialises this object.
-
#initialize(*args) ⇒ TextBoxAttr
constructor
A new instance of TextBoxAttr.
-
#is_default ⇒ Boolean
(also: #default?)
Returns true if no attributes are set.
-
#is_floating ⇒ Boolean
(also: #floating?)
Returns true if this object is floating.
-
#remove_flag(flag) ⇒ void
Removes this flag.
-
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
-
#reset ⇒ void
Resets this object.
-
#set_box_style_name(name) ⇒ void
(also: #box_style_name=)
Sets the box style name.
-
#set_clear_mode(mode) ⇒ void
(also: #clear_mode=)
Set the clear mode.
-
#set_collapse_borders(collapse) ⇒ void
(also: #collapse_borders=)
Sets the collapse mode - whether to collapse borders.
-
#set_corner_radius(dim) ⇒ void
(also: #corner_radius=)
Sets the corner radius value.
-
#set_flags(flags) ⇒ void
(also: #flags=)
Sets the flags.
-
#set_float_mode(mode) ⇒ void
(also: #float_mode=)
Sets the float mode.
-
#set_max_size(sz) ⇒ void
(also: #max_size=)
Sets the object maximum size.
-
#set_min_size(sz) ⇒ void
(also: #min_size=)
Sets the object minimum size.
-
#set_size(sz) ⇒ void
(also: #size=)
Sets the object size.
-
#set_vertical_alignment(verticalAlignment) ⇒ void
(also: #vertical_alignment=)
Sets the vertical alignment.
-
#set_whitespace_mode(whitespace) ⇒ void
(also: #whitespace_mode=)
Sets the whitespace mode.
Constructor Details
#initialize ⇒ Wx::RTC::TextBoxAttr #initialize(attr) ⇒ Wx::RTC::TextBoxAttr
Returns a new instance of TextBoxAttr.
1544 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1544 def initialize(*args) end |
Instance Method Details
#==(attr) ⇒ Boolean
Equality test.
1557 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1557 def ==(attr) end |
#add_flag(flag) ⇒ void
This method returns an undefined value.
Adds this flag.
1612 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1612 def add_flag(flag) end |
#apply(style, compareWith = nil) ⇒ Boolean
Merges the given attributes.
If compareWith is non-null, then it will be used to mask out those attributes that are the same in style and compareWith, for situations where we don't want to explicitly set inherited attributes.
1573 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1573 def apply(style, compareWith=nil) end |
#collect_common_attributes(attr, clashingAttr, absentAttr) ⇒ void
This method returns an undefined value.
Collects the attributes that are common to a range of content, building up a note of which attributes are absent in some objects and which clash in some objects.
1580 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1580 def collect_common_attributes(attr, clashingAttr, absentAttr) end |
#eq_partial(attr, weakTest = true) ⇒ Boolean
Partial equality test, ignoring unset attributes.
If weakTest is true, attributes of this object do not have to be present if those attributes of attr are present. If weakTest is false, the function will fail if an attribute is present in attr but not in this object.
1565 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1565 def eq_partial(attr, weakTest=true) end |
#get_border ⇒ Wx::RTC::TextAttrBorders Also known as: border
1785 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1785 def get_border; end |
#get_bottom ⇒ Wx::RTC::TextAttrDimension Also known as: bottom
1761 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1761 def get_bottom; end |
#get_bottom_border ⇒ Wx::RTC::TextAttrBorder Also known as: bottom_border
1801 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1801 def get_bottom_border; end |
#get_bottom_margin ⇒ Wx::RTC::TextAttrDimension Also known as: bottom_margin
1741 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1741 def get_bottom_margin; end |
#get_bottom_outline ⇒ Wx::RTC::TextAttrBorder Also known as: bottom_outline
1821 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1821 def get_bottom_outline; end |
#get_bottom_padding ⇒ Wx::RTC::TextAttrDimension Also known as: bottom_padding
1781 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1781 def get_bottom_padding; end |
#get_box_style_name ⇒ Wx::String Also known as: box_style_name
Returns the box style name.
1864 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1864 def get_box_style_name; end |
#get_clear_mode ⇒ Wx::TextBoxAttrClearStyle Also known as: clear_mode
Returns the clear mode - whether to wrap text after object.
Currently unimplemented.
1644 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1644 def get_clear_mode; end |
#get_collapse_borders ⇒ Wx::TextBoxAttrCollapseMode Also known as: collapse_borders
Returns the collapse mode - whether to collapse borders.
1662 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1662 def get_collapse_borders; end |
#get_corner_radius ⇒ Wx::RTC::TextAttrDimension Also known as: corner_radius
Returns the corner radius value.
1699 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1699 def get_corner_radius; end |
#get_flags ⇒ Integer Also known as: flags
Returns the flags.
1595 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1595 def get_flags; end |
#get_float_mode ⇒ Wx::TextBoxAttrFloatStyle Also known as: float_mode
Returns the float mode.
1621 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1621 def get_float_mode; end |
#get_height ⇒ Wx::RTC::TextAttrDimension Also known as: height
1859 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1859 def get_height; end |
#get_left ⇒ Wx::RTC::TextAttrDimension Also known as: left
1749 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1749 def get_left; end |
#get_left_border ⇒ Wx::RTC::TextAttrBorder Also known as: left_border
1789 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1789 def get_left_border; end |
#get_left_margin ⇒ Wx::RTC::TextAttrDimension Also known as: left_margin
1729 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1729 def get_left_margin; end |
#get_left_outline ⇒ Wx::RTC::TextAttrBorder Also known as: left_outline
1809 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1809 def get_left_outline; end |
#get_left_padding ⇒ Wx::RTC::TextAttrDimension Also known as: left_padding
1769 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1769 def get_left_padding; end |
#get_margins ⇒ Wx::RTC::TextAttrDimensions Also known as: margins
1725 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1725 def get_margins; end |
#get_max_size ⇒ Wx::RTC::TextAttrSize Also known as: max_size
1833 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1833 def get_max_size; end |
#get_min_size ⇒ Wx::RTC::TextAttrSize Also known as: min_size
1829 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1829 def get_min_size; end |
#get_outline ⇒ Wx::RTC::TextAttrBorders Also known as: outline
1805 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1805 def get_outline; end |
#get_padding ⇒ Wx::RTC::TextAttrDimensions Also known as: padding
1765 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1765 def get_padding; end |
#get_position ⇒ Wx::RTC::TextAttrDimensions Also known as: position
1745 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1745 def get_position; end |
#get_right ⇒ Wx::RTC::TextAttrDimension Also known as: right
1753 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1753 def get_right; end |
#get_right_border ⇒ Wx::RTC::TextAttrBorder Also known as: right_border
1797 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1797 def get_right_border; end |
#get_right_margin ⇒ Wx::RTC::TextAttrDimension Also known as: right_margin
1733 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1733 def get_right_margin; end |
#get_right_outline ⇒ Wx::RTC::TextAttrBorder Also known as: right_outline
1817 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1817 def get_right_outline; end |
#get_right_padding ⇒ Wx::RTC::TextAttrDimension Also known as: right_padding
1773 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1773 def get_right_padding; end |
#get_shadow ⇒ Wx::RTC::TextAttrShadow Also known as: shadow
1879 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1879 def get_shadow; end |
#get_size ⇒ Wx::RTC::TextAttrSize Also known as: size
1825 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1825 def get_size; end |
#get_top ⇒ Wx::RTC::TextAttrDimension Also known as: top
1757 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1757 def get_top; end |
#get_top_border ⇒ Wx::RTC::TextAttrBorder Also known as: top_border
1793 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1793 def get_top_border; end |
#get_top_margin ⇒ Wx::RTC::TextAttrDimension Also known as: top_margin
1737 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1737 def get_top_margin; end |
#get_top_outline ⇒ Wx::RTC::TextAttrBorder Also known as: top_outline
1813 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1813 def get_top_outline; end |
#get_top_padding ⇒ Wx::RTC::TextAttrDimension Also known as: top_padding
1777 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1777 def get_top_padding; end |
#get_vertical_alignment ⇒ Wx::TextBoxAttrVerticalAlignment Also known as: vertical_alignment
Returns the vertical alignment.
1710 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1710 def get_vertical_alignment; end |
#get_whitespace_mode ⇒ Wx::TextBoxAttrWhitespaceMode Also known as: whitespace_mode
Returns the whitespace mode.
1678 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1678 def get_whitespace_mode; end |
#get_width ⇒ Wx::RTC::TextAttrDimension Also known as: width
1855 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1855 def get_width; end |
#has_box_style_name ⇒ Boolean Also known as: has_box_style_name?
Returns true if the box style name is present.
1875 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1875 def has_box_style_name; end |
#has_clear_mode ⇒ Boolean Also known as: has_clear_mode?
Returns true if we have a clear flag.
1657 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1657 def has_clear_mode; end |
#has_collapse_borders ⇒ Boolean Also known as: has_collapse_borders?
Returns true if the collapse borders flag is present.
1673 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1673 def has_collapse_borders; end |
#has_corner_radius ⇒ Boolean Also known as: has_corner_radius?
Returns true if the corner radius flag is present.
1694 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1694 def has_corner_radius; end |
#has_flag(flag) ⇒ Boolean Also known as: has_flag?
Is this flag present?
1601 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1601 def has_flag(flag) end |
#has_float_mode ⇒ Boolean Also known as: has_float_mode?
Returns true if float mode is active.
1632 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1632 def has_float_mode; end |
#has_vertical_alignment ⇒ Boolean Also known as: has_vertical_alignment?
Returns true if a vertical alignment flag is present.
1721 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1721 def has_vertical_alignment; end |
#has_whitespace_mode ⇒ Boolean Also known as: has_whitespace_mode?
Returns true if the whitespace flag is present.
1689 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1689 def has_whitespace_mode; end |
#init ⇒ void
This method returns an undefined value.
Initialises this object.
1548 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1548 def init; end |
#is_default ⇒ Boolean Also known as: default?
Returns true if no attributes are set.
1616 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1616 def is_default; end |
#is_floating ⇒ Boolean Also known as: floating?
Returns true if this object is floating.
1637 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1637 def is_floating; end |
#remove_flag(flag) ⇒ void
This method returns an undefined value.
Removes this flag.
1607 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1607 def remove_flag(flag) end |
#remove_style(attr) ⇒ Boolean
Removes the specified attributes from this object.
1585 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1585 def remove_style(attr) end |
#reset ⇒ void
This method returns an undefined value.
Resets this object.
1552 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1552 def reset; end |
#set_box_style_name(name) ⇒ void Also known as: box_style_name=
This method returns an undefined value.
Sets the box style name.
1870 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1870 def set_box_style_name(name) end |
#set_clear_mode(mode) ⇒ void Also known as: clear_mode=
This method returns an undefined value.
Set the clear mode.
Currently unimplemented.
1652 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1652 def set_clear_mode(mode) end |
#set_collapse_borders(collapse) ⇒ void Also known as: collapse_borders=
This method returns an undefined value.
Sets the collapse mode - whether to collapse borders.
1668 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1668 def set_collapse_borders(collapse) end |
#set_corner_radius(dim) ⇒ void Also known as: corner_radius=
This method returns an undefined value.
Sets the corner radius value.
1705 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1705 def set_corner_radius(dim) end |
#set_flags(flags) ⇒ void Also known as: flags=
This method returns an undefined value.
Sets the flags.
1590 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1590 def set_flags(flags) end |
#set_float_mode(mode) ⇒ void Also known as: float_mode=
This method returns an undefined value.
Sets the float mode.
1627 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1627 def set_float_mode(mode) end |
#set_max_size(sz) ⇒ void Also known as: max_size=
This method returns an undefined value.
Sets the object maximum size.
1851 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1851 def set_max_size(sz) end |
#set_min_size(sz) ⇒ void Also known as: min_size=
This method returns an undefined value.
Sets the object minimum size.
1845 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1845 def set_min_size(sz) end |
#set_size(sz) ⇒ void Also known as: size=
This method returns an undefined value.
Sets the object size.
1839 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1839 def set_size(sz) end |
#set_vertical_alignment(verticalAlignment) ⇒ void Also known as: vertical_alignment=
This method returns an undefined value.
Sets the vertical alignment.
1716 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1716 def set_vertical_alignment(verticalAlignment) end |
#set_whitespace_mode(whitespace) ⇒ void Also known as: whitespace_mode=
This method returns an undefined value.
Sets the whitespace mode.
1684 |
# File 'lib/wx/doc/gen/rtc/rich_text_object.rb', line 1684 def set_whitespace_mode(whitespace) end |