Class: Wx::STC::StyledTextEvent
- Inherits:
-
CommandEvent
- Object
- Object
- Event
- CommandEvent
- Wx::STC::StyledTextEvent
- Defined in:
- lib/wx/doc/gen/stc/styled_text_event.rb
Overview
The type of events sent from StyledTextCtrl.
Events using this class
The following event-handler methods redirect the events to member method or handler blocks for StyledTextEvent events. Event handler methods:
EvtHandler#evt_stc_autocomp_cancelled(id, meth = nil, &block): Process a EVT_STC_AUTOCOMP_CANCELLED event.
EvtHandler#evt_stc_autocomp_char_deleted(id, meth = nil, &block): Process a EVT_STC_AUTOCOMP_CHAR_DELETED event.
EvtHandler#evt_stc_autocomp_completed(id, meth = nil, &block): Process a EVT_STC_AUTOCOMP_COMPLETED event.
EvtHandler#evt_stc_autocomp_selection(id, meth = nil, &block): Process a EVT_STC_AUTOCOMP_SELECTION event.
EvtHandler#evt_stc_autocomp_selection_change(id, meth = nil, &block): Process a EVT_STC_AUTOCOMP_SELECTION_CHANGE event.
EvtHandler#evt_stc_calltip_click(id, meth = nil, &block): Process a EVT_STC_CALLTIP_CLICK event.
EvtHandler#evt_stc_change(id, meth = nil, &block): Process a EVT_STC_CHANGE event.
EvtHandler#evt_stc_charadded(id, meth = nil, &block): Process a EVT_STC_CHARADDED event.
EvtHandler#evt_stc_clipboard_copy(id, meth = nil, &block): Process a EVT_STC_CLIPBOARD_COPY event.
EvtHandler#evt_stc_clipboard_paste(id, meth = nil, &block): Process a EVT_STC_CLIPBOARD_PASTE event.
EvtHandler#evt_stc_do_drop(id, meth = nil, &block): Process a EVT_STC_DO_DROP event.
EvtHandler#evt_stc_doubleclick(id, meth = nil, &block): Process a EVT_STC_DOUBLECLICK event.
EvtHandler#evt_stc_drag_over(id, meth = nil, &block): Process a EVT_STC_DRAG_OVER event.
EvtHandler#evt_stc_dwellend(id, meth = nil, &block): Process a EVT_STC_DWELLEND event.
EvtHandler#evt_stc_dwellstart(id, meth = nil, &block): Process a EVT_STC_DWELLSTART event.
EvtHandler#evt_stc_hotspot_click(id, meth = nil, &block): Process a EVT_STC_HOTSPOT_CLICK event.
EvtHandler#evt_stc_hotspot_dclick(id, meth = nil, &block): Process a EVT_STC_HOTSPOT_DCLICK event.
EvtHandler#evt_stc_hotspot_release_click(id, meth = nil, &block): Process a EVT_STC_HOTSPOT_RELEASE_CLICK event.
EvtHandler#evt_stc_indicator_click(id, meth = nil, &block): Process a EVT_STC_INDICATOR_CLICK event.
EvtHandler#evt_stc_indicator_release(id, meth = nil, &block): Process a EVT_STC_INDICATOR_RELEASE event.
EvtHandler#evt_stc_macrorecord(id, meth = nil, &block): Process a EVT_STC_MACRORECORD event.
EvtHandler#evt_stc_margin_right_click(id, meth = nil, &block): Process a EVT_STC_MARGIN_RIGHT_CLICK event.
EvtHandler#evt_stc_marginclick(id, meth = nil, &block): Process a EVT_STC_MARGINCLICK event.
EvtHandler#evt_stc_modified(id, meth = nil, &block): Process a EVT_STC_MODIFIED event.
EvtHandler#evt_stc_needshown(id, meth = nil, &block): Process a EVT_STC_NEEDSHOWN event.
EvtHandler#evt_stc_painted(id, meth = nil, &block): Process a EVT_STC_PAINTED event.
EvtHandler#evt_stc_romodifyattempt(id, meth = nil, &block): Process a EVT_STC_ROMODIFYATTEMPT event.
EvtHandler#evt_stc_savepointleft(id, meth = nil, &block): Process a EVT_STC_SAVEPOINTLEFT event.
EvtHandler#evt_stc_savepointreached(id, meth = nil, &block): Process a EVT_STC_SAVEPOINTREACHED event.
EvtHandler#evt_stc_start_drag(id, meth = nil, &block): Process a EVT_STC_START_DRAG event.
EvtHandler#evt_stc_styleneeded(id, meth = nil, &block): Process a EVT_STC_STYLENEEDED event.
EvtHandler#evt_stc_updateui(id, meth = nil, &block): Process a EVT_STC_UPDATEUI event.
EvtHandler#evt_stc_userlistselection(id, meth = nil, &block): Process a EVT_STC_USERLISTSELECTION event.
EvtHandler#evt_stc_zoom(id, meth = nil, &block): Process a EVT_STC_ZOOM event.
Most of the Scintilla notifications are mapped to a similarly named StyledTextEvent. However a few of the notifications would only offer information available in other wxWidgets event types, and in those cases a corresponding StyledTextEvent is not defined. Currently, the EVT_KEY_DOWN event is used instead of the SCN_KEY notification. The regular wxWidgets drag and drop functionality can be used instead of the SCN_URIDROPPED notification. The EVT_SET_FOCUS event is used instead of the SCN_FOCUSIN notification. And the EVT_KILL_FOCUS event is used instead of the SCN_FOCUSOUT notification.
Event Types
The following is a brief description of when the control generates these events and a list of which methods provide relevant information. Additional details can be found in the Scintilla documentation (http://www.scintilla.org/ScintillaDoc.html\#Notifications). EVT_STC_AUTOCOMP_CANCELLED
- Generated when an autocompletion list has been canceled.
- Valid event functions: none.
- Generated when a character has been deleted from an autocompletion list.
- Valid event functions: none.
- Generated after an autocompletion list has closed and inserted its text into the control.
- Valid event functions: #get_key, #get_position, GetString, #get_list_completion_method.
- Generated when an entry has been selected in an autocompletion list but before the text has been inserted.
- To prevent the insertion, call Wx::STC::StyledTextCtrl#auto_comp_cancel in the event handler.
- Valid event functions: #get_key, #get_position, GetString, #get_list_completion_method.
EVT_STC_AUTOCOMP_SELECTION_CHANGE
- Generated when items are highlighted in an autocompletion or user list.
- #get_position will return the position at which the list is being shown.
- For a user list, #get_list_type will return the list type. The list type is a value input in to the Wx::STC::StyledTextCtrl#user_list_show method when a user list is created.
- For an autocompletion list, #get_list_type will always return zero.
- Valid event functions: #get_list_type, #get_position, GetString.
- Generated when a calltip has been clicked.
- #get_position will return 1 if the up arrow has been clicked, 2 if the down arrow has been clicked, and 0 for all other clicks.
- Valid event functions: #get_position.
- Generated when the text of the document has changed.
- This an older style event and should probably not be used in new code. Use EVT_STC_MODIFIED instead.
- Valid event functions: none.
- Generated when a character has been added to the control.
- Valid event functions: #get_key.
- Generated when text is being cut or copied to the clipboard.
- Use #set_string to modify the text that will be placed on the clipboard.
- Valid event functions: GetString, Wx::SetString.
- Generated when text is being pasted from the clipboard.
- Use #set_string to modify the text that will be inserted into the control.
- Valid event functions: #get_position, GetString, Wx::SetString.
- Generated when text is being dropped into the control.
- Details of the drag may be altered by changing the respective fields of the event.
- Valid event functions: #get_drag_result, #set_drag_result, #get_position, #set_position, GetString, Wx::SetString, #get_x, #get_y.
- Generated when the control has been double-clicked.
- Valid event functions: #get_line, #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated repeatedly as text is being dragged inside the control.
- Valid event functions: #get_drag_result, #set_drag_result, #get_position, #get_x, #get_y.
- Generated when the mouse has been moved after a EVT_STC_DWELLSTART event.
- Valid event functions: #get_position, #get_x, #get_y.
- Generated when the mouse has remained still for a certain amount of time.
- The amount of time can be specified with Wx::STC::StyledTextCtrl#set_mouse_dwell_time.
- Valid event functions: #get_position, #get_x, #get_y.
- Generated when a hotspot has been clicked.
- Valid event functions: #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when a hotspot has been double-clicked.
- Valid event functions: #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when a click-over hotspot has been released.
- Valid event functions: #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when an indicator has been clicked.
- Valid event functions: #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when a click over an indicator has been released.
- Valid event functions: #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated while macro recording is in progress.
- Valid event functions: #get_message, #get_l_param, #get_w_param.
- Generated when one of the margins is clicked with the right mouse button.
- This event is only generated if Wx::SetMarginSensitive has been called for one or more of the margins.
- Valid event functions: #get_margin, #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when one of the margins is clicked.
- This event is only generated if Wx::SetMarginSensitive has been called for one or more of the margins.
- Valid event functions: #get_margin, #get_modifiers, #get_position, #get_alt, #get_control, #get_shift.
- Generated when the contents of the control have changed or are about to change.
- You should not attempt to make any changes to the control inside a handler for this event.
- Valid event functions: #get_annotations_lines_added, #get_fold_level_now, #get_fold_level_prev, #get_length, #get_line, #get_lines_added, #get_modification_type, #get_position, GetString, #get_token.
- Generated when certain lines should be made visible by scrolling the text in the control.
- Valid event functions: #get_length, #get_position.
- Generated when the control has been refreshed.
- Valid event functions: none.
- Generated when an attempt has been made to change the control's text after it has been set read-only.
- Valid event functions: none.
- Generated when the undo history has been made empty.
- Valid event functions: none.
- Generated when the undo history is no longer empty.
- Valid event functions: none.
- Generated when text is being dragged from the control.
- Details of the drag may be altered by changing the respective fields of the event; in particular, set an empty string to prohibit the drag entirely.
- Valid event functions: #get_drag_flags, #set_drag_flags, #get_position, GetString, Wx::SetString.
- Generated when the control has determined that style bytes should be set for a portion of the document.
- These events are only sent if the lexer is set to STC_LEX_CONTAINER.
- Valid event functions: #get_position.
- Generated when the text, style, cursor position, selection, or scrolling of the control has changed.
- Valid event functions: #get_updated.
- Generated when a selection has been made from a user list.
- Valid event functions: #get_list_type, #get_position, GetString, #get_key, #get_list_completion_method.
- Generated when the zoom factor of the control has been changed either by the user or a call to Wx::STC::StyledTextCtrl#zoom_in/ZoomOut.
- Valid event functions: none.
Category: Events, Scintilla Text Editor
Instance Method Summary collapse
-
#get_alt ⇒ Boolean
(also: #alt)
Returns true if the Alt key is pressed.
-
#get_annotations_lines_added ⇒ Integer
(also: #annotations_lines_added)
Returns the number of lines that have been added to or removed from an annotation.
-
#get_control ⇒ Boolean
(also: #control)
Returns true if the Control key is pressed.
-
#get_drag_flags ⇒ Integer
(also: #drag_flags)
Returns flags for the drag operation associated with this event.
-
#get_drag_result ⇒ Wx::DragResult
(also: #drag_result)
Returns drag result for this event.
-
#get_fold_level_now ⇒ Integer
(also: #fold_level_now)
Returns the current fold level for the line.
-
#get_fold_level_prev ⇒ Integer
(also: #fold_level_prev)
Returns previous fold level for the line.
-
#get_key ⇒ Integer
(also: #key)
Returns the key code of the key that generated this event.
-
#get_l_param ⇒ Integer
(also: #l_param)
Returns the value of the LParam field for this event.
-
#get_length ⇒ Integer
(also: #length)
Returns the length (number of characters) of this event.
-
#get_line ⇒ Integer
(also: #line)
Returns zero-based line number for this event.
-
#get_lines_added ⇒ Integer
(also: #lines_added)
Returns the number of lines added or deleted with this event.
-
#get_list_completion_method ⇒ Integer
(also: #list_completion_method)
Returns a value describing the action that closed the list.
-
#get_list_type ⇒ Integer
(also: #list_type)
Returns the list type for this event.
-
#get_margin ⇒ Integer
(also: #margin)
Returns the zero-based index of the margin that generated this event.
-
#get_message ⇒ Integer
(also: #message)
Returns a message number while a macro is being recorded.
-
#get_modification_type ⇒ Integer
(also: #modification_type)
Returns the modification type for this event.
-
#get_modifiers ⇒ Integer
(also: #modifiers)
Returns the modifiers of the key press or mouse click for this event.
-
#get_position ⇒ Integer
(also: #position)
Returns the zero-based text position associated this event.
-
#get_shift ⇒ Boolean
(also: #shift)
Returns true if the Shift key is pressed.
-
#get_token ⇒ Integer
(also: #token)
Returns the token value for this event.
-
#get_updated ⇒ Integer
(also: #updated)
Returns the value of the updated field for this event.
-
#get_w_param ⇒ Integer
(also: #w_param)
Returns value of the WParam field for this event.
-
#get_x ⇒ Integer
(also: #x)
Returns the X coordinate of the mouse for this event.
-
#get_y ⇒ Integer
(also: #y)
Returns the Y coordinate of the mouse for this event.
-
#initialize(*args) ⇒ StyledTextEvent
constructor
A new instance of StyledTextEvent.
-
#set_annotation_lines_added(val) ⇒ void
(also: #annotation_lines_added=)
Sets the annotation lines added value for this event.
-
#set_drag_flags(flags) ⇒ void
(also: #drag_flags=)
Sets the drag flags for this event.
-
#set_drag_result(val) ⇒ void
(also: #drag_result=)
Sets the drag result for this event.
-
#set_fold_level_now(val) ⇒ void
(also: #fold_level_now=)
Sets the current fold level for this event.
-
#set_fold_level_prev(val) ⇒ void
(also: #fold_level_prev=)
Sets the previous fold level for this event.
-
#set_key(k) ⇒ void
(also: #key=)
Sets the key code for this event.
-
#set_l_param(val) ⇒ void
(also: #l_param=)
Sets value of the LParam field for this event.
-
#set_length(len) ⇒ void
(also: #length=)
Sets the length value for this event.
-
#set_line(val) ⇒ void
(also: #line=)
Sets line number for this event.
-
#set_lines_added(num) ⇒ void
(also: #lines_added=)
Sets the number of lines added for this event.
-
#set_list_completion_method(val) ⇒ void
(also: #list_completion_method=)
Sets the list completion method for this event.
-
#set_list_type(val) ⇒ void
(also: #list_type=)
Sets the list type for this event.
-
#set_margin(val) ⇒ void
(also: #margin=)
Sets margin number for this event.
-
#set_message(val) ⇒ void
(also: #message=)
Sets message number for this event.
-
#set_modification_type(t) ⇒ void
(also: #modification_type=)
Sets the modification type for this event.
-
#set_modifiers(m) ⇒ void
(also: #modifiers=)
Sets the value of the modifiers field for this event.
-
#set_position(pos) ⇒ void
(also: #position=)
Sets file position for this event.
-
#set_token(val) ⇒ void
(also: #token=)
Sets the token for this event.
-
#set_updated(val) ⇒ void
(also: #updated=)
Sets the value of the updated field for this event.
-
#set_w_param(val) ⇒ void
(also: #w_param=)
Sets the value of the WParam field for this event.
-
#set_x(val) ⇒ void
(also: #x=)
Sets the X value for this event.
-
#set_y(val) ⇒ void
(also: #y=)
Sets the Y value for this event.
Methods inherited from CommandEvent
#client_data, #client_data=, #get_client_data, #get_client_object, #get_int, #get_selection, #get_string, #is_checked, #is_selection, #set_client_data, #set_client_object, #set_extra_long, #set_int, #set_string
Methods inherited from Event
#clone, #get_event_category, #get_event_object, #get_event_type, #get_id, #get_skipped, #get_timestamp, #is_command_event, #resume_propagation, #set_event_object, #set_event_type, #set_id, #set_timestamp, #should_propagate, #skip, #stop_propagation
Methods inherited from Object
#clone, #dup, #is_same_as, #un_share
Constructor Details
#initialize(commandType = 0, id = 0) ⇒ Wx::STC::StyledTextEvent #initialize(event) ⇒ Wx::STC::StyledTextEvent
Returns a new instance of StyledTextEvent.
8315 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8315 def initialize(*args) end |
Instance Method Details
#get_alt ⇒ Boolean Also known as: alt
Returns true if the Alt key is pressed.
This method is valid for the following event types:
8330 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8330 def get_alt; end |
#get_annotations_lines_added ⇒ Integer Also known as: annotations_lines_added
Returns the number of lines that have been added to or removed from an annotation.
This method is valid for EVT_STC_MODIFIED events when the result of #get_modification_type includes Wx::STC::STC_MOD_CHANGEANNOTATION.
8337 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8337 def get_annotations_lines_added; end |
#get_control ⇒ Boolean Also known as: control
Returns true if the Control key is pressed.
This method is valid for the following event types:
8353 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8353 def get_control; end |
#get_drag_flags ⇒ Integer Also known as: drag_flags
Returns flags for the drag operation associated with this event.
This method is valid for EVT_STC_START_DRAG events.
8360 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8360 def get_drag_flags; end |
#get_drag_result ⇒ Wx::DragResult Also known as: drag_result
Returns drag result for this event.
This method is valid for EVT_STC_DRAG_OVER and EVT_STC_DO_DROP events.
8367 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8367 def get_drag_result; end |
#get_fold_level_now ⇒ Integer Also known as: fold_level_now
Returns the current fold level for the line.
This method is valid for EVT_STC_MODIFIED events when the result of #get_modification_type includes Wx::STC::STC_MOD_CHANGEFOLD.
8374 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8374 def get_fold_level_now; end |
#get_fold_level_prev ⇒ Integer Also known as: fold_level_prev
Returns previous fold level for the line.
This method is valid for EVT_STC_MODIFIED events when the result of #get_modification_type includes Wx::STC::STC_MOD_CHANGEFOLD.
8381 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8381 def get_fold_level_prev; end |
#get_key ⇒ Integer Also known as: key
Returns the key code of the key that generated this event.
This method is valid for the following event types:
8393 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8393 def get_key; end |
#get_l_param ⇒ Integer Also known as: l_param
Returns the value of the LParam field for this event.
This method is valid for EVT_STC_MACRORECORD events.
8453 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8453 def get_l_param; end |
#get_length ⇒ Integer Also known as: length
Returns the length (number of characters) of this event.
This method is valid for EVT_STC_MODIFIED and EVT_STC_NEEDSHOWN events.
8400 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8400 def get_length; end |
#get_line ⇒ Integer Also known as: line
Returns zero-based line number for this event.
This method is valid for EVT_STC_DOUBLECLICK and EVT_STC_MODIFIED events.
8407 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8407 def get_line; end |
#get_lines_added ⇒ Integer Also known as: lines_added
Returns the number of lines added or deleted with this event.
This method is valid for EVT_STC_MODIFIED events when the result of #get_modification_type includes wxSTC_MOD_INSERTTEXT or Wx::STC::STC_MOD_DELETETEXT.
8414 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8414 def get_lines_added; end |
#get_list_completion_method ⇒ Integer Also known as: list_completion_method
Returns a value describing the action that closed the list.
The returned value will be one of the following constants:
Wx::STC::STC_AC_FILLUP A fillup character caused the completion.
Wx::STC::STC_AC_DOUBLECLICK A double-click caused the completion.
Wx::STC::STC_AC_TAB The tab key caused the completion.
Wx::STC::STC_AC_NEWLINE The enter key caused the completion.
Wx::STC::STC_AC_COMMAND The Wx::STC::StyledTextCtrl#auto_comp_complete method was called.
This method is valid for EVT_STC_USERLISTSELECTION, EVT_STC_AUTOCOMP_SELECTION, and EVT_STC_AUTOCOMP_COMPLETED events.
8438 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8438 def get_list_completion_method; end |
#get_list_type ⇒ Integer Also known as: list_type
Returns the list type for this event.
The list type is an integer passed to a list when it is created with the wxStyledTextCtrl::UserListShow method and can be used to distinguish lists if more than one is used. This method is valid for EVT_STC_AUTOCOMP_SELECTION_CHANGE and EVT_STC_USERLISTSELECTION events.
8446 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8446 def get_list_type; end |
#get_margin ⇒ Integer Also known as: margin
Returns the zero-based index of the margin that generated this event.
This method is valid for EVT_STC_MARGINCLICK and EVT_STC_MARGIN_RIGHT_CLICK events.
8460 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8460 def get_margin; end |
#get_message ⇒ Integer Also known as: message
Returns a message number while a macro is being recorded.
Many of the Wx::STC::StyledTextCtrl methods such as InsertText and Paste have an event number associated with them. This method returns that number while a macro is being recorded so that the macro can be played back later. This method is valid for EVT_STC_MACRORECORD events.
8468 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8468 def ; end |
#get_modification_type ⇒ Integer Also known as: modification_type
Returns the modification type for this event.
The modification type is a bit list that describes the change that generated this event. It may contain one or more of the following values:
- wxSTC_MOD_INSERTTEXT
- wxSTC_MOD_DELETETEXT
- wxSTC_MOD_CHANGESTYLE
- wxSTC_MOD_CHANGEFOLD
- wxSTC_PERFORMED_USER
- wxSTC_PERFORMED_UNDO
- wxSTC_PERFORMED_REDO
- wxSTC_MULTISTEPUNDOREDO
- wxSTC_LASTSTEPINUNDOREDO
- wxSTC_MOD_CHANGEMARKER
- wxSTC_MOD_BEFOREINSERT
- wxSTC_MOD_BEFOREDELETE
- wxSTC_MULTILINEUNDOREDO
- wxSTC_STARTACTION
- wxSTC_MOD_CHANGEINDICATOR
- wxSTC_MOD_CHANGELINESTATE
- wxSTC_MOD_CHANGEMARGIN
- wxSTC_MOD_CHANGEANNOTATION
- wxSTC_MOD_CONTAINER
- wxSTC_MOD_LEXERSTATE
- wxSTC_MOD_INSERTCHECK
- wxSTC_MOD_CHANGETABSTOPS
This method is valid for EVT_STC_MODIFIED events.
8500 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8500 def get_modification_type; end |
#get_modifiers ⇒ Integer Also known as: modifiers
Returns the modifiers of the key press or mouse click for this event.
The returned value is a bit list that may contain one or more of the following values:
- wxSTC_KEYMOD_SHIFT
- wxSTC_KEYMOD_CTRL
- wxSTC_KEYMOD_ALT
- wxSTC_KEYMOD_SUPER
- wxSTC_KEYMOD_META
In addition, the value can be checked for equality with wxSTC_KEYMOD_NORM to test if no modifiers are present. This method is valid for the following event types:
8525 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8525 def get_modifiers; end |
#get_position ⇒ Integer Also known as: position
Returns the zero-based text position associated this event.
This method is valid for the following event types:
- EVT_STC_STYLENEEDED
- EVT_STC_DOUBLECLICK
- EVT_STC_MODIFIED
- EVT_STC_MARGINCLICK
- EVT_STC_NEEDSHOWN
- EVT_STC_USERLISTSELECTION
- EVT_STC_DWELLSTART
- EVT_STC_DWELLEND
- EVT_STC_HOTSPOT_CLICK
- EVT_STC_HOTSPOT_DCLICK
- EVT_STC_HOTSPOT_RELEASE_CLICK
- EVT_STC_INDICATOR_CLICK
- EVT_STC_INDICATOR_RELEASE
- EVT_STC_CALLTIP_CLICK
- EVT_STC_AUTOCOMP_SELECTION
- EVT_STC_AUTOCOMP_SELECTION_CHANGE
- EVT_STC_AUTOCOMP_COMPLETED
- EVT_STC_MARGIN_RIGHT_CLICK
8551 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8551 def get_position; end |
#get_shift ⇒ Boolean Also known as: shift
Returns true if the Shift key is pressed.
This method is valid for the following event types:
8567 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8567 def get_shift; end |
#get_token ⇒ Integer Also known as: token
Returns the token value for this event.
The token is an integer value that can be set with a call to the Wx::STC::StyledTextCtrl#add_undo_action method. This method is valid for EVT_STC_MODIFIED events when the result of #get_modification_type includes Wx::STC::STC_MOD_CONTAINER.
8575 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8575 def get_token; end |
#get_updated ⇒ Integer Also known as: updated
Returns the value of the updated field for this event.
The value of this field is a bit list that describes the change that generated this event. It may contain one or more of the following values:
- wxSTC_UPDATE_CONTENT
- wxSTC_UPDATE_SELECTION
- wxSTC_UPDATE_V_SCROLL
- wxSTC_UPDATE_H_SCROLL
This method is valid for EVT_STC_UPDATEUI events.
8589 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8589 def get_updated; end |
#get_w_param ⇒ Integer Also known as: w_param
Returns value of the WParam field for this event.
This method is valid for EVT_STC_MACRORECORD events.
8596 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8596 def get_w_param; end |
#get_x ⇒ Integer Also known as: x
Returns the X coordinate of the mouse for this event.
This method is valid for the following event types:
8609 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8609 def get_x; end |
#get_y ⇒ Integer Also known as: y
Returns the Y coordinate of the mouse for this event.
This method is valid for the following event types:
8622 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8622 def get_y; end |
#set_annotation_lines_added(val) ⇒ void Also known as: annotation_lines_added=
This method returns an undefined value.
Sets the annotation lines added value for this event.
8628 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8628 def set_annotation_lines_added(val) end |
#set_drag_flags(flags) ⇒ void Also known as: drag_flags=
This method returns an undefined value.
Sets the drag flags for this event.
8634 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8634 def set_drag_flags(flags) end |
#set_drag_result(val) ⇒ void Also known as: drag_result=
This method returns an undefined value.
Sets the drag result for this event.
8640 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8640 def set_drag_result(val) end |
#set_fold_level_now(val) ⇒ void Also known as: fold_level_now=
This method returns an undefined value.
Sets the current fold level for this event.
8646 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8646 def set_fold_level_now(val) end |
#set_fold_level_prev(val) ⇒ void Also known as: fold_level_prev=
This method returns an undefined value.
Sets the previous fold level for this event.
8652 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8652 def set_fold_level_prev(val) end |
#set_key(k) ⇒ void Also known as: key=
This method returns an undefined value.
Sets the key code for this event.
8658 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8658 def set_key(k) end |
#set_l_param(val) ⇒ void Also known as: l_param=
This method returns an undefined value.
Sets value of the LParam field for this event.
8694 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8694 def set_l_param(val) end |
#set_length(len) ⇒ void Also known as: length=
This method returns an undefined value.
Sets the length value for this event.
8664 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8664 def set_length(len) end |
#set_line(val) ⇒ void Also known as: line=
This method returns an undefined value.
Sets line number for this event.
8670 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8670 def set_line(val) end |
#set_lines_added(num) ⇒ void Also known as: lines_added=
This method returns an undefined value.
Sets the number of lines added for this event.
8676 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8676 def set_lines_added(num) end |
#set_list_completion_method(val) ⇒ void Also known as: list_completion_method=
This method returns an undefined value.
Sets the list completion method for this event.
8682 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8682 def set_list_completion_method(val) end |
#set_list_type(val) ⇒ void Also known as: list_type=
This method returns an undefined value.
Sets the list type for this event.
8688 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8688 def set_list_type(val) end |
#set_margin(val) ⇒ void Also known as: margin=
This method returns an undefined value.
Sets margin number for this event.
8700 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8700 def set_margin(val) end |
#set_message(val) ⇒ void Also known as: message=
This method returns an undefined value.
Sets message number for this event.
8706 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8706 def (val) end |
#set_modification_type(t) ⇒ void Also known as: modification_type=
This method returns an undefined value.
Sets the modification type for this event.
8712 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8712 def set_modification_type(t) end |
#set_modifiers(m) ⇒ void Also known as: modifiers=
This method returns an undefined value.
Sets the value of the modifiers field for this event.
8718 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8718 def set_modifiers(m) end |
#set_position(pos) ⇒ void Also known as: position=
This method returns an undefined value.
Sets file position for this event.
8724 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8724 def set_position(pos) end |
#set_token(val) ⇒ void Also known as: token=
This method returns an undefined value.
Sets the token for this event.
8730 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8730 def set_token(val) end |
#set_updated(val) ⇒ void Also known as: updated=
This method returns an undefined value.
Sets the value of the updated field for this event.
8736 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8736 def set_updated(val) end |
#set_w_param(val) ⇒ void Also known as: w_param=
This method returns an undefined value.
Sets the value of the WParam field for this event.
8742 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8742 def set_w_param(val) end |
#set_x(val) ⇒ void Also known as: x=
This method returns an undefined value.
Sets the X value for this event.
8748 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8748 def set_x(val) end |
#set_y(val) ⇒ void Also known as: y=
This method returns an undefined value.
Sets the Y value for this event.
8754 |
# File 'lib/wx/doc/gen/stc/styled_text_event.rb', line 8754 def set_y(val) end |