Class: Wx::ToolTip
Overview
This class holds information about a tooltip associated with a window (see Window#set_tool_tip).
The four static methods, ToolTip.enable, ToolTip.set_delay ToolTip.set_auto_pop and ToolTip.set_reshow can be used to globally alter tooltips behaviour.
Category: HELP
Class Method Summary collapse
-
.enable(flag) ⇒ void
Enable or disable tooltips globally.
-
.set_auto_pop(msecs) ⇒ void
Set the delay after which the tooltip disappears or how long a tooltip remains visible.
-
.set_delay(msecs) ⇒ void
Set the delay after which the tooltip appears.
-
.set_reshow(msecs) ⇒ void
Set the delay between subsequent tooltips to appear.
Instance Method Summary collapse
-
#get_tip ⇒ String
(also: #tip)
Get the tooltip text.
-
#get_window ⇒ Wx::Window
(also: #window)
Get the associated window.
-
#initialize(tip) ⇒ Wx::ToolTip
constructor
Constructor.
-
#set_tip(tip) ⇒ void
(also: #tip=)
Set the tooltip text.
Methods inherited from Object
#clone, #dup, #is_same_as, #un_share
Constructor Details
#initialize(tip) ⇒ Wx::ToolTip
Constructor.
21 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 21 def initialize(tip) end |
Class Method Details
.enable(flag) ⇒ void
This method returns an undefined value.
Enable or disable tooltips globally.
May not be supported on all platforms (eg. Cocoa).
48 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 48 def self.enable(flag) end |
.set_auto_pop(msecs) ⇒ void
This method returns an undefined value.
Set the delay after which the tooltip disappears or how long a tooltip remains visible.
May not be supported on all platforms (eg. Cocoa, GTK).
59 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 59 def self.set_auto_pop(msecs) end |
.set_delay(msecs) ⇒ void
This method returns an undefined value.
Set the delay after which the tooltip appears.
May not be supported on all platforms.
70 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 70 def self.set_delay(msecs) end |
.set_reshow(msecs) ⇒ void
This method returns an undefined value.
Set the delay between subsequent tooltips to appear.
May not be supported on all platforms (eg. Cocoa, GTK).
81 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 81 def self.set_reshow(msecs) end |
Instance Method Details
#get_tip ⇒ String Also known as: tip
Get the tooltip text.
25 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 25 def get_tip; end |
#get_window ⇒ Wx::Window Also known as: window
Get the associated window.
30 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 30 def get_window; end |
#set_tip(tip) ⇒ void Also known as: tip=
This method returns an undefined value.
Set the tooltip text.
36 |
# File 'lib/wx/doc/gen/tool_tip.rb', line 36 def set_tip(tip) end |