Class: Wx::WEB::WebViewArchiveHandler
- Inherits:
-
WebViewHandler
- Object
- WebViewHandler
- Wx::WEB::WebViewArchiveHandler
- Defined in:
- lib/wx/doc/gen/web/web_view_handler.rb
Overview
Note:
This class is untracked and should not be derived from nor instances extended!
A custom handler for the file scheme which also supports loading from archives.
The syntax for WebViewArchiveHandler differs from virtual file systems in the rest of wxWidgets by using a syntax such as scheme:///C:/example/docs.zip;protocol=zip/main.htm Currently the only supported protocol is zip.
Category: WebView
Instance Method Summary collapse
-
#get_file(uri) ⇒ Wx::FSFile
(also: #file)
A pointer to the file represented by uri.
-
#initialize(scheme) ⇒ Wx::WEB::WebViewArchiveHandler
constructor
Constructor.
Methods inherited from WebViewHandler
#get_name, #get_security_url, #get_virtual_host, #set_security_url, #set_virtual_host, #start_request
Constructor Details
#initialize(scheme) ⇒ Wx::WEB::WebViewArchiveHandler
Constructor.
142 |
# File 'lib/wx/doc/gen/web/web_view_handler.rb', line 142 def initialize(scheme) end |
Instance Method Details
#get_file(uri) ⇒ Wx::FSFile Also known as: file
A pointer to the file represented by uri.
149 |
# File 'lib/wx/doc/gen/web/web_view_handler.rb', line 149 def get_file(uri) end |