Class: Wx::WEB::WebViewConfiguration
- Inherits:
-
Object
- Object
- Wx::WEB::WebViewConfiguration
- Defined in:
- lib/wx/doc/gen/web/web_view.rb
Overview
This class allows access to web view configuration options and settings, that have to be specified before placing a webview in a window with Wx::WEB::WebView#create.
Category: WebView
Instance Method Summary collapse
-
#enable_persistent_storage(enable) ⇒ Boolean
Allows to disable persistent storage for the webview.
-
#get_backend ⇒ String
(also: #backend)
Returns the backend identifier for which this configuration was created.
-
#get_data_path ⇒ String
(also: #data_path)
Returns the data path for the webview.
-
#set_data_path(path) ⇒ void
(also: #data_path=)
Set the data path for the webview.
Instance Method Details
#enable_persistent_storage(enable) ⇒ Boolean
Allows to disable persistent storage for the webview.
The default is to enable it. When the webview is created without persistent storage the data is stored in memory and is lost when the webview is destroyed. In browsers this is equivalent to "private browsing" or "incognito mode". true if the backend supports to modify this setting. false if the setting is not supported by the backend.
This is only implemented on the Edge, WebKit2GTK+ and macOS backends.
1126 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1126 def enable_persistent_storage(enable) end |
#get_backend ⇒ String Also known as: backend
Returns the backend identifier for which this configuration was created.
1084 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1084 def get_backend; end |
#get_data_path ⇒ String Also known as: data_path
Returns the data path for the webview.
This is the path where the webview stores its data, such as cookies, local storage, etc. The path to the data directory.
This is used by Edge, WebKit2GTK+ and Chromium backends and always returns empty string for the other ones.
1111 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1111 def get_data_path; end |
#set_data_path(path) ⇒ void Also known as: data_path=
This method returns an undefined value.
Set the data path for the webview.
This is the path where the webview stores its data, such as cookies, local storage, etc.
This is used by Edge, WebKit2GTK+ and Chromium backends (the latter creates "UserData" subdirectory under the given path).
1098 |
# File 'lib/wx/doc/gen/web/web_view.rb', line 1098 def set_data_path(path) end |